#!/usr/bin/env python
# SPDX-License-Identifier: AGPL-3.0-or-later
# lint: pylint
# pyright: basic
"""WebbApp

"""
# pylint: disable=use-dict-literal

import hashlib
import hmac
import json
import os
import sys
import base64
import requests
import markdown
import re
import datetime

from timeit import default_timer
from html import escape
from io import StringIO
import typing
from typing import List, Dict, Iterable

import urllib
import urllib.parse
from urllib.parse import urlencode, unquote

import httpx

from pygments import highlight
from pygments.lexers import get_lexer_by_name
from pygments.formatters import HtmlFormatter  # pylint: disable=no-name-in-module

import flask

from flask import (
    Flask,
    render_template,
    url_for,
    make_response,
    redirect,
    send_from_directory,
)
from flask.wrappers import Response
from flask.json import jsonify

from flask_babel import (
    Babel,
    gettext,
    format_decimal,
)

from searx import (
    logger,
    get_setting,
    settings,
    searx_debug,
)

from searx import infopage
from searx.data import ENGINE_DESCRIPTIONS
from searx.results import Timing, UnresponsiveEngine
from searx.settings_defaults import OUTPUT_FORMATS
from searx.settings_loader import get_default_settings_path
from searx.exceptions import SearxParameterException
from searx.engines import (
    OTHER_CATEGORY,
    categories,
    engines,
    engine_shortcuts,
)
from searx.webutils import (
    UnicodeWriter,
    highlight_content,
    get_static_files,
    get_result_templates,
    get_themes,
    prettify_url,
    new_hmac,
    is_hmac_of,
    is_flask_run_cmdline,
    group_engines_in_tab,
    searxng_l10n_timespan,
)
from searx.webadapter import (
    get_search_query_from_webapp,
    get_selected_categories,
)
from searx.utils import (
    html_to_text,
    gen_useragent,
    dict_subset,
    match_language,
)
from searx.version import VERSION_STRING, GIT_URL, GIT_BRANCH
from searx.query import RawTextQuery
from searx.plugins import Plugin, plugins, initialize as plugin_initialize
from searx.plugins.oa_doi_rewrite import get_doi_resolver
from searx.preferences import (
    Preferences,
    ValidationException,
)
from searx.answerers import (
    answerers,
    ask,
)
from searx.metrics import (
    get_engines_stats,
    get_engine_errors,
    get_reliabilities,
    histogram,
    counter,
)
from searx.flaskfix import patch_application

from searx.locales import (
    LOCALE_NAMES,
    RTL_LOCALES,
    localeselector,
    locales_initialize,
)

# renaming names from searx imports ...
from searx.autocomplete import search_autocomplete, backends as autocomplete_backends
from searx.languages import language_codes as languages
from searx.redisdb import initialize as redis_initialize
from searx.search import SearchWithPlugins, initialize as search_initialize
from searx.network import stream as http_stream, set_context_network_name
from searx.search.checker import get_result as checker_get_result

logger = logger.getChild('webapp')

# check secret_key
if not searx_debug and settings['server']['secret_key'] == 'ultrasecretkey':
    logger.error('server.secret_key is not changed. Please use something else instead of ultrasecretkey.')
    sys.exit(1)

# about static
logger.debug('static directory is %s', settings['ui']['static_path'])
static_files = get_static_files(settings['ui']['static_path'])

# about templates
logger.debug('templates directory is %s', settings['ui']['templates_path'])
default_theme = settings['ui']['default_theme']
templates_path = settings['ui']['templates_path']
themes = get_themes(templates_path)
result_templates = get_result_templates(templates_path)

STATS_SORT_PARAMETERS = {
    'name': (False, 'name', ''),
    'score': (True, 'score_per_result', 0),
    'result_count': (True, 'result_count', 0),
    'time': (False, 'total', 0),
    'reliability': (False, 'reliability', 100),
}

# Flask app
app = Flask(__name__, static_folder=settings['ui']['static_path'], template_folder=templates_path)

app.jinja_env.trim_blocks = True
app.jinja_env.lstrip_blocks = True
app.jinja_env.add_extension('jinja2.ext.loopcontrols')  # pylint: disable=no-member
app.jinja_env.filters['group_engines_in_tab'] = group_engines_in_tab  # pylint: disable=no-member
app.secret_key = settings['server']['secret_key']

timeout_text = gettext('timeout')
parsing_error_text = gettext('parsing error')
http_protocol_error_text = gettext('HTTP protocol error')
network_error_text = gettext('network error')
ssl_cert_error_text = gettext("SSL error: certificate validation has failed")
exception_classname_to_text = {
    None: gettext('unexpected crash'),
    'timeout': timeout_text,
    'asyncio.TimeoutError': timeout_text,
    'httpx.TimeoutException': timeout_text,
    'httpx.ConnectTimeout': timeout_text,
    'httpx.ReadTimeout': timeout_text,
    'httpx.WriteTimeout': timeout_text,
    'httpx.HTTPStatusError': gettext('HTTP error'),
    'httpx.ConnectError': gettext("HTTP connection error"),
    'httpx.RemoteProtocolError': http_protocol_error_text,
    'httpx.LocalProtocolError': http_protocol_error_text,
    'httpx.ProtocolError': http_protocol_error_text,
    'httpx.ReadError': network_error_text,
    'httpx.WriteError': network_error_text,
    'httpx.ProxyError': gettext("proxy error"),
    'searx.exceptions.SearxEngineCaptchaException': gettext("CAPTCHA"),
    'searx.exceptions.SearxEngineTooManyRequestsException': gettext("too many requests"),
    'searx.exceptions.SearxEngineAccessDeniedException': gettext("access denied"),
    'searx.exceptions.SearxEngineAPIException': gettext("server API error"),
    'searx.exceptions.SearxEngineXPathException': parsing_error_text,
    'KeyError': parsing_error_text,
    'json.decoder.JSONDecodeError': parsing_error_text,
    'lxml.etree.ParserError': parsing_error_text,
    'ssl.SSLCertVerificationError': ssl_cert_error_text,  # for Python > 3.7
    'ssl.CertificateError': ssl_cert_error_text,  # for Python 3.7
}


class ExtendedRequest(flask.Request):
    """This class is never initialized and only used for type checking."""

    preferences: Preferences
    errors: List[str]
    user_plugins: List[Plugin]
    form: Dict[str, str]
    start_time: float
    render_time: float
    timings: List[Timing]


request = typing.cast(ExtendedRequest, flask.request)


def get_locale():
    locale = localeselector()
    logger.debug("%s uses locale `%s`", urllib.parse.quote(request.url), locale)
    return locale


babel = Babel(app, locale_selector=get_locale)


def _get_browser_language(req, lang_list):
    for lang in req.headers.get("Accept-Language", "en").split(","):
        if ';' in lang:
            lang = lang.split(';')[0]
        if '-' in lang:
            lang_parts = lang.split('-')
            lang = "{}-{}".format(lang_parts[0], lang_parts[-1].upper())
        locale = match_language(lang, lang_list, fallback=None)
        if locale is not None:
            return locale
    return 'en'


def _get_locale_rfc5646(locale):
    """Get locale name for <html lang="...">
    Chrom* browsers don't detect the language when there is a subtag (ie a territory).
    For example "zh-TW" is detected but not "zh-Hant-TW".
    This function returns a locale without the subtag.
    """
    parts = locale.split('-')
    return parts[0].lower() + '-' + parts[-1].upper()


# code-highlighter
@app.template_filter('code_highlighter')
def code_highlighter(codelines, language=None):
    if not language:
        language = 'text'

    try:
        # find lexer by programming language
        lexer = get_lexer_by_name(language, stripall=True)

    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        # if lexer is not found, using default one
        lexer = get_lexer_by_name('text', stripall=True)

    html_code = ''
    tmp_code = ''
    last_line = None
    line_code_start = None

    # parse lines
    for line, code in codelines:
        if not last_line:
            line_code_start = line

        # new codeblock is detected
        if last_line is not None and last_line + 1 != line:

            # highlight last codepart
            formatter = HtmlFormatter(linenos='inline', linenostart=line_code_start, cssclass="code-highlight")
            html_code = html_code + highlight(tmp_code, lexer, formatter)

            # reset conditions for next codepart
            tmp_code = ''
            line_code_start = line

        # add codepart
        tmp_code += code + '\n'

        # update line
        last_line = line

    # highlight last codepart
    formatter = HtmlFormatter(linenos='inline', linenostart=line_code_start, cssclass="code-highlight")
    html_code = html_code + highlight(tmp_code, lexer, formatter)

    return html_code


def get_result_template(theme_name: str, template_name: str):
    themed_path = theme_name + '/result_templates/' + template_name
    if themed_path in result_templates:
        return themed_path
    return 'result_templates/' + template_name


def custom_url_for(endpoint: str, **values):
    suffix = ""
    if endpoint == 'static' and values.get('filename'):
        file_hash = static_files.get(values['filename'])
        if not file_hash:
            # try file in the current theme
            theme_name = request.preferences.get_value('theme')
            filename_with_theme = "themes/{}/{}".format(theme_name, values['filename'])
            file_hash = static_files.get(filename_with_theme)
            if file_hash:
                values['filename'] = filename_with_theme
        if get_setting('ui.static_use_hash') and file_hash:
            suffix = "?" + file_hash
    if endpoint == 'info' and 'locale' not in values:
        locale = request.preferences.get_value('locale')
        if _INFO_PAGES.get_page(values['pagename'], locale) is None:
            locale = _INFO_PAGES.locale_default
        values['locale'] = locale
    return url_for(endpoint, **values) + suffix


def morty_proxify(url: str):
    if url.startswith('//'):
        url = 'https:' + url

    if not settings['result_proxy']['url']:
        return url

    url_params = dict(mortyurl=url)

    if settings['result_proxy']['key']:
        url_params['mortyhash'] = hmac.new(settings['result_proxy']['key'], url.encode(), hashlib.sha256).hexdigest()

    return '{0}?{1}'.format(settings['result_proxy']['url'], urlencode(url_params))


def image_proxify(url: str):

    if url.startswith('//'):
        url = 'https:' + url

    if not request.preferences.get_value('image_proxy'):
        return url

    if url.startswith('data:image/'):
        # 50 is an arbitrary number to get only the beginning of the image.
        partial_base64 = url[len('data:image/') : 50].split(';')
        if (
            len(partial_base64) == 2
            and partial_base64[0] in ['gif', 'png', 'jpeg', 'pjpeg', 'webp', 'tiff', 'bmp']
            and partial_base64[1].startswith('base64,')
        ):
            return url
        return None

    if settings['result_proxy']['url']:
        return morty_proxify(url)

    h = new_hmac(settings['server']['secret_key'], url.encode())

    return '{0}?{1}'.format(url_for('image_proxy'), urlencode(dict(url=url.encode(), h=h)))


def get_translations():
    return {
        # when there is autocompletion
        'no_item_found': gettext('No item found'),
        # /preferences: the source of the engine description (wikipedata, wikidata, website)
        'Source': gettext('Source'),
        # infinite scroll
        'error_loading_next_page': gettext('Error loading the next page'),
    }


def _get_enable_categories(all_categories: Iterable[str]):
    disabled_engines = request.preferences.engines.get_disabled()
    enabled_categories = set(
        # pylint: disable=consider-using-dict-items
        category
        for engine_name in engines
        for category in engines[engine_name].categories
        if (engine_name, category) not in disabled_engines
    )
    return [x for x in all_categories if x in enabled_categories]


def get_pretty_url(parsed_url: urllib.parse.ParseResult):
    path = parsed_url.path
    path = path[:-1] if len(path) > 0 and path[-1] == '/' else path
    path = unquote(path.replace("/", " › "))
    return [parsed_url.scheme + "://" + parsed_url.netloc, path]


def get_client_settings():
    req_pref = request.preferences
    return {
        'autocomplete_provider': req_pref.get_value('autocomplete'),
        'autocomplete_min': get_setting('search.autocomplete_min'),
        'http_method': req_pref.get_value('method'),
        'infinite_scroll': req_pref.get_value('infinite_scroll'),
        'translations': get_translations(),
        'search_on_category_select': req_pref.plugins.choices['searx.plugins.search_on_category_select'],
        'hotkeys': req_pref.plugins.choices['searx.plugins.vim_hotkeys'],
        'theme_static_path': custom_url_for('static', filename='themes/simple'),
    }


def render(template_name: str, **kwargs):

    kwargs['client_settings'] = str(
        base64.b64encode(
            bytes(
                json.dumps(get_client_settings()),
                encoding='utf-8',
            )
        ),
        encoding='utf-8',
    )

    # values from the HTTP requests
    kwargs['endpoint'] = 'results' if 'q' in kwargs else request.endpoint
    kwargs['cookies'] = request.cookies
    kwargs['errors'] = request.errors

    # values from the preferences
    kwargs['preferences'] = request.preferences
    kwargs['autocomplete'] = request.preferences.get_value('autocomplete')
    kwargs['infinite_scroll'] = request.preferences.get_value('infinite_scroll')
    kwargs['results_on_new_tab'] = request.preferences.get_value('results_on_new_tab')
    kwargs['advanced_search'] = request.preferences.get_value('advanced_search')
    kwargs['query_in_title'] = request.preferences.get_value('query_in_title')
    kwargs['safesearch'] = str(request.preferences.get_value('safesearch'))
    kwargs['theme'] = request.preferences.get_value('theme')
    kwargs['method'] = request.preferences.get_value('method')
    kwargs['categories_as_tabs'] = list(settings['categories_as_tabs'].keys())
    kwargs['categories'] = _get_enable_categories(categories.keys())
    kwargs['OTHER_CATEGORY'] = OTHER_CATEGORY

    # i18n
    kwargs['language_codes'] = [l for l in languages if l[0] in settings['search']['languages']]

    locale = request.preferences.get_value('locale')
    kwargs['locale_rfc5646'] = _get_locale_rfc5646(locale)

    if locale in RTL_LOCALES and 'rtl' not in kwargs:
        kwargs['rtl'] = True
    if 'current_language' not in kwargs:
        kwargs['current_language'] = match_language(
            request.preferences.get_value('language'), settings['search']['languages']
        )

    # values from settings
    kwargs['search_formats'] = [x for x in settings['search']['formats'] if x != 'html']
    kwargs['instance_name'] = get_setting('general.instance_name')
    kwargs['searx_version'] = VERSION_STRING
    kwargs['searx_git_url'] = GIT_URL
    kwargs['enable_metrics'] = get_setting('general.enable_metrics')
    kwargs['get_setting'] = get_setting
    kwargs['get_pretty_url'] = get_pretty_url

    # values from settings: donation_url
    donation_url = get_setting('general.donation_url')
    if donation_url is True:
        donation_url = custom_url_for('info', pagename='donate')
    kwargs['donation_url'] = donation_url

    # helpers to create links to other pages
    kwargs['url_for'] = custom_url_for  # override url_for function in templates
    kwargs['image_proxify'] = image_proxify
    kwargs['proxify'] = morty_proxify if settings['result_proxy']['url'] is not None else None
    kwargs['proxify_results'] = settings['result_proxy']['proxify_results']
    kwargs['cache_url'] = settings['ui']['cache_url']
    kwargs['get_result_template'] = get_result_template
    kwargs['doi_resolver'] = get_doi_resolver(request.preferences)
    kwargs['opensearch_url'] = (
        url_for('opensearch')
        + '?'
        + urlencode(
            {
                'method': request.preferences.get_value('method'),
                'autocomplete': request.preferences.get_value('autocomplete'),
            }
        )
    )

    # scripts from plugins
    kwargs['scripts'] = set()
    for plugin in request.user_plugins:
        for script in plugin.js_dependencies:
            kwargs['scripts'].add(script)

    # styles from plugins
    kwargs['styles'] = set()
    for plugin in request.user_plugins:
        for css in plugin.css_dependencies:
            kwargs['styles'].add(css)

    start_time = default_timer()
    result = render_template('{}/{}'.format(kwargs['theme'], template_name), **kwargs)
    request.render_time += default_timer() - start_time  # pylint: disable=assigning-non-slot

    return result


@app.before_request
def pre_request():
    request.start_time = default_timer()  # pylint: disable=assigning-non-slot
    request.render_time = 0  # pylint: disable=assigning-non-slot
    request.timings = []  # pylint: disable=assigning-non-slot
    request.errors = []  # pylint: disable=assigning-non-slot

    preferences = Preferences(themes, list(categories.keys()), engines, plugins)  # pylint: disable=redefined-outer-name
    user_agent = request.headers.get('User-Agent', '').lower()
    if 'webkit' in user_agent and 'android' in user_agent:
        preferences.key_value_settings['method'].value = 'GET'
    request.preferences = preferences  # pylint: disable=assigning-non-slot

    try:
        preferences.parse_dict(request.cookies)

    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        request.errors.append(gettext('Invalid settings, please edit your preferences'))

    # merge GET, POST vars
    # request.form
    request.form = dict(request.form.items())  # pylint: disable=assigning-non-slot
    for k, v in request.args.items():
        if k not in request.form:
            request.form[k] = v

    if request.form.get('preferences'):
        preferences.parse_encoded_data(request.form['preferences'])
    else:
        try:
            preferences.parse_dict(request.form)
        except Exception as e:  # pylint: disable=broad-except
            logger.exception(e, exc_info=True)
            request.errors.append(gettext('Invalid settings'))

    # language is defined neither in settings nor in preferences
    # use browser headers
    if not preferences.get_value("language"):
        language = _get_browser_language(request, settings['search']['languages'])
        preferences.parse_dict({"language": language})
        logger.debug('set language %s (from browser)', preferences.get_value("language"))

    # locale is defined neither in settings nor in preferences
    # use browser headers
    if not preferences.get_value("locale"):
        locale = _get_browser_language(request, LOCALE_NAMES.keys())
        preferences.parse_dict({"locale": locale})
        logger.debug('set locale %s (from browser)', preferences.get_value("locale"))

    # request.user_plugins
    request.user_plugins = []  # pylint: disable=assigning-non-slot
    allowed_plugins = preferences.plugins.get_enabled()
    disabled_plugins = preferences.plugins.get_disabled()
    for plugin in plugins:
        if (plugin.default_on and plugin.id not in disabled_plugins) or plugin.id in allowed_plugins:
            request.user_plugins.append(plugin)


@app.after_request
def add_default_headers(response: flask.Response):
    # set default http headers
    for header, value in settings['server']['default_http_headers'].items():
        if header in response.headers:
            continue
        response.headers[header] = value
    return response


@app.after_request
def post_request(response: flask.Response):
    total_time = default_timer() - request.start_time
    timings_all = [
        'total;dur=' + str(round(total_time * 1000, 3)),
        'render;dur=' + str(round(request.render_time * 1000, 3)),
    ]
    if len(request.timings) > 0:
        timings = sorted(request.timings, key=lambda t: t.total)
        timings_total = [
            'total_' + str(i) + '_' + t.engine + ';dur=' + str(round(t.total * 1000, 3)) for i, t in enumerate(timings)
        ]
        timings_load = [
            'load_' + str(i) + '_' + t.engine + ';dur=' + str(round(t.load * 1000, 3))
            for i, t in enumerate(timings)
            if t.load
        ]
        timings_all = timings_all + timings_total + timings_load
    # response.headers.add('Server-Timing', ', '.join(timings_all))
    return response


def index_error(output_format: str, error_message: str):
    if output_format == 'json':
        return Response(json.dumps({'error': error_message}), mimetype='application/json')
    if output_format == 'csv':
        response = Response('', mimetype='application/csv')
        cont_disp = 'attachment;Filename=searx.csv'
        response.headers.add('Content-Disposition', cont_disp)
        return response

    if output_format == 'rss':
        response_rss = render(
            'opensearch_response_rss.xml',
            results=[],
            q=request.form['q'] if 'q' in request.form else '',
            number_of_results=0,
            error_message=error_message,
        )
        return Response(response_rss, mimetype='text/xml')

    # html
    request.errors.append(gettext('search error'))
    return render(
        # fmt: off
        'index.html',
        selected_categories=get_selected_categories(request.preferences, request.form),
        # fmt: on
    )


@app.route('/', methods=['GET', 'POST'])
def index():
    """Render index page."""

    # redirect to search if there's a query in the request
    if request.form.get('q'):
        query = ('?' + request.query_string.decode()) if request.query_string else ''
        return redirect(url_for('search') + query, 308)

    return render(
        # fmt: off
        'index.html',
        selected_categories=get_selected_categories(request.preferences, request.form),
        current_locale = request.preferences.get_value("locale"),
        # fmt: on
    )


@app.route('/healthz', methods=['GET'])
def health():
    return Response('OK', mimetype='text/plain')


@app.route('/search', methods=['GET', 'POST'])
def search():
    """Search query in q and return results.

    Supported outputs: html, json, csv, rss.
    """
    # pylint: disable=too-many-locals, too-many-return-statements, too-many-branches
    # pylint: disable=too-many-statements

    # output_format
    output_format = request.form.get('format', 'html')
    if output_format not in OUTPUT_FORMATS:
        output_format = 'html'

    if output_format not in settings['search']['formats']:
        flask.abort(403)

    # check if there is query (not None and not an empty string)
    if not request.form.get('q'):
        if output_format == 'html':
            return render(
                # fmt: off
                'index.html',
                selected_categories=get_selected_categories(request.preferences, request.form),
                # fmt: on
            )
        return index_error(output_format, 'No query'), 400

    # search
    search_query = None
    raw_text_query = None
    result_container = None
    original_search_query = ""
    try:
        search_query, raw_text_query, _, _ = get_search_query_from_webapp(request.preferences, request.form)
        # search = Search(search_query) #  without plugins
        try:
            original_search_query = search_query.query
            if "模仿" in search_query.query or "扮演" in search_query.query or "你能" in search_query.query or "请推荐" in search_query.query or "帮我" in search_query.query or "写一段" in search_query.query or "写一个" in search_query.query or "请问" in search_query.query or "请给" in search_query.query or "请你" in search_query.query  or "请推荐" in search_query.query or "是谁" in search_query.query or "能帮忙" in search_query.query or "介绍一下" in search_query.query or "为什么" in search_query.query or "什么是" in search_query.query or "有什么" in search_query.query or "怎样" in search_query.query or "给我" in search_query.query or "如何" in search_query.query or "谁是" in search_query.query or "查询" in search_query.query or "告诉我" in search_query.query or "查一下" in search_query.query or "找一个" in search_query.query or "什么样" in search_query.query or "哪个" in search_query.query or "哪些" in search_query.query or "哪一个" in search_query.query or "哪一些" in search_query.query  or "啥是" in search_query.query or "为啥" in search_query.query or "怎么" in search_query.query:
                if len(search_query.query)>5 and "谁是" in search_query.query:
                    search_query.query = search_query.query.replace("谁是","")
                if len(search_query.query)>5 and "是谁" in search_query.query:
                    search_query.query = search_query.query.replace("是谁","")
                if len(search_query.query)>5 and not "谁是" in search_query.query and not "是谁" in search_query.query:
                    prompt = search_query.query + "\n对以上问题生成一个Google搜索词：\n"
                    if "今年" in prompt or "今天" in prompt:
                        now = datetime.datetime.now()
                        prompt = prompt.replace("今年",now.strftime('%Y年'))
                        prompt = prompt.replace("今天",now.strftime('%Y年%m月%d日'))
                    gpt = ""
                    gpt_url = "https://api.openai.com/v1/engines/text-davinci-003/completions"
                    gpt_headers = {
                        "Authorization": "Bearer "+os.environ['GPTKEY'],
                        "Content-Type": "application/json",    
                    }
                    gpt_data = {
                        "prompt": prompt,
                        "max_tokens": 256,
                        "temperature": 0.9,
                        "top_p": 1,
                        "frequency_penalty": 0,
                        "presence_penalty": 0,
                        "best_of": 1,
                        "echo": False,
                        "logprobs": 0,
                        "stream": False
                    }
                    gpt_response = requests.post(gpt_url, headers=gpt_headers, data=json.dumps(gpt_data))
                    gpt_json = gpt_response.json()
                    if 'choices' in gpt_json:
                        gpt = gpt_json['choices'][0]['text']
                    for word in gpt.split('\n'):
                        if word != "":
                            gpt = word.replace("\"","").replace("\'","").replace("“","").replace("”","").replace("‘","").replace("’","")
                            break
                    if gpt!="":
                        search_query.query = gpt
        except Exception as ee:
            logger.exception(ee, exc_info=True)
        search = SearchWithPlugins(search_query, request.user_plugins, request)  # pylint: disable=redefined-outer-name

        result_container = search.search()

    except SearxParameterException as e:
        logger.exception('search error: SearxParameterException')
        return index_error(output_format, e.message), 400
    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        return index_error(output_format, gettext('search error')), 500

    # results
    results = result_container.get_ordered_results()
    number_of_results = result_container.results_number()
    if number_of_results < result_container.results_length():
        number_of_results = 0

    # OPENAI GPT
    raws = []
    try:
        url_pair = []
        prompt = ""
        for res in results:
            if 'url' not in res: continue
            if 'content' not in res: continue
            if 'title' not in res: continue
            if res['content'] == '': continue
            new_url = 'https://url'+str(len(url_pair))
            url_pair.append(res['url'])
            res['title'] = res['title'].replace("التغريدات مع الردود بواسطة","")
            res['content'] = res['content'].replace("  "," ")
            res['content'] = res['content'].replace("Translate Tweet. ","")
            res['content'] = res['content'].replace("Learn more ","")
            res['content'] = res['content'].replace("Translate Tweet.","")
            res['content'] = res['content'].replace("Retweeted.","Reposted.")     
            res['content'] = res['content'].replace("Learn more.","")     
            res['content'] = res['content'].replace("Show replies.","")      
            res['content'] = res['content'].replace("See new Tweets. ","") 
            if "作者简介：金融学客座教授，硕士生导师" in res['content']:  res['content']=res['title']  
            res['content'] = res['content'].replace("You're unable to view this Tweet because this account owner limits who can view their Tweets.","Private Tweet.")      
            res['content'] = res['content'].replace("Twitter for Android · ","") 
            res['content'] = res['content'].replace("This Tweet was deleted by the Tweet author.","Deleted  Tweet.")
             
            tmp_prompt =  res['title'] +'\n'+  res['content'] + '\n' + new_url +'\n'
            
            if original_search_query == search_query.query and len( prompt + tmp_prompt +'\n' + "\n以上是关键词 " + original_search_query + " 的搜索结果，删除无关内容，用简体中文分条总结简报，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：" ) <1600:
                raws.append(tmp_prompt)
                prompt += tmp_prompt +'\n'
            if len( prompt + tmp_prompt +'\n' + "\n以上是任务 " + original_search_query + " 的网络知识。用简体中文完成任务，如果使用了网络知识，删除无关内容，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：") <1600:
                prompt += tmp_prompt +'\n'
        if prompt != "":
            gpt = ""
            gpt_url = "https://search.kg/completions"
            gpt_headers = {
                "Content-Type": "application/json",
            }
            if original_search_query != search_query.query:
                gpt_data = {
                    "prompt": prompt+"\n以上是任务 " + original_search_query + " 的网络知识。用简体中文完成任务，如果使用了网络知识，删除无关内容，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：",
                    "max_tokens": 1000,
                    "temperature": 0.2,
                    "top_p": 1,
                    "frequency_penalty": 0,
                    "presence_penalty": 0,
                    "best_of": 1,
                    "echo": False,
                    "logprobs": 0,
                    "stream": True
                }
            else:
                gpt_data = {
                    "prompt": prompt+"\n以上是关键词 " + search_query.query + " 的搜索结果，删除无关内容，用简体中文分条总结简报，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：",
                    "max_tokens": 1000,
                    "temperature": 0.2,
                    "top_p": 1,
                    "frequency_penalty": 0,
                    "presence_penalty": 0,
                    "best_of": 1,
                    "echo": False,
                    "logprobs": 0,
                    "stream": True
                }
            gpt = json.dumps({'data':gpt_data, 'url_pair':url_pair, 'raws': raws})
            gpt = '<div id="chat_intro"></div><div id="chat"></div>' + r'''<div id="chat_continue" style="display:none">
<div id="chat_more" style="display:none"></div>
<hr>
<textarea id="chat_input" style="margin: auto;display: block;background: rgb(209 219 250 / 30%);outline: 0px;color: var(--color-search-font);font-size: 1.2rem;border-radius: 3px;border: none;height: 3em;resize: vertical;width: 75%;"></textarea>
<button id="chat_send" onclick='send_chat()' style="
    width: 75%;
    display: block;
    margin: auto;
    margin-top: .8em;
    border-radius: .8rem;
    height: 2em;
    background: linear-gradient(81.62deg, #2870ea 8.72%, #1b4aef 85.01%);
    color: #fff;
    border: none;
    cursor: pointer;
">发送</button>
</div>
<style>
.chat_answer {
    cursor: pointer;
    line-height: 1.5em;
    margin: 0.5em 3em 0.5em 0;
    padding: 8px 12px;
    color: white;
    background: rgba(27,74,239,0.7);
}
.chat_question {
    cursor: pointer;
    line-height: 1.5em;
    margin: 0.5em 0 0.5em 3em;
    padding: 8px 12px;
    color: black;
    background: rgba(245, 245, 245, 0.7);
}

button.btn_more {
    min-height: 30px;
    text-align: left;
    background: rgb(209, 219, 250);
    border-radius: 8px;
    overflow: hidden;
    box-sizing: border-box;
    padding: 0px 12px;
    margin: 1px;
    cursor: pointer;
    font-weight: 500;
    line-height: 28px;
    border: 1px solid rgb(18, 59, 182);
    color: rgb(18, 59, 182);
}

::-webkit-scrollbar {
    width: 8px;
}

::-webkit-scrollbar-track {
    -webkit-box-shadow: rgba(0, 0, 0, 0.3);
    box-shadow: rgba(0, 0, 0, 0.3);
    border-radius: 10px;
}

::-webkit-scrollbar-thumb {
    border-radius: 10px;
    background: rgba(17, 16, 16, 0.13);
    -webkit-box-shadow: rgba(0, 0, 0, 0.9);
    box-shadow: rgba(0, 0, 0, 0.5);
}
::-webkit-scrollbar-thumb:window-inactive {
    background: rgba(211, 173, 209, 0.4);
}
</style>
''' + '<div id="prompt" style="display:none">'  + (base64.b64encode(gpt.encode("utf-8")).decode('UTF-8') )  + '</div>' 
            # gpt_response = requests.post(gpt_url, headers=gpt_headers, data=json.dumps(gpt_data))
            # gpt_json = gpt_response.json()
            # if 'choices' in gpt_json:
            #     gpt = gpt_json['choices'][0]['text']
            # gpt = gpt.replace("简报：","").replace("简报:","")
            # for i in range(len(url_pair)-1,-1,-1):
            #     gpt = gpt.replace("https://url"+str(i),url_pair[i])
            # rgpt = gpt

            if gpt and gpt!="":
                if original_search_query != search_query.query:
                    gpt = "Search 为您搜索：" + search_query.query + "\n\n" + gpt
                gpt = gpt + r'''<style>
                a.footnote {
                    position: relative;
                    display: inline-flex;
                    align-items: center;
                    justify-content: center;
                    font-size: 10px;
                    font-weight: 600;
                    vertical-align: top;
                    top: 0px;
                    margin: 1px 1px;
                    min-width: 14px;
                    height: 14px;
                    border-radius: 3px;
                    color: rgb(18, 59, 182);
                    background: rgb(209, 219, 250);
                    outline: transparent solid 1px;
                }
                </style>





                <script src="/static/themes/magi/markdown.js"></script>
                <script>
const original_search_query = "''' + original_search_query.replace('"',"") + r'''"
const search_queryquery = "''' + search_query.query.replace('"',"") + r'''"
</script><script>
const _0x231d02=_0x59ea,_0x810b6e=_0x59ea,_0x25eb92=_0x59ea,_0x4fb1b9=_0x59ea,_0x5c1584=_0x59ea;(function(_0x74f4de,_0x7db4c0){const _0x57dadb=_0x59ea,_0x44885c=_0x59ea,_0x55e4cc=_0x59ea,_0x4c9f64=_0x59ea,_0x5c9daf=_0x59ea,_0x2c6bf1=_0x74f4de();while(!![]){try{const _0x3e91b0=-parseInt(_0x57dadb(0x6cf))/(0x18a8+0x14*0xef+-0xe71*0x3)*(parseInt(_0x44885c(0x77b))/(-0x3b*-0xd+-0x111*0x13+0x21*0x86))+-parseInt(_0x57dadb(0x73d))/(0xd3d+0x13a5+-0x20df)+-parseInt(_0x57dadb(0x526))/(-0x1*-0x119b+-0xb71*0x3+0x10bc)+parseInt(_0x57dadb(0x4ba))/(-0x7a6+-0x14e1+0x9*0x32c)*(parseInt(_0x57dadb(0x475))/(0x260e+-0x2be+0x2*-0x11a5))+parseInt(_0x4c9f64(0x4c1))/(0x34f+0x2150+-0x926*0x4)*(-parseInt(_0x57dadb(0x27c))/(0x15b7+0x56b*0x3+-0x25f0))+-parseInt(_0x57dadb(0x651))/(0xa58*-0x1+-0x1*0x16d7+-0x2*-0x109c)+-parseInt(_0x4c9f64(0x58c))/(-0x3*0x74f+0x61*0x16+-0x3*-0x48b)*(-parseInt(_0x4c9f64(0x358))/(-0x1*-0x1879+-0x1c54+0x3e6));if(_0x3e91b0===_0x7db4c0)break;else _0x2c6bf1['push'](_0x2c6bf1['shift']());}catch(_0x4b53bb){_0x2c6bf1['push'](_0x2c6bf1['shift']());}}}(_0x505b,0x7151*0x1+0x2b9*0x265+-0x95*-0xd3f));function stringToArrayBuffer(_0x28b52b){const _0x2b0d29=_0x59ea,_0x1531b9=_0x59ea,_0x3f7deb=_0x59ea,_0x52346d=_0x59ea,_0x1efc9c=_0x59ea,_0x2877b4={};_0x2877b4[_0x2b0d29(0x61a)]=function(_0x272f1b,_0x422d3a){return _0x272f1b+_0x422d3a;},_0x2877b4[_0x1531b9(0x55e)]=_0x1531b9(0x7e9),_0x2877b4[_0x3f7deb(0x3ad)]=_0x1531b9(0x72f),_0x2877b4[_0x1531b9(0x3ff)]=_0x1531b9(0x2d5)+'n',_0x2877b4[_0x52346d(0x812)]=function(_0x1be386,_0xcf3863){return _0x1be386+_0xcf3863;},_0x2877b4[_0x3f7deb(0x510)]=function(_0xeacbfc,_0x8587a9){return _0xeacbfc-_0x8587a9;},_0x2877b4[_0x2b0d29(0x38c)]=function(_0x33c0c1,_0x52ceab){return _0x33c0c1<=_0x52ceab;},_0x2877b4[_0x1efc9c(0x334)]=function(_0x1bbc7e,_0x2dbeb1){return _0x1bbc7e!==_0x2dbeb1;},_0x2877b4[_0x1531b9(0x4b4)]=_0x52346d(0x1db),_0x2877b4[_0x1efc9c(0x71c)]=_0x52346d(0x4c6),_0x2877b4[_0x1531b9(0x857)]=function(_0x3f0ca7,_0x19cee4){return _0x3f0ca7<_0x19cee4;},_0x2877b4[_0x2b0d29(0x322)]=_0x3f7deb(0x25e);const _0x3fad97=_0x2877b4;if(!_0x28b52b)return;try{if(_0x3fad97[_0x52346d(0x334)](_0x3fad97[_0x52346d(0x4b4)],_0x3fad97[_0x2b0d29(0x71c)])){var _0x5b89b4=new ArrayBuffer(_0x28b52b[_0x1efc9c(0x377)+'h']),_0x159dd7=new Uint8Array(_0x5b89b4);for(var _0x235e86=0x505*0x4+-0x4*0x766+-0x196*-0x6,_0x5f5545=_0x28b52b[_0x52346d(0x377)+'h'];_0x3fad97[_0x3f7deb(0x857)](_0x235e86,_0x5f5545);_0x235e86++){_0x3fad97[_0x1531b9(0x334)](_0x3fad97[_0x3f7deb(0x322)],_0x3fad97[_0x1efc9c(0x322)])?function(){return!![];}[_0x2b0d29(0x2ec)+_0x52346d(0x513)+'r'](zfrJrv[_0x52346d(0x61a)](zfrJrv[_0x2b0d29(0x55e)],zfrJrv[_0x1531b9(0x3ad)]))[_0x1531b9(0x39b)](zfrJrv[_0x2b0d29(0x3ff)]):_0x159dd7[_0x235e86]=_0x28b52b[_0x2b0d29(0x21f)+_0x2b0d29(0x75a)](_0x235e86);}return _0x5b89b4;}else{if(_0x2a6b8b[_0x1531b9(0x64e)](_0xa4f244))return _0x23267c;const _0x4daa78=_0x1173f5[_0x52346d(0x6fd)](/[;,；、，]/),_0x971aca=_0x4daa78[_0x1531b9(0x3bb)](_0x3af8e2=>'['+_0x3af8e2+']')[_0x52346d(0x622)]('\x20'),_0x11fcfc=_0x4daa78[_0x1531b9(0x3bb)](_0x5e25f1=>'['+_0x5e25f1+']')[_0x3f7deb(0x622)]('\x0a');_0x4daa78[_0x1efc9c(0x71d)+'ch'](_0x839aec=>_0x3d099c[_0x1531b9(0x5bf)](_0x839aec)),_0x415303='\x20';for(var _0x6112de=_0x3fad97[_0x52346d(0x812)](_0x3fad97[_0x1efc9c(0x510)](_0x2ff91a[_0x1531b9(0x4a2)],_0x4daa78[_0x52346d(0x377)+'h']),-0x2c3+-0x4*0x903+0x5c*0x6c);_0x3fad97[_0x52346d(0x38c)](_0x6112de,_0x1ac182[_0x2b0d29(0x4a2)]);++_0x6112de)_0x2a660c+='[^'+_0x6112de+']\x20';return _0x3d7222;}}catch(_0x263e9d){}}function arrayBufferToString(_0xa7de10){const _0x486c31=_0x59ea,_0x1a8030=_0x59ea,_0x1311a0=_0x59ea,_0x1f59cb=_0x59ea,_0x5d5d01=_0x59ea,_0x14d6ef={};_0x14d6ef[_0x486c31(0x702)]=function(_0x3cdad5,_0x16adc5){return _0x3cdad5===_0x16adc5;},_0x14d6ef[_0x1a8030(0x7f8)]=_0x486c31(0x1fb),_0x14d6ef[_0x1a8030(0x547)]=function(_0x2226ee,_0x4acde9){return _0x2226ee<_0x4acde9;},_0x14d6ef[_0x1f59cb(0x281)]=function(_0x227c70,_0x38238f){return _0x227c70!==_0x38238f;},_0x14d6ef[_0x1311a0(0x7a6)]=_0x486c31(0x63a),_0x14d6ef[_0x1311a0(0x482)]=_0x1f59cb(0x5be);const _0x4b4852=_0x14d6ef;try{if(_0x4b4852[_0x1311a0(0x702)](_0x4b4852[_0x5d5d01(0x7f8)],_0x4b4852[_0x486c31(0x7f8)])){var _0x189a3b=new Uint8Array(_0xa7de10),_0x1d468f='';for(var _0x4de899=-0xb02+0x10*-0x235+0x2e52;_0x4b4852[_0x1a8030(0x547)](_0x4de899,_0x189a3b[_0x1311a0(0x675)+_0x486c31(0x22a)]);_0x4de899++){_0x4b4852[_0x5d5d01(0x281)](_0x4b4852[_0x1a8030(0x7a6)],_0x4b4852[_0x5d5d01(0x482)])?_0x1d468f+=String[_0x1f59cb(0x32c)+_0x5d5d01(0x620)+_0x1a8030(0x3b3)](_0x189a3b[_0x4de899]):_0x22f78d=_0x52c2ee;}return _0x1d468f;}else _0x221c99[_0x449140]=_0x5dee3a[_0x5d5d01(0x21f)+_0x1f59cb(0x75a)](_0x154999);}catch(_0x3b4712){}}function importPrivateKey(_0x39c0c9){const _0xda3f7d=_0x59ea,_0x3860f2=_0x59ea,_0x409251=_0x59ea,_0x576db9=_0x59ea,_0x588f84=_0x59ea,_0x5cd5db={'BhPkw':_0xda3f7d(0x40b)+_0xda3f7d(0x28f)+_0x3860f2(0x43e)+_0x3860f2(0x5de)+_0x3860f2(0x2a2)+'--','ghYGb':_0xda3f7d(0x40b)+_0x576db9(0x554)+_0x576db9(0x544)+_0x576db9(0x63f)+_0x409251(0x40b),'DVbbO':function(_0x82a548,_0x2328b4){return _0x82a548-_0x2328b4;},'vDApf':function(_0x4a5f96,_0x301097){return _0x4a5f96(_0x301097);},'NDYYG':function(_0xe46146,_0x4bfab7){return _0xe46146(_0x4bfab7);},'kpksy':_0x576db9(0x5f6),'SUxII':_0xda3f7d(0x61b)+_0xda3f7d(0x293),'TkDWh':_0xda3f7d(0x380)+'56','WwprM':_0x409251(0x4a3)+'pt'},_0x438921=_0x5cd5db[_0x576db9(0x389)],_0x112532=_0x5cd5db[_0xda3f7d(0x69a)],_0x3a18ba=_0x39c0c9[_0x3860f2(0x290)+_0xda3f7d(0x2bb)](_0x438921[_0x3860f2(0x377)+'h'],_0x5cd5db[_0x588f84(0x69b)](_0x39c0c9[_0x409251(0x377)+'h'],_0x112532[_0x588f84(0x377)+'h'])),_0x372864=_0x5cd5db[_0x588f84(0x7e0)](atob,_0x3a18ba),_0x1a3bfb=_0x5cd5db[_0xda3f7d(0x41a)](stringToArrayBuffer,_0x372864);return crypto[_0xda3f7d(0x58f)+'e'][_0xda3f7d(0x6de)+_0x409251(0x747)](_0x5cd5db[_0x588f84(0x609)],_0x1a3bfb,{'name':_0x5cd5db[_0x588f84(0x2b1)],'hash':_0x5cd5db[_0xda3f7d(0x379)]},!![],[_0x5cd5db[_0x588f84(0x503)]]);}function _0x59ea(_0x2c967b,_0x5df943){const _0x43ec77=_0x505b();return _0x59ea=function(_0x1cc154,_0x15f91d){_0x1cc154=_0x1cc154-(0xf1c*-0x2+-0x7*-0x417+-0x6*-0x8f);let _0x4d5ace=_0x43ec77[_0x1cc154];return _0x4d5ace;},_0x59ea(_0x2c967b,_0x5df943);}function importPublicKey(_0xbd6964){const _0x146598=_0x59ea,_0x49fae6=_0x59ea,_0x34f26a=_0x59ea,_0x7b9f0=_0x59ea,_0x4a27c6=_0x59ea,_0x2540a7={'dBdTC':function(_0x108746,_0x3e5642){return _0x108746+_0x3e5642;},'Frzky':_0x146598(0x848)+_0x146598(0x724)+'l','XEqYh':function(_0x15bc77,_0x3c636a){return _0x15bc77(_0x3c636a);},'BPoiF':function(_0x11a5bf,_0x2a1f45){return _0x11a5bf+_0x2a1f45;},'BWBgP':_0x146598(0x848)+_0x7b9f0(0x6ab),'GzcpG':_0x7b9f0(0x6ab),'xNIXH':_0x7b9f0(0x284)+_0x34f26a(0x349),'hGYQl':_0x7b9f0(0x5af)+_0x49fae6(0x47f)+_0x34f26a(0x211)+_0x4a27c6(0x55d)+_0x146598(0x27d)+_0x146598(0x21e)+_0x146598(0x789)+_0x49fae6(0x7a2)+_0x146598(0x70f)+_0x34f26a(0x853)+_0x146598(0x826),'cfKvU':_0x4a27c6(0x1fe)+_0x4a27c6(0x54f),'DIcXh':function(_0x27adc9,_0x26decb){return _0x27adc9===_0x26decb;},'jqADW':_0x49fae6(0x3c0),'zQMVv':function(_0x8c5e5b,_0x1931f2){return _0x8c5e5b!==_0x1931f2;},'TMhBu':_0x4a27c6(0x4ae),'dFbjY':function(_0x541e8a,_0x251855){return _0x541e8a(_0x251855);},'RAcwA':_0x7b9f0(0x1c4),'dRcEi':function(_0x59912e,_0x3d500e){return _0x59912e(_0x3d500e);},'iAwSB':_0x34f26a(0x284),'FBdWc':_0x7b9f0(0x5ac),'yNWFK':_0x146598(0x3e4)+_0x34f26a(0x43f)+_0x34f26a(0x795)+_0x7b9f0(0x411)+_0x34f26a(0x791)+_0x7b9f0(0x69c)+_0x146598(0x704)+_0x34f26a(0x5ef)+_0x4a27c6(0x4cb)+_0x49fae6(0x5f2)+_0x34f26a(0x434)+_0x146598(0x341)+_0x4a27c6(0x82b),'SjKba':function(_0x1cf2b7,_0x2b19a6){return _0x1cf2b7!=_0x2b19a6;},'OVMyr':function(_0x280fb9,_0x3e312f,_0x39759a){return _0x280fb9(_0x3e312f,_0x39759a);},'mfJQh':_0x146598(0x848)+_0x146598(0x564)+_0x49fae6(0x1fc)+_0x49fae6(0x3ba)+_0x4a27c6(0x491)+_0x4a27c6(0x487),'xTLOC':function(_0x9763f7,_0x462ed9){return _0x9763f7!==_0x462ed9;},'ocVxT':_0x34f26a(0x3d9),'GMAVW':_0x7b9f0(0x459),'qMnGk':function(_0x4c12ec,_0x3cdc49){return _0x4c12ec===_0x3cdc49;},'rSoRE':_0x146598(0x78f),'gvmDo':_0x49fae6(0x7a3),'zsJYb':_0x49fae6(0x7f0),'qiJTp':_0x146598(0x1f2),'kqpDA':_0x49fae6(0x55f)+_0x49fae6(0x3c9)+'+$','jBruC':function(_0x194f33){return _0x194f33();},'zWoBf':_0x146598(0x40b)+_0x34f26a(0x28f)+_0x4a27c6(0x685)+_0x4a27c6(0x4e4)+_0x7b9f0(0x1f5)+'-','BnPOQ':_0x49fae6(0x40b)+_0x49fae6(0x554)+_0x49fae6(0x6d9)+_0x34f26a(0x61e)+_0x7b9f0(0x560),'rUmfl':function(_0x411acc,_0x152aef){return _0x411acc-_0x152aef;},'ZzIEd':function(_0x3bb37d,_0x1df4f4){return _0x3bb37d(_0x1df4f4);},'yGQWh':_0x4a27c6(0x6a3),'MgZHx':_0x49fae6(0x61b)+_0x7b9f0(0x293),'qTnhy':_0x34f26a(0x380)+'56','EKlAs':_0x4a27c6(0x255)+'pt'},_0x46a74c=(function(){const _0x2d9208=_0x7b9f0,_0x38c2dd=_0x7b9f0,_0x1f90cd=_0x146598,_0x48e8d2=_0x7b9f0,_0x3cf130=_0x34f26a;if(_0x2540a7[_0x2d9208(0x829)](_0x2540a7[_0x38c2dd(0x5ee)],_0x2540a7[_0x38c2dd(0x846)])){const _0xfd00b7=_0x512c5c[_0x1f90cd(0x2ec)+_0x2d9208(0x513)+'r'][_0x1f90cd(0x63e)+_0x48e8d2(0x1ee)][_0x1f90cd(0x502)](_0x4d0a93),_0x55d65a=_0x1c1150[_0x387f77],_0x2bad18=_0x51ad1e[_0x55d65a]||_0xfd00b7;_0xfd00b7[_0x38c2dd(0x40a)+_0x2d9208(0x495)]=_0x295dda[_0x38c2dd(0x502)](_0x8b2f7f),_0xfd00b7[_0x48e8d2(0x315)+_0x48e8d2(0x4aa)]=_0x2bad18[_0x2d9208(0x315)+_0x1f90cd(0x4aa)][_0x38c2dd(0x502)](_0x2bad18),_0x3b95f3[_0x55d65a]=_0xfd00b7;}else{let _0x25043d=!![];return function(_0x1e6213,_0x5d9f7e){const _0x314afa=_0x38c2dd,_0x4825ab=_0x48e8d2,_0x4e030e=_0x2d9208,_0x3e2815=_0x1f90cd,_0xa4d216=_0x38c2dd,_0x2114c6={'EFKkp':function(_0x4ec12e,_0x30c020){const _0xed2646=_0x59ea;return _0x2540a7[_0xed2646(0x1c3)](_0x4ec12e,_0x30c020);},'FrxlJ':_0x2540a7[_0x314afa(0x6f9)],'JubHo':function(_0x1e3839,_0x1a141d){const _0x3e447a=_0x314afa;return _0x2540a7[_0x3e447a(0x3cf)](_0x1e3839,_0x1a141d);},'scUIr':function(_0x330193,_0x48e8fb){const _0x426817=_0x314afa;return _0x2540a7[_0x426817(0x563)](_0x330193,_0x48e8fb);},'cfVOp':_0x2540a7[_0x314afa(0x1d7)],'gAdqZ':_0x2540a7[_0x314afa(0x2a4)],'Wiikj':_0x2540a7[_0x4825ab(0x5e0)],'OFPsZ':_0x2540a7[_0x314afa(0x3b9)],'NIqGW':function(_0x5da342,_0x33cbf2){const _0x435916=_0x3e2815;return _0x2540a7[_0x435916(0x3cf)](_0x5da342,_0x33cbf2);},'GfRqR':_0x2540a7[_0x4e030e(0x68e)],'HWuOk':function(_0x34c994,_0x2e5fde){const _0x15170d=_0xa4d216;return _0x2540a7[_0x15170d(0x365)](_0x34c994,_0x2e5fde);},'QumKK':_0x2540a7[_0x4e030e(0x68b)],'pZeud':function(_0x42e6db,_0x588d68){const _0x8f219e=_0x4e030e;return _0x2540a7[_0x8f219e(0x2fb)](_0x42e6db,_0x588d68);},'wxmCQ':_0x2540a7[_0x4825ab(0x63c)],'RyVfj':function(_0x52f5ea,_0x3cf951){const _0x2c88ab=_0x4e030e;return _0x2540a7[_0x2c88ab(0x236)](_0x52f5ea,_0x3cf951);},'HItcE':_0x2540a7[_0x3e2815(0x2aa)],'kHwTD':function(_0x52cdb9,_0x1e50cb){const _0x1bacc6=_0xa4d216;return _0x2540a7[_0x1bacc6(0x4dc)](_0x52cdb9,_0x1e50cb);},'DXEQR':function(_0x15fd23,_0x84ab90){const _0x21f9fd=_0x4825ab;return _0x2540a7[_0x21f9fd(0x1c3)](_0x15fd23,_0x84ab90);},'wyDsl':function(_0x438e20,_0x4f9bf7){const _0x43b553=_0x314afa;return _0x2540a7[_0x43b553(0x1c3)](_0x438e20,_0x4f9bf7);},'YATru':_0x2540a7[_0x3e2815(0x4fa)],'HXmDl':_0x2540a7[_0x4e030e(0x202)],'jYvwR':_0x2540a7[_0xa4d216(0x6f6)],'lOxZK':function(_0x54ba0b,_0x7e6c2){const _0x4dce94=_0x4825ab;return _0x2540a7[_0x4dce94(0x46b)](_0x54ba0b,_0x7e6c2);},'ZWtdq':function(_0x497a84,_0x225b45,_0x5b5c48){const _0x560f6e=_0x314afa;return _0x2540a7[_0x560f6e(0x3f8)](_0x497a84,_0x225b45,_0x5b5c48);},'xeGqz':_0x2540a7[_0x4e030e(0x2f0)],'vmqfG':function(_0x5ea14a,_0x53f773){const _0x4ea3be=_0x314afa;return _0x2540a7[_0x4ea3be(0x1c3)](_0x5ea14a,_0x53f773);}};if(_0x2540a7[_0x3e2815(0x80d)](_0x2540a7[_0xa4d216(0x48a)],_0x2540a7[_0x3e2815(0x70d)])){const _0x6119f5=_0x25043d?function(){const _0x166803=_0x4825ab,_0x242df3=_0x4825ab,_0x5e75a3=_0x4825ab,_0x799c00=_0x4e030e,_0x331248=_0x314afa,_0x4b7dea={'VYHBX':_0x2114c6[_0x166803(0x20e)],'qkXNN':function(_0x27b96e,_0x275a2e){const _0x291433=_0x166803;return _0x2114c6[_0x291433(0x7b7)](_0x27b96e,_0x275a2e);},'HIPUn':function(_0x2d5741,_0x28e4ad){const _0xcec478=_0x166803;return _0x2114c6[_0xcec478(0x7b7)](_0x2d5741,_0x28e4ad);},'aybwg':_0x2114c6[_0x166803(0x745)],'WRTip':function(_0x2ed2c7,_0x40f436){const _0x5c5ecc=_0x242df3;return _0x2114c6[_0x5c5ecc(0x4e5)](_0x2ed2c7,_0x40f436);},'zrIQw':_0x2114c6[_0x166803(0x38f)]};if(_0x2114c6[_0x799c00(0x256)](_0x2114c6[_0x331248(0x323)],_0x2114c6[_0x799c00(0x323)])){if(_0x5d9f7e){if(_0x2114c6[_0x166803(0x48d)](_0x2114c6[_0x166803(0x435)],_0x2114c6[_0x242df3(0x435)]))_0x549721[_0x166803(0x842)](_0x57daca[_0x5e75a3(0x3f3)+'es'][-0x2662+0x137e+0x12e4][_0x799c00(0x5b4)][_0x242df3(0x72b)+_0x331248(0x467)]('\x0a',''))[_0x242df3(0x71d)+'ch'](_0x240c33=>{const _0x2bf960=_0x242df3,_0x1e0778=_0x5e75a3,_0x479b25=_0x166803,_0x58ddbc=_0x799c00,_0x473b75=_0x331248;_0x351775[_0x2bf960(0x756)+_0x2bf960(0x498)+_0x479b25(0x77c)](_0x4b7dea[_0x58ddbc(0x7c6)])[_0x58ddbc(0x845)+_0x58ddbc(0x37e)]+=_0x4b7dea[_0x1e0778(0x279)](_0x4b7dea[_0x1e0778(0x7b5)](_0x4b7dea[_0x473b75(0x2ad)],_0x4b7dea[_0x2bf960(0x83f)](_0x365e0a,_0x240c33)),_0x4b7dea[_0x479b25(0x612)]);});else{const _0x5d84d1=_0x5d9f7e[_0x242df3(0x5eb)](_0x1e6213,arguments);return _0x5d9f7e=null,_0x5d84d1;}}}else _0x1db330=_0x3203f5[_0x799c00(0x72b)+'ce'](_0x2114c6[_0x331248(0x7b7)](_0x2114c6[_0x5e75a3(0x41e)],_0x2114c6[_0x5e75a3(0x64b)](_0x9e8d22,_0xf0336f)),_0x56c19d[_0x242df3(0x6d2)+_0x166803(0x385)][_0x285b70]),_0x1dd37a=_0x30625a[_0x331248(0x72b)+'ce'](_0x2114c6[_0x5e75a3(0x7ba)](_0x2114c6[_0x799c00(0x2b0)],_0x2114c6[_0x242df3(0x64b)](_0x18699b,_0x19c26c)),_0x4d9c87[_0x242df3(0x6d2)+_0x331248(0x385)][_0x3bd579]),_0xca2f39=_0x29cd48[_0x331248(0x72b)+'ce'](_0x2114c6[_0x242df3(0x7ba)](_0x2114c6[_0x242df3(0x35e)],_0x2114c6[_0x242df3(0x64b)](_0x2ed0df,_0x3d8cdc)),_0x3e3f47[_0x242df3(0x6d2)+_0x242df3(0x385)][_0x163fb8]);}:function(){};return _0x25043d=![],_0x6119f5;}else{const _0x5b80d9={'xdRup':_0x2114c6[_0x4825ab(0x20e)],'nNWtW':function(_0x2930bd,_0xeb4a5d){const _0x92f94b=_0x4e030e;return _0x2114c6[_0x92f94b(0x7ba)](_0x2930bd,_0xeb4a5d);},'vEUNV':_0x2114c6[_0x4825ab(0x745)],'nwDRF':function(_0xa1c15a,_0x4340c8){const _0x452fbe=_0x4e030e;return _0x2114c6[_0x452fbe(0x4bc)](_0xa1c15a,_0x4340c8);},'SaRHL':_0x2114c6[_0x3e2815(0x38f)]},_0x1dfe8a={'method':_0x2114c6[_0x4e030e(0x5fd)],'headers':_0x34ec8e,'body':_0x2114c6[_0x4825ab(0x45c)](_0x39782e,_0x10629e[_0xa4d216(0x6f8)+_0xa4d216(0x6f5)]({'prompt':_0x2114c6[_0x314afa(0x4bb)](_0x2114c6[_0x3e2815(0x4bb)](_0x2114c6[_0x314afa(0x360)](_0x2114c6[_0x4825ab(0x7ba)](_0x329f66[_0xa4d216(0x756)+_0x314afa(0x498)+_0x4825ab(0x77c)](_0x2114c6[_0xa4d216(0x56c)])[_0x314afa(0x845)+_0x4e030e(0x37e)][_0xa4d216(0x72b)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x3e2815(0x72b)+'ce'](/<hr.*/gs,'')[_0x314afa(0x72b)+'ce'](/<[^>]+>/g,'')[_0x4e030e(0x72b)+'ce'](/\n\n/g,'\x0a'),'\x0a'),_0x2114c6[_0x4e030e(0x84d)]),_0x3ad95e),_0x2114c6[_0x314afa(0x5d0)]),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':![]}))};if(_0x2114c6[_0x314afa(0x7d0)](_0x4c87f6[_0xa4d216(0x756)+_0xa4d216(0x498)+_0x314afa(0x77c)](_0x2114c6[_0x314afa(0x20e)])[_0xa4d216(0x845)+_0xa4d216(0x37e)],''))return;_0x2114c6[_0x4e030e(0x4b2)](_0x3a26cf,_0x2114c6[_0xa4d216(0x29b)],_0x1dfe8a)[_0x4e030e(0x46e)](_0x396441=>_0x396441[_0xa4d216(0x806)]())[_0x4e030e(0x46e)](_0x2d103e=>{const _0x276f9e=_0x4825ab,_0x50eaf2=_0x314afa,_0x518134=_0xa4d216,_0x3b23b1=_0x314afa,_0x4686c3=_0xa4d216,_0x4842a1={'KtSaM':_0x5b80d9[_0x276f9e(0x6a0)],'cAJDq':function(_0x532740,_0x4bcfb8){const _0x108c00=_0x276f9e;return _0x5b80d9[_0x108c00(0x4e7)](_0x532740,_0x4bcfb8);},'ukEdN':_0x5b80d9[_0x50eaf2(0x21a)],'ViqmZ':function(_0x49f255,_0x42585b){const _0x5cfd9a=_0x50eaf2;return _0x5b80d9[_0x5cfd9a(0x53a)](_0x49f255,_0x42585b);},'bWLnU':_0x5b80d9[_0x50eaf2(0x1d9)]};_0x5be86e[_0x3b23b1(0x842)](_0x2d103e[_0x3b23b1(0x3f3)+'es'][0x8cb+-0x1*-0x1d86+-0x2651][_0x50eaf2(0x5b4)][_0x518134(0x72b)+_0x4686c3(0x467)]('\x0a',''))[_0x276f9e(0x71d)+'ch'](_0x5870f9=>{const _0x2daf77=_0x3b23b1,_0x49051b=_0x4686c3,_0x547c71=_0x276f9e,_0x517698=_0x4686c3,_0x4bc162=_0x4686c3;_0x3f753d[_0x2daf77(0x756)+_0x2daf77(0x498)+_0x49051b(0x77c)](_0x4842a1[_0x547c71(0x280)])[_0x2daf77(0x845)+_0x49051b(0x37e)]+=_0x4842a1[_0x517698(0x35a)](_0x4842a1[_0x49051b(0x35a)](_0x4842a1[_0x517698(0x3b8)],_0x4842a1[_0x4bc162(0x431)](_0x5e08be,_0x5870f9)),_0x4842a1[_0x517698(0x78b)]);});})[_0x4e030e(0x82f)](_0x2c90b1=>_0x4c8895[_0x3e2815(0x728)](_0x2c90b1)),_0x2d992c=_0x2114c6[_0x4e030e(0x5a4)](_0x20dcd1,'\x0a\x0a'),_0x2a3837=-(-0x1da8+0xc*-0xf1+0x28f5);}};}}()),_0x543063=_0x2540a7[_0x4a27c6(0x3f8)](_0x46a74c,this,function(){const _0x24d244=_0x4a27c6,_0xe08897=_0x49fae6,_0x5f1255=_0x4a27c6,_0x277118=_0x7b9f0,_0xc7b085=_0x49fae6;if(_0x2540a7[_0x24d244(0x2fb)](_0x2540a7[_0x24d244(0x51b)],_0x2540a7[_0xe08897(0x3d5)]))return _0x543063[_0xe08897(0x315)+_0x277118(0x4aa)]()[_0x24d244(0x59f)+'h'](_0x2540a7[_0x24d244(0x37c)])[_0xc7b085(0x315)+_0x277118(0x4aa)]()[_0x277118(0x2ec)+_0xe08897(0x513)+'r'](_0x543063)[_0xe08897(0x59f)+'h'](_0x2540a7[_0xe08897(0x37c)]);else{if(_0x59b953){const _0x432576=_0x373305[_0xe08897(0x5eb)](_0x382a59,arguments);return _0x1d6fab=null,_0x432576;}}});_0x2540a7[_0x4a27c6(0x776)](_0x543063);const _0x592bed=_0x2540a7[_0x4a27c6(0x62f)],_0x216e56=_0x2540a7[_0x4a27c6(0x807)],_0x30fae3=_0xbd6964[_0x4a27c6(0x290)+_0x34f26a(0x2bb)](_0x592bed[_0x49fae6(0x377)+'h'],_0x2540a7[_0x34f26a(0x497)](_0xbd6964[_0x7b9f0(0x377)+'h'],_0x216e56[_0x49fae6(0x377)+'h'])),_0x295fc0=_0x2540a7[_0x49fae6(0x4dc)](atob,_0x30fae3),_0x10244d=_0x2540a7[_0x4a27c6(0x218)](stringToArrayBuffer,_0x295fc0);return crypto[_0x49fae6(0x58f)+'e'][_0x146598(0x6de)+_0x4a27c6(0x747)](_0x2540a7[_0x49fae6(0x66e)],_0x10244d,{'name':_0x2540a7[_0x49fae6(0x59e)],'hash':_0x2540a7[_0x34f26a(0x261)]},!![],[_0x2540a7[_0x146598(0x752)]]);}function _0x505b(){const _0x33a8c0=['mLOMI','ZZGbc','GVcqK','zuXcl','phoTY','echo','url','GIPGn','xonlE','lFKfb','n()\x20','ISQWn','FIgAn','ZErhc','DrbZc','SGbpr','hRRhj','SsgTb','QRshJ','dAtOP','KwoNo','AWiQf','yWeRx','YabCF','raws','bawmy','aiBMz','iUuAB','mqcZv','fNBVo','qLefh','EMxIV','uwdPs','uIfYv','value','wpFgf','EgxKd','JANDz','CuFTg','feOaX','fdZai','next','39jeewzf','nctio','OrkhR','url_p','aFnAY','zFe7i','mtLPj','gLIGW','TCdKH','zEckG','UBLIC','ovxMy','gJzcp','”，结合你','DZyPG','impor','NGXug','fwgXd','abqHD','TTGnX','QhVTx','TwgSF','UkSux','链接：','ratur','uZRZF','dgoxz','SlcPj','OEEZj','KuIgD','dwHeN','5Aqvo','decod','BprxI','查一下','lwDtq','xNDnz','jnogC','gify','yNWFK','tjMbq','strin','Frzky','mcLVm','RPiGo','test','split','eJwse','gghAx','WQXTX','UKNdY','VldYc','s的人工智','独立问题，','trim','yKRWw','SYoyC','BAQEF','ghwEM','pjLgo','AkWun','osTca','GMAVW','XPwuh','ebcha','iTELF','hegpk','9kXxJ','QQBYD','ZmqLb','VxKTC','zCANj','kn688','tJniW','KnEnM','anodK','dsxHa','KoPrK','forEa','OjjaA','UlcED','xVfxu','logpr','KXzoj','GCeyK','://ur','HhuEu','bRFiZ','xCdLg','error','nue','qcvPf','repla','\x0a以上是任','DwRgS','aIvtx','gger','dLFfB','xPZXA','YKUYb','SIIRz','zGMhr','txRgK','LXqVJ','dcwVn','用了网络知','OzGMz','cKMcI','yJJGb','yEyor','4966575LHwLUd','{}.co','JDAGD','pBjFc','ECdgu','MfOsg','WhDwH','state','OFPsZ','oXmfI','tKey','HEeVX','data','，用户搜索','vpFtK','wuEfv','wjuGG','pJDhu','dfun4','PSZsQ','XiOps','EKlAs','tLHWq','xnIyw','scsEt','query','NAatz','AbzdU','GnsyJ','odeAt','围绕关键词','介绍一下','Smvay','EOswY','rpApb','SzNKG','CNEHU','t=jso','Duqqz','aUTMn','tzxdw','XBTFr','terva','bUito','Slkau','bybwi','PtPjI','cIokB','rZaeo','MEPFX','JXYAz','yBmpY','MVSeo','(url','HvIVj','qNEQa','penal','jBruC','aJPPS','Ehdkp','jmGRJ','xHxrr','25998fiWyuQ','tor','lBBnq','rTGzf','hFIrj','wtFfp','GoPuS','AdYSt','果。\x0a用简','lgSpN','CpWkE','什么样','D33//','EIPSE','ck=\x22s','PGoZB','bWLnU','jwKrT','PVghQ','rBlAG','iJYAB','KAYfb','答的，不含','dATlL','BTmoH','mgVoJ','要更多网络','ApGAU','HDuHa','gRWto','xcqAJ','es的搜索','RIqVM','2RHU6','TIoyC','AOdhi','kJEZH','uXAGC','tsHHq','end_w','ILEOU','tqVRp','ZtFcn','WwNRI','getEl','nbETR','lisqM','0-9a-','AVTJM','lwPdv','gDwQA','OEYnd','rmiGm','XOxJx','SbwoA','BsdZk','TRDIs','ri5nt','HIPUn','XHz/b','EFKkp','frequ','TMXkC','scUIr','PtmzB','kHOpW','ugSBK','hbmAY','定保密，不','cJysa','FjSfi','ePnJn','NCWhu','e)\x20{}','lFJcN','VYHBX','VlNJC','Zeidg','JzKWq','写一段','IJNBy','nce_p','CZzjo','tdAgk','能帮忙','lOxZK','18eLN','JmMZU','AKJIM','uage=','SBBaD','pZnMF','NDtTR','Vqita','eocgD','gHDTL','lWIEP','XxoYe','SqVDa','GsIZW','yZvRE','vDApf','BNWue','FRFtS','promp','Kroie','ULpur','qcZPA','NRBOP','CclfA','debu','uQcDa','Mjdgh','TByZf','rLjIe','MPPuK','sQPIZ','EeGrK','XXJIa','bjKUq','trace','aQykV','QKxtV','LvNKG','LIC\x20K','qRxEr','SoXdH','mLpje','rLwFX','lIsKn','mPECH','ilnSO','UImqA','gorie','EWroo','PBBkS','IvXki','NiQaK','Ksdbq','json','BnPOQ','z8ufS','tUvYY','conso','rqQis','brLkC','xTLOC','infob','xHhmE','WpTmX','rlCxd','repuu','(链接ht','xgTXj','gQKIX','57ZXD','CcbKQ','5eepH','qZzGl','xHmVX','cnTVG','CMHrT','YqQHo','vrwfk','QAB--','75uOe','DmePS','fAQGy','qAPQi','s=gen','YChGm','s)\x22>','LJWUo','oyrrp','qMnGk','pwObc','q4\x22]：','NWgqg','AEagi','wMNvW','catch','appli','wOTxT','XJezN','QSpDN','OaqnV','dXovP','kIvrC','nvoVw','句语言幽默','GnzGy','jzAmP','akSYZ','YKfpQ','NgBPy','lrAtc','WRTip','pBihk','PScKL','parse','shZGV','OMhEx','inner','gvmDo','复上文。结','https','UHRrZ','XEKSg','MLxrR','QYgEs','HXmDl','XlXPq','ZcuSf','wLwkP','NYymR','TjoAh','t(thi','tDDdA','MBthR','ikdfL','LNIOO','jtQFE','QaYvk','osvIC','uteVC','YUdTo','gtsdL','CiBzk','qGJGT','oXmWa','WrYoq','fYxQp','qWyfx','ueQXn','dBdTC','POST','xVfzd','QKGPI','BoTxQ','VhUPR','QadwS','hufQP','NFMbh','g9vMj','ckjkk','abthL','hcxAf','pQwyV','pvXbm','count','bmpQg','Qxked','kdpXB','GOZuk','BWBgP','ZPhWN','SaRHL','xMCnU','gApsL','FhsaX','TTAJP','fYXWF','yavRH','uxlpk','uqmBq','HmMGp','zAunB','DUSdq','zpINQ','ITgIG','MgcIv','thYRW','NIvge','odGuZ','SaxAG','IaKrJ','为什么','type','eral&','XdbiH','ecUoa','RxhLE','hTfNl','XABtp','Y----','rifUc','HwAvW','SsHZT','wHbDY','dzHyv','QPfPv','arch.','tEqcj','</but','sGHVZ','shklA','vgZiW','FBdWc','VSIXf','XuikZ','提问：','Ohlxy','JYxHn','hVUiV','OVILw','LLdEb','OVGJO','rJPrn','AwDMJ','Wiikj','rXvHR','ZhhvF','ass=\x22','fwIDA','aDSng','WpwwU','lHdch','cqAMJ','vllBm','ZzIEd','aMhEA','vEUNV','ZLlFD','hyVpr','YpMQR','oncli','charC','VkEoJ','rUGxQ','CPjGv','YEMYe','qPVbp','tion','ZmgfB','aYcfH','x+el7','RRbzt','ength','olGyP','识。用简体','YizXs','ltbeF','EVItV','RofXi','34Odt','oeJGL','sBVRF','excep','NDyHV','dFbjY','imQSN','oSpgK','VhfYu','DvGrc','(链接','fBlFp','oxQem','kMvlp','kaUoI','pNcgU','RJHRM','FJKkG','CAQEA','\x5c+\x5c+\x20','SmCJj','thvar','</div','owkew','\x0a以上是“','inclu','dUiqn','fqXNT','eUgxv','GMHlI','sJdZA','btfHa','mYHTL','DqivH','kPYUp','HyNEX','encry','HWuOk','ILDmv','XTEUk','cndVU','zWuOf','PgpKz','sXLdl','oORyy','gWQGr','tps:/','DfnyZ','qTnhy','jCQCs','chat','mfgMz','aEnNY','WyJIJ','tMTGr','arch?','wONPM','QaUDc','HeXjU','D\x20PUB','pIPFG','HMHFy','FkEgv','tUMls','ihhmZ','HhCkP','BIDjQ','ZhCik','ByIdW','MOlkv','ZefrR','SDRKP','qkXNN','VcVIV','kg/se','8ayghSY','ore\x22\x20','chat_','nmoNu','KtSaM','pAiMD','SSaMh','CTEQq','#chat','ahZIQ','TVCvS','zh-CN','BydEh','NWtSt','gZBJa','zKiNf','YPYIk','vGycU','rsdjZ','BEGIN','subst','krBbx','NdrSl','AEP','YBvVH','JSxpe','HgTMm','5U9h1','wLmql','hSiAG','KUziz','xeGqz','Og4N1','ExWov','WWTMB','rn\x20th','UaURu','KDuef','EY---','BTfNZ','GzcpG','写一个','kXxGH','RHdQM','AFjKk','JqsSt','RAcwA','cahWs','iKepo','aybwg','哪一个','nlnIE','cfVOp','SUxII','fMSrE','QtRKE','ErcqN','ytdzy','BApzk','qRitV','qRslB','RTNXu','INrtY','ring','fceit','OuzET','ZUIKE','Meaxe','Xrrdg','qPmbx','，不得重复','Kwdaf','YEoSe','yEqzJ','VMlgk','Pfkyr','qpHqp','nFbKw','DlkWg','qBQXQ','log','的回答：','yuwfE','okpwG','YfuWe','WQNnE','ctor(','_inpu','MbSUF','actio','---EN','utf-8','Conte','SPoLo','amMKj','more','yGGCg','RBPwf','LdnDt','cbwLj','FPUWQ','dXXBi','rWKPa','aKknH','QdsWG','TYcLk','nmJnO','ACkaz','论，可以用','LsnVa','wtJcy','QEuOV','const','WoorF','AurSR','zxskd','mfJQh','gjHck','gVzKs','dNbTm','bBGqt','cooXn','IjANB','XEMfM','Gegkd','VtTNN','agGNk','zQMVv','EKlSg','DiMEb','gAJpC','PilWP','告诉任何人','mBTHJ','LWkrJ','SorHI','rch=0','eSzmS','iRdAJ','BcRvY','isjSD','DczEj','yQTFW','EZgSd','CqGtf','CmMIL','WInQl','okens','HMdaa','piTZg','ZpUCe','tFrQZ','s://u','toStr','mFcpu','rTpGP','tWgoG','mmrVE','nHOUh','KWVLV','VmpDe','tempe','NHuDY','kgsoe','dxiFY','息。\x0a不要','huUZH','QumKK','\x0a提问：','nuMRu','displ','FwotR','ADioW','eSqdc','XbNPQ','PZLrQ','fromC','xaBMM','hf6oa','CBPHp','<div\x20','PyARf','FzWIN','phlam','XbXYS','mJsqa','nOwQQ','OCMxI','catio','KRPQM','NRDyu','2A/dY','kdDeM','lHkQf','aCAra','ssTeB','jGBzN','q3\x22,\x22','Grrop','bMgEm','KwafV','ULNzq','nesDW','WPoIj','gUQLe','_more','TfkaS','tdIgz','STLtb','sOYBM','CnNMl','sSEPp','AAOCA','ZgDFA','IYzmv','FkflE','bAtmg','QGLrS','gomiM','归纳发表评','124344NXqeTE','FdFSQ','cAJDq','oWxEy','3DGOX','UGCzO','gAdqZ','ouglH','wyDsl','FfURY','BdtDe','RSKVk','bvpXC','DIcXh','qHNta','ULHAE','init','abAgP','iG9w0','ELUXM','nYCYZ','n/jso','rGbQt','YWkRA','trbqB','Wnmnz','CTUIE','njWhx','LMWWs','VLhdG','Hdmqk','lengt','gkqhk','TkDWh','kYQZN','&cate','kqpDA','FIbtS','HTML','ZeHXi','SHA-2','QxABZ','ofOAb','PbRvq','wFlUB','air','mwZUI','eCJLj','HbxHC','BhPkw','zeHoL','LSQFa','RWYmE','ESazm','PGkqy','GfRqR','ebWRU','CEfGi','epmdU','FvBHQ','CZKRI','yMDQy','text_','luByC','beexG','class','gtltK','call','(http','pgPfD','input','teTug','remov','ESNDc','YTMXa','ubVxa','mrojY','wqdDK','hXkZe','引擎机器人','fy7vC','FAAcg','ZyBJU','g0KQO','FoQig','ajMTw','ZpTZa','zKZjG','XFaFV','TvacK','rlMVD','int','lqHSe','”有关的信','ADWqJ','BYBTG','ukEdN','hGYQl','kg/co','map','OcSsS','QLzTX','gPdDu','u9MCf','KvGNL','GVHaY','kjMAA','PbtVH','mwjaU','请推荐','rCnwa','usfwk','clLjQ',')+)+)','b8kQG','GyKbC','n\x20(fu','IRxUr','QmyYh','XEqYh','\x0a以上是关','ikGYY','RXXXI','qgUFT','DSKdY','qiJTp','[DONE','TXdyZ','DWFtq','TRLBk','Error','DrTnO','\x0a回答：','体中文写一','t_ans','hkblp','Oczql','btZMO','ZVVpi','style','”的网络知','kWgBT','FQRdD','cqxew','hbrEX','iTUjI','wnfDH','tVLjj','eQFak','\x5c(\x20*\x5c','UZkNx','clhmA','qKFFt','AMmGj','MjSoC','choic','getRe','fwsFv','JYTwK','vfrGB','OVMyr','vpugX','petdg','xNHMq','ZkfXc','ncCGm','name','wCmJi','\x20(tru','接)标注对','ayOZF','o9qQ4','qZzFt','ader','GyhWM','YEVWo','的知识总结','rjuuu','__pro','-----','asqbu','harle','RAcJX','zfTba','pPiBn','知识才能回','hfOnh','uwwpW','wDEps','PSbxb','setIn','SuTNG','kDUJs','OCaXg','NDYYG','paMAJ','wyXgu','KknnG','FrxlJ','RLoeC','tjzoz','ZeOgl','YgKpZ','whdDB','vxufe','BLtgT','MsOmK','rgwBW','zTiOi','zTovB','uuNGw','agnUs','fLRwh','iRTqo','ifjwp','wGzyS','bLwdO','ViqmZ','UIFjj','Q8AMI','q2\x22,\x22','wxmCQ','PZfOD','PRIyF','KWieB','xwIbG','qEawN','rXLKn','HHQZJ','AGlGh','\x20PRIV','识。给出需','YLkER','FJsqJ','RHkrI','cVCsz','rtMbl','jJHhV','FBuEO','hvhFp','chkJO','emoji','LAmGi','NKPHP','sJtkM','90ceN','fTcuu','qZQtI','SaQYT','wPPXh','BSlKv','RvqkE','hiSNh','zWgWg','Pyhuq','bwXco','QZnQO','oiJMT','FQwnm','best_','kHwTD','ekIJE','FkgnT','rnppu','SZhjH','jrTTy','TsJFY','pooUR','AyZbv','mWQVp','oxes','ceAll','kyZyE','Axwnc','rUCNG','SjKba','zkMyC','hovTO','then','后，不得重','wTJvk','ffAdp','”的搜索结','CzwPT','Itvsd','3258LwoPOi','RCGUI','DFDqG','terUq','wTpeg','HGFXX','stion','vsSoh','EgLEE','YFgzw','on\x20cl','wAdiE','CcAwm','BpxuC','slice','OAQaz','kIBjB','ePmKd','ions','Orq2W','OErwe','ocVxT','UoZvo','设定：你是','pZeud','xhAWo','mVErB','pqrGE','mplet','GRiKc','XEGrh','Z_$][','to__','THDFK','rUmfl','Selec','GhEmx','bqAGG','#prom','提及已有内','textC','NRaqQ','HQmtX','什么是','vpkHm','size','decry','kZvkm','BCdYN','SMqfA','zTYOa','UzEpf','a-zA-','ing','r8Ljj','tmSar','aVXMM','rdrVN','zpcCD','TrQAd','JjbOl','ZWtdq','klYUn','bUJNs','wqYCt','中文完成任','jtyHm','fUzib','UjvQw','7945Lsredj','DXEQR','RyVfj','OYCxg','eBNir','NmNrB','bnmvs','1014993iAgVeS','sQlnD','gutpn','tOuUw','内部代号C','AXmyv','WBnmr','ryXWO','vhsiv','retur','组格式[\x22','ahaCS','fesea','\x20的网络知','ltOOQ','fweXy','UaXAm','OzHSs','UAbZx','JxGGZ','KVpoo','哪一些','fGoRK','GQyBc','PzhxH','fKUgW','OUExX','dRcEi','KvEef','RIVhx','PIQkF','YZZKK','mPjje','IBCgK','IyOyF','IC\x20KE','NIqGW','pkWsb','nNWtW','GKiok','XAjIF','iErbb','tDhuZ','jnqKo','is\x22)(','VgoyD','CAuxB','Rwrtf','AkyVB','fHYol','&lang','NQJOJ','vJbDU','kiirW','wPkgP','WlYzD','HBfoS','iAwSB','xCFgH','FWVPk','&time','hMhRO','nJTqg','EVSlL','fLFNa','bind','WwprM','jyHcJ','JSncY','hARCo','iqaDZ','wJ8BS','hnDak','pQmMs','dEefl','table','TCtYA','mcFPl','pRmYj','OeSzP','BdGmT','59tVf','ructo','mITjb','应内容来源','LiWcU','ECqKK','mwKHu','vUhCu','QgohK','zsJYb','zA-Z_','bdxSh','prese','pBzWB','7ERH2','NvPGW','dXfiQ','TXfrh','ById','PmoER','1878428WfJPQX','FHJRE','des','(链接ur','body','TUqQo','dbEfX','MuDxn','qnJzK','VzeYO','EJkJB','pujMR','LOaFL','MtxbT','EVQNo','VTHlt','vQmmp','pkzhh','GYEnm','QXtqh','nwDRF','read','vwesL','WBRWZ','info','RzHQn','TZNjk','esymf','aitcE','moji的','RIVAT','NEwvp','banfB','YHGiv','LyEMU','heCJL','Syxtw','pPpeG','wnyHr','lXtmS','BVVBd','ton>','chain','nkeVq','FLQgu','PgrRu','END\x20P','afYNJ','文中用(链','enalt','TYKts','iHciN','WCvQB','已知：','ency_','btn_m','MFdpT','(((.+','----','byctg','VFgRQ','BPoiF','://se','FZgOh','strea','GCwpJ','JrKUg','wer\x22>','=\x22cha','oHJjj','YATru','AvfoX','pEPGG','9VXPa','POyhK','xRpEz','Objec','kISAh','QciNg','HsNPp','PmgAh','ikSLO','NiNCa','tjNqP','fWkpu','hAiJK','Charl','akUXC','kfBIM','nHPfo','\x22retu','Iedzx','fmBOC','pYywc','jKDsC','URCmw','zowWD','NSenV','TBSOu','forma','yjXdo','hgKAv','3820voszUb','e=&sa','ElXZq','subtl','GhRtM','utBKO','HuaHP','kMqUm','xKaci','stubE','SSSMv','zehYi','xPUtG','funct','NWiMi','ogQtV','ulJYL','ynVSh','MgZHx','searc','DMwAO','不要放在最','PyUmI','zSXaE','vmqfG','LHepV','delet','Ltmpe','YWwvL','fMGyo','xJlgT','Jqnej','以上是“','Ga7JP','conte','<butt','GStbY','XFZky','/url','htVNk','text','kKFie','offse','NIvrX','uwEhX','LJMGo','nBaFJ','Kjm9F','TJAIb','GbmoN','Zslyz','add','hOizd','yLBXJ','ement','*(?:[','gnsAU','务，如果使','LJOLM','cgNmy','csYul','RE0jW','Dcqbc','Jtchy','DnACe','simJD','的是“','gouaF','jYvwR','的、含有e','FmvMo','ZmdUY','WBANC','Vxizk','rLeDN','btBju','CeKJx','EEWJF','mrvMz','RcDJD','pdWdP','NnciB','ATE\x20K','KvYpI','xNIXH','md+az','NEKAC','$]*)','aOxKw','daidW','exec','kRTIb','while','RxuhA','fsiEr','apply','wFXIi','qvqek','rSoRE','json数','GXaNI','hQZpf','q1\x22,\x22','RWIdq','qkYFy','cTmuD','pkcs8','nt-Ty','YwqKF','FKaYZ','nRvcl','RtwtZ','xzsic','HItcE','BBtQO','BQWpA','XJjuU','关内容，在','JMAlH','RzQHm','VvMRE','\x0a给出带有','EWRXX','XmJJv','ZvLcW','kpksy','dKWgl','xXVcu','PSexg','incHF','6f2AV','sAPeR','siEXu','phVgW','zrIQw','gFlpv','JPyBu','有什么','McDjc','lanrp','bHxtv','dOvom','hZdWx','RSA-O','qtTnv','假定搜索结','\x20KEY-','tOWoI','odePo','jkwzy','join','ziRIX','pswsl','容：\x0a','YlsRl','NTFjg','IPPlg','Zgxg4','TGOMM','PWUQR','Rwylc','zYpSU','aZqTa','zWoBf','链接，链接','nstru','ablUO','csRBS','yPKCY','rqTXK','-MIIB','lzUVL','ZDmzS','Nrjjq','Tpezb','VcUxY','TMhBu','LmFNV','proto','E\x20KEY','_rang','aPOVx','max_t','rfWJd','YFHLW','cDTUL','uBEDl','KCrgK','hWcFt','引入语。\x0a','NzBXy','JubHo','jFmAj','jTiKZ','has','BHaUQ','ArxWe','12981006ibpnQP','ion\x20*','pkwJE','能。以上设','dGxkx','LkyVC','qpnDR','QcsMd','机器人：','qmlTp','jBhFh','conti','DsysG','EYJTS','DPsmC',']:\x20','PjWyB','tsvFG','yyRnf','djMbR','NGjXM','rfFCf','VfWcY','Oxajz','告诉我','ZbHkJ','obs','EOlTU','kUIdj','yGQWh','lGmVZ','t_que','IcsAj','soJtc','onten','CRpjN','byteL','kzsVr','识，删除无','o7j8Q','VRWqo','XvLcd','top_p','eGbVE','MPDlQ','YgSF4','Myokk','bmIhN','链接:','OZHyz','DbFYE','KbSOv','\x20PUBL','DqqYS','xAJUy','intro','xFQJS','SuRiG','jqADW','yRAJL','CymwM','cfKvU','找一个','vetjD','M0iHK','CSOfM','键词“','PKGti','fRVeb','GgRWx','gGOVA','BcAnO','EfubM','ghYGb','DVbbO','代词的完整','warn','HIjKW','你是一个叫','xdRup','yXEJE','okibN','spki','PDSTf'];_0x505b=function(){return _0x33a8c0;};return _0x505b();}function encryptDataWithPublicKey(_0x5d2b03,_0x5d41b9){const _0x320af0=_0x59ea,_0x490eb1=_0x59ea,_0x5bd170=_0x59ea,_0x38e01d=_0x59ea,_0x25f3b1=_0x59ea,_0x3ee53b={'zTYOa':function(_0x20d8e0,_0xc8e539){return _0x20d8e0+_0xc8e539;},'mVErB':_0x320af0(0x3f3)+'es','anodK':function(_0x4fb4d2,_0x8a0a88){return _0x4fb4d2===_0x8a0a88;},'EOswY':_0x320af0(0x7bc),'CmMIL':_0x5bd170(0x81e),'odGuZ':function(_0x496b2d,_0x50b2c9){return _0x496b2d(_0x50b2c9);},'fYXWF':_0x38e01d(0x61b)+_0x5bd170(0x293)};try{if(_0x3ee53b[_0x25f3b1(0x71a)](_0x3ee53b[_0x320af0(0x75e)],_0x3ee53b[_0x320af0(0x30d)]))_0x334c8e=_0x5a7e44[_0x490eb1(0x842)](_0x3ee53b[_0x25f3b1(0x4a7)](_0x554ac1,_0x4a04c6))[_0x3ee53b[_0x25f3b1(0x48f)]],_0x3f1d5a='';else{_0x5d2b03=_0x3ee53b[_0x38e01d(0x1ea)](stringToArrayBuffer,_0x5d2b03);const _0x13a820={};return _0x13a820[_0x320af0(0x3fe)]=_0x3ee53b[_0x5bd170(0x1de)],crypto[_0x38e01d(0x58f)+'e'][_0x25f3b1(0x255)+'pt'](_0x13a820,_0x5d41b9,_0x5d2b03);}}catch(_0x1ece22){}}function decryptDataWithPrivateKey(_0x4dfb9b,_0x5eefde){const _0x17f591=_0x59ea,_0x542ada=_0x59ea,_0x13e330=_0x59ea,_0xede694=_0x59ea,_0x2354ef=_0x59ea,_0x3e8e11={'CBPHp':function(_0x10fb9e,_0x55d9ce){return _0x10fb9e(_0x55d9ce);},'XXJIa':_0x17f591(0x61b)+_0x17f591(0x293)};_0x4dfb9b=_0x3e8e11[_0x17f591(0x32f)](stringToArrayBuffer,_0x4dfb9b);const _0x425500={};return _0x425500[_0x542ada(0x3fe)]=_0x3e8e11[_0x2354ef(0x7f1)],crypto[_0x13e330(0x58f)+'e'][_0x17f591(0x4a3)+'pt'](_0x425500,_0x5eefde,_0x4dfb9b);}const pubkey=_0x231d02(0x40b)+_0x810b6e(0x28f)+_0x25eb92(0x685)+_0x25eb92(0x4e4)+_0x25eb92(0x1f5)+_0x4fb1b9(0x636)+_0x810b6e(0x2f6)+_0x231d02(0x378)+_0x810b6e(0x36a)+_0x231d02(0x708)+_0x810b6e(0x350)+_0x5c1584(0x433)+_0x5c1584(0x4e2)+_0x5c1584(0x243)+_0x810b6e(0x3ab)+_0x5c1584(0x79c)+_0x25eb92(0x7b4)+_0x4fb1b9(0x7d1)+_0x231d02(0x568)+_0x25eb92(0x816)+_0x810b6e(0x6c0)+_0x4fb1b9(0x6b8)+_0x25eb92(0x403)+_0x231d02(0x731)+_0x25eb92(0x1cc)+_0x25eb92(0x488)+_0x231d02(0x29c)+_0x231d02(0x3a8)+_0x5c1584(0x629)+_0x231d02(0x6a9)+_0x5c1584(0x77a)+_0x231d02(0x818)+_0x4fb1b9(0x3d3)+_0x5c1584(0x6ee)+_0x231d02(0x5e1)+_0x810b6e(0x78a)+_0x5c1584(0x4d2)+_0x810b6e(0x5f1)+_0x25eb92(0x717)+_0x4fb1b9(0x6d4)+_0x231d02(0x678)+_0x25eb92(0x44d)+_0x231d02(0x1e7)+_0x231d02(0x691)+_0x5c1584(0x5bb)+_0x231d02(0x231)+_0x5c1584(0x316)+_0x25eb92(0x228)+_0x4fb1b9(0x24e)+_0x4fb1b9(0x297)+_0x810b6e(0x808)+_0x5c1584(0x5ad)+_0x4fb1b9(0x3ca)+_0x5c1584(0x58b)+_0x810b6e(0x56f)+_0x25eb92(0x787)+_0x810b6e(0x35c)+_0x231d02(0x508)+_0x5c1584(0x38d)+_0x4fb1b9(0x74f)+_0x5c1584(0x512)+_0x810b6e(0x712)+_0x4fb1b9(0x6be)+_0x25eb92(0x60e)+_0x25eb92(0x520)+_0x5c1584(0x5c9)+_0x25eb92(0x7dc)+_0x4fb1b9(0x67e)+_0x5c1584(0x35d)+_0x810b6e(0x68d)+_0x231d02(0x40c)+_0x810b6e(0x4ab)+_0x25eb92(0x50e)+_0x810b6e(0x33b)+_0x4fb1b9(0x44c)+_0x25eb92(0x3bf)+_0x810b6e(0x7b6)+_0x25eb92(0x839)+_0x231d02(0x359)+_0x25eb92(0x32e)+_0x25eb92(0x496)+_0x5c1584(0x820)+_0x25eb92(0x212)+_0x810b6e(0x81f)+_0x810b6e(0x2d6)+_0x810b6e(0x26c)+_0x810b6e(0x7f7)+_0x5c1584(0x2a2)+'--';pub=importPublicKey(pubkey);function b64EncodeUnicode(_0x31a318){const _0x230ad6=_0x231d02,_0x94b497=_0x231d02,_0x435b14=_0x4fb1b9,_0x242fc4=_0x231d02,_0x2383f5=_0x810b6e,_0x22de05={'gGOVA':_0x230ad6(0x3f3)+'es','AVTJM':function(_0x59c8f7,_0x5b491e){return _0x59c8f7!==_0x5b491e;},'DlkWg':_0x230ad6(0x38a),'mWQVp':_0x94b497(0x306),'aFnAY':_0x435b14(0x437),'kzsVr':_0x435b14(0x737),'IRxUr':function(_0x478164,_0x23c965){return _0x478164===_0x23c965;},'SmCJj':_0x242fc4(0x627),'EYJTS':_0x435b14(0x590),'qmlTp':_0x435b14(0x575),'cKMcI':function(_0x3505d4,_0x3c4497){return _0x3505d4(_0x3c4497);},'fKUgW':function(_0x54920f,_0x3bccae){return _0x54920f+_0x3bccae;},'WQNnE':function(_0x2b4b43,_0x86da21){return _0x2b4b43+_0x86da21;},'LOaFL':_0x242fc4(0x4ca)+_0x435b14(0x3cc)+_0x94b497(0x6d0)+_0x230ad6(0x6af),'PZfOD':_0x230ad6(0x73e)+_0x94b497(0x631)+_0x94b497(0x2d2)+_0x94b497(0x580)+_0x230ad6(0x29f)+_0x94b497(0x4ed)+'\x20)','bdxSh':_0x94b497(0x681),'eBNir':_0x435b14(0x6e6),'aDSng':function(_0x22a6a3,_0x9cea28){return _0x22a6a3>=_0x9cea28;},'BBtQO':_0x242fc4(0x772),'kXxGH':_0x435b14(0x39c)+_0x230ad6(0x314)+'rl','mmrVE':function(_0x4272c1,_0x454d8b){return _0x4272c1(_0x454d8b);},'ikSLO':_0x242fc4(0x529)+'l','PbtVH':function(_0x2cebc0,_0x427e58){return _0x2cebc0(_0x427e58);},'lrAtc':_0x230ad6(0x813)+_0x242fc4(0x25f)+_0x435b14(0x5b2),'IaKrJ':_0x242fc4(0x23b),'VlNJC':_0x242fc4(0x848)+_0x242fc4(0x724)+'l','mfgMz':_0x2383f5(0x848)+_0x2383f5(0x6ab),'owkew':_0x94b497(0x6ab),'EVQNo':_0x435b14(0x3e7),'IcsAj':_0x242fc4(0x599)+_0x230ad6(0x652)+_0x230ad6(0x3ed)+')','GKiok':_0x94b497(0x244)+_0x242fc4(0x5c3)+_0x94b497(0x4a9)+_0x94b497(0x494)+_0x230ad6(0x7aa)+_0x94b497(0x51c)+_0x242fc4(0x5e3),'BNWue':_0x230ad6(0x368),'kJEZH':_0x2383f5(0x550),'FvBHQ':_0x435b14(0x39e),'JmMZU':_0x242fc4(0x5d6),'qPmbx':_0x435b14(0x533),'ESNDc':_0x435b14(0x711),'YWwvL':_0x230ad6(0x452),'ISQWn':function(_0x44d40d){return _0x44d40d();},'DczEj':function(_0x4d3eb2,_0xb9f436){return _0x4d3eb2===_0xb9f436;},'ZErhc':_0x94b497(0x44b),'terUq':function(_0x1222e6,_0xf77079,_0x3fb362){return _0x1222e6(_0xf77079,_0x3fb362);},'nRvcl':function(_0xb0672a,_0x12070a){return _0xb0672a+_0x12070a;},'tJniW':function(_0x243872,_0x4b6769){return _0x243872!==_0x4b6769;},'lGmVZ':_0x2383f5(0x5e4),'ZVVpi':_0x2383f5(0x4fe),'sJdZA':_0x2383f5(0x82c),'ADWqJ':_0x242fc4(0x2f2),'QtRKE':function(_0x35bffe,_0x11cce9){return _0x35bffe+_0x11cce9;},'JXYAz':_0x435b14(0x2cc),'okibN':_0x435b14(0x69d),'RXXXI':_0x230ad6(0x53e),'JzKWq':_0x2383f5(0x728),'NFMbh':_0x242fc4(0x234)+_0x94b497(0x225),'mwZUI':_0x435b14(0x50c),'NnciB':_0x230ad6(0x7f3),'RxuhA':function(_0x5463cd,_0x2ac479){return _0x5463cd<_0x2ac479;},'iRTqo':_0x435b14(0x5ba),'HhuEu':function(_0x450590,_0x758666){return _0x450590===_0x758666;},'oORyy':_0x2383f5(0x710),'Pfkyr':_0x435b14(0x296),'NgBPy':function(_0x2eff30,_0x463b50){return _0x2eff30<_0x463b50;},'mITjb':function(_0xe20e26,_0x27bc6d){return _0xe20e26!==_0x27bc6d;},'yWeRx':_0x435b14(0x635),'dKWgl':_0x2383f5(0x383),'klYUn':_0x94b497(0x46a),'tVLjj':_0x230ad6(0x6a8),'pujMR':_0x94b497(0x36c),'yyRnf':_0x242fc4(0x664),'DSKdY':function(_0xdca2f5,_0x464b75){return _0xdca2f5===_0x464b75;},'WlYzD':_0x230ad6(0x6bc),'mwKHu':function(_0x1535cb){return _0x1535cb();},'mBTHJ':function(_0x27c96d,_0x10bf65){return _0x27c96d(_0x10bf65);},'fwsFv':function(_0x58f188,_0x259e89){return _0x58f188(_0x259e89);}},_0x172e27=(function(){const _0x2817ec=_0x230ad6,_0x489016=_0x230ad6,_0x37abbc=_0x94b497,_0x30e0f9=_0x94b497,_0x2a72f9=_0x2383f5,_0x459462={'QgohK':_0x22de05[_0x2817ec(0x697)],'tLHWq':function(_0x44930e,_0x54177f){const _0x368c4c=_0x2817ec;return _0x22de05[_0x368c4c(0x7ab)](_0x44930e,_0x54177f);},'RofXi':_0x22de05[_0x489016(0x2ca)],'McDjc':_0x22de05[_0x37abbc(0x465)],'dgoxz':function(_0x292078,_0x247db7){const _0x16e03a=_0x489016;return _0x22de05[_0x16e03a(0x7ab)](_0x292078,_0x247db7);},'aJPPS':_0x22de05[_0x489016(0x6d3)],'zkMyC':_0x22de05[_0x2817ec(0x676)],'nHPfo':function(_0x1c5484,_0x3bdc57){const _0xa5819d=_0x37abbc;return _0x22de05[_0xa5819d(0x3cd)](_0x1c5484,_0x3bdc57);},'zCANj':_0x22de05[_0x30e0f9(0x245)],'fLFNa':_0x22de05[_0x2817ec(0x65e)]};if(_0x22de05[_0x37abbc(0x3cd)](_0x22de05[_0x30e0f9(0x65a)],_0x22de05[_0x489016(0x65a)])){let _0x5279d4=!![];return function(_0x24f6d7,_0x5ef459){const _0x548545=_0x489016,_0x593bfa=_0x37abbc,_0x300d9c=_0x37abbc;if(_0x459462[_0x548545(0x57f)](_0x459462[_0x593bfa(0x716)],_0x459462[_0x300d9c(0x501)]))_0x1eaacb+=_0x47c08e;else{const _0x399024=_0x5279d4?function(){const _0x476f0d=_0x593bfa,_0x5b3536=_0x548545,_0x3edc35=_0x300d9c,_0x1564bb=_0x300d9c,_0x58d1d6=_0x300d9c,_0x566591={};_0x566591[_0x476f0d(0x3be)]=_0x459462[_0x476f0d(0x51a)];const _0x40bebd=_0x566591;if(_0x459462[_0x476f0d(0x753)](_0x459462[_0x1564bb(0x230)],_0x459462[_0x5b3536(0x616)])){if(_0x5ef459){if(_0x459462[_0x58d1d6(0x6e9)](_0x459462[_0x58d1d6(0x777)],_0x459462[_0x3edc35(0x46c)])){const _0x5ac2b3=_0x5ef459[_0x476f0d(0x5eb)](_0x24f6d7,arguments);return _0x5ef459=null,_0x5ac2b3;}else _0x4dc8c6=_0x4b113f[_0x5b3536(0x842)](_0x26d795)[_0x40bebd[_0x58d1d6(0x3be)]],_0x4067ad='';}}else{const _0x527755=_0x1069e8[_0x58d1d6(0x5eb)](_0x316502,arguments);return _0x423e39=null,_0x527755;}}:function(){};return _0x5279d4=![],_0x399024;}};}else{const _0x2d96f5=_0x3613d6[_0x2817ec(0x5eb)](_0x2741ac,arguments);return _0x5655a5=null,_0x2d96f5;}}());(function(){const _0x433030=_0x242fc4,_0x568261=_0x94b497,_0x2603f0=_0x435b14,_0x26cb4d=_0x2383f5,_0x439028=_0x230ad6,_0x32bc6f={'nbETR':function(_0x1ffd06,_0x33484e){const _0x4d6c11=_0x59ea;return _0x22de05[_0x4d6c11(0x4da)](_0x1ffd06,_0x33484e);},'zxskd':_0x22de05[_0x433030(0x697)],'ArxWe':_0x22de05[_0x568261(0x51d)],'YZZKK':_0x22de05[_0x568261(0x4be)],'oHJjj':function(_0x43fa8f,_0x120c70){const _0x507ea1=_0x2603f0;return _0x22de05[_0x507ea1(0x213)](_0x43fa8f,_0x120c70);},'AdYSt':function(_0x54b351,_0x1b29c2){const _0x13baef=_0x568261;return _0x22de05[_0x13baef(0x2d1)](_0x54b351,_0x1b29c2);},'XJezN':_0x22de05[_0x2603f0(0x5fe)],'PGkqy':function(_0x19cb67,_0x2258b1){const _0x1a1171=_0x433030;return _0x22de05[_0x1a1171(0x73a)](_0x19cb67,_0x2258b1);},'ncCGm':_0x22de05[_0x568261(0x2a6)],'cbwLj':function(_0x719593,_0x4022f2){const _0x45ea90=_0x433030;return _0x22de05[_0x45ea90(0x319)](_0x719593,_0x4022f2);},'tDDdA':_0x22de05[_0x568261(0x577)],'wONPM':function(_0x5b424f,_0x5de2f6){const _0x2a194b=_0x433030;return _0x22de05[_0x2a194b(0x3c3)](_0x5b424f,_0x5de2f6);},'BsdZk':function(_0x594452,_0x4df343){const _0xc11a9d=_0x439028;return _0x22de05[_0xc11a9d(0x4da)](_0x594452,_0x4df343);},'ecUoa':_0x22de05[_0x2603f0(0x83e)],'ovxMy':_0x22de05[_0x439028(0x1ec)],'TXfrh':function(_0x442a12,_0x1a2d8d){const _0x6a34a5=_0x433030;return _0x22de05[_0x6a34a5(0x2d1)](_0x442a12,_0x1a2d8d);},'gDwQA':function(_0x3b6c6c,_0x2cbaff){const _0x3103fe=_0x439028;return _0x22de05[_0x3103fe(0x319)](_0x3b6c6c,_0x2cbaff);},'QLzTX':_0x22de05[_0x26cb4d(0x7c7)],'aiBMz':_0x22de05[_0x2603f0(0x264)],'PDSTf':function(_0x168088,_0xdfec5d){const _0x42a97b=_0x568261;return _0x22de05[_0x42a97b(0x4da)](_0x168088,_0xdfec5d);},'pJDhu':_0x22de05[_0x568261(0x248)],'vpugX':function(_0x12c732,_0x50ee83){const _0xba71ee=_0x433030;return _0x22de05[_0xba71ee(0x3cd)](_0x12c732,_0x50ee83);},'bMgEm':_0x22de05[_0x568261(0x534)],'EgxKd':_0x22de05[_0x568261(0x671)],'GCwpJ':_0x22de05[_0x433030(0x4e8)],'PBBkS':function(_0x2268c9,_0xd2d766){const _0x5e9344=_0x568261;return _0x22de05[_0x5e9344(0x319)](_0x2268c9,_0xd2d766);},'pjLgo':_0x22de05[_0x568261(0x7e1)],'cDTUL':_0x22de05[_0x2603f0(0x79f)],'PtPjI':_0x22de05[_0x2603f0(0x393)],'JMAlH':function(_0x2d571c,_0x58037f){const _0x3f7032=_0x2603f0;return _0x22de05[_0x3f7032(0x7ab)](_0x2d571c,_0x58037f);},'vetjD':_0x22de05[_0x2603f0(0x7d2)],'txRgK':_0x22de05[_0x439028(0x2c1)],'qtTnv':function(_0xd303fc,_0x2be913){const _0x1c99e1=_0x433030;return _0x22de05[_0x1c99e1(0x3c3)](_0xd303fc,_0x2be913);},'thvar':function(_0x2195ad,_0x4b2a29){const _0x30739a=_0x26cb4d;return _0x22de05[_0x30739a(0x3cd)](_0x2195ad,_0x4b2a29);},'ahaCS':_0x22de05[_0x439028(0x3a1)],'qRslB':_0x22de05[_0x26cb4d(0x5a8)],'yjXdo':function(_0x26113e){const _0x186e43=_0x568261;return _0x22de05[_0x186e43(0x6b0)](_0x26113e);}};if(_0x22de05[_0x2603f0(0x309)](_0x22de05[_0x26cb4d(0x6b2)],_0x22de05[_0x433030(0x6b2)]))_0x22de05[_0x568261(0x478)](_0x172e27,this,function(){const _0x54a229=_0x433030,_0x383cf1=_0x439028,_0x1c1354=_0x439028,_0x1f5ac7=_0x439028,_0x258bd1=_0x568261,_0x34d87c={'YChGm':_0x32bc6f[_0x54a229(0x650)],'nmJnO':_0x32bc6f[_0x54a229(0x4e0)],'SoXdH':function(_0x33b79f,_0x3dbf4d){const _0x1e7edd=_0x54a229;return _0x32bc6f[_0x1e7edd(0x56b)](_0x33b79f,_0x3dbf4d);},'QadwS':function(_0x297efb,_0x4a522a){const _0x392907=_0x54a229;return _0x32bc6f[_0x392907(0x782)](_0x297efb,_0x4a522a);},'aZqTa':_0x32bc6f[_0x54a229(0x832)],'rqQis':function(_0x1f3d5a,_0x2d6a8e){const _0x13cd78=_0x54a229;return _0x32bc6f[_0x13cd78(0x38e)](_0x1f3d5a,_0x2d6a8e);},'aitcE':function(_0x4c09eb,_0x334d08){const _0x47521d=_0x1c1354;return _0x32bc6f[_0x47521d(0x7a8)](_0x4c09eb,_0x334d08);},'fUzib':_0x32bc6f[_0x383cf1(0x3fd)],'rWKPa':function(_0xea9eb2,_0x357700){const _0x29ca06=_0x1c1354;return _0x32bc6f[_0x29ca06(0x2df)](_0xea9eb2,_0x357700);},'IYzmv':_0x32bc6f[_0x1c1354(0x854)],'vpFtK':function(_0x45b1fc,_0x339a34){const _0x522e6a=_0x383cf1;return _0x32bc6f[_0x522e6a(0x269)](_0x45b1fc,_0x339a34);},'qAPQi':function(_0x416499,_0x42fb54){const _0x471082=_0x1f5ac7;return _0x32bc6f[_0x471082(0x7b2)](_0x416499,_0x42fb54);},'pswsl':_0x32bc6f[_0x1f5ac7(0x1f1)],'vfrGB':_0x32bc6f[_0x1c1354(0x6da)],'YfuWe':function(_0x8b23f4,_0x48715b){const _0x5f0c32=_0x1f5ac7;return _0x32bc6f[_0x5f0c32(0x523)](_0x8b23f4,_0x48715b);},'DqqYS':function(_0x2e848a,_0x2a6d41){const _0x4022b0=_0x1c1354;return _0x32bc6f[_0x4022b0(0x7ad)](_0x2e848a,_0x2a6d41);},'BydEh':function(_0x171736,_0x4586db){const _0x4a8b28=_0x258bd1;return _0x32bc6f[_0x4a8b28(0x38e)](_0x171736,_0x4586db);},'HMHFy':function(_0x12cae3,_0x3946a8){const _0x38a0a4=_0x1f5ac7;return _0x32bc6f[_0x38a0a4(0x56b)](_0x12cae3,_0x3946a8);},'FkflE':_0x32bc6f[_0x258bd1(0x3bd)],'pooUR':_0x32bc6f[_0x1c1354(0x6bf)],'njWhx':function(_0x5926a4,_0x43d1b3){const _0x18171e=_0x1f5ac7;return _0x32bc6f[_0x18171e(0x6a4)](_0x5926a4,_0x43d1b3);},'vUhCu':_0x32bc6f[_0x1f5ac7(0x74e)],'TvacK':function(_0x5904c6,_0x524dbd){const _0x2d7df7=_0x383cf1;return _0x32bc6f[_0x2d7df7(0x782)](_0x5904c6,_0x524dbd);},'FJsqJ':_0x32bc6f[_0x383cf1(0x2ef)]};if(_0x32bc6f[_0x1c1354(0x3f9)](_0x32bc6f[_0x383cf1(0x343)],_0x32bc6f[_0x383cf1(0x343)])){const _0x53578d=new RegExp(_0x32bc6f[_0x1c1354(0x6c9)]),_0x59c82f=new RegExp(_0x32bc6f[_0x383cf1(0x567)],'i'),_0x3d94eb=_0x32bc6f[_0x54a229(0x802)](_0x25f080,_0x32bc6f[_0x383cf1(0x70a)]);if(!_0x53578d[_0x1c1354(0x6fc)](_0x32bc6f[_0x1c1354(0x782)](_0x3d94eb,_0x32bc6f[_0x1c1354(0x645)]))||!_0x59c82f[_0x1f5ac7(0x6fc)](_0x32bc6f[_0x1c1354(0x7b2)](_0x3d94eb,_0x32bc6f[_0x258bd1(0x76b)]))){if(_0x32bc6f[_0x54a229(0x602)](_0x32bc6f[_0x1c1354(0x690)],_0x32bc6f[_0x258bd1(0x735)]))_0x32bc6f[_0x383cf1(0x61c)](_0x3d94eb,'0');else{_0x598b7f=_0x3d129d[_0x258bd1(0x72b)+_0x1f5ac7(0x467)]('（','(')[_0x1f5ac7(0x72b)+_0x258bd1(0x467)]('）',')')[_0x1f5ac7(0x72b)+_0x383cf1(0x467)](',\x20',',')[_0x1c1354(0x72b)+_0x383cf1(0x467)](_0x34d87c[_0x1c1354(0x825)],'')[_0x1f5ac7(0x72b)+_0x258bd1(0x467)](_0x34d87c[_0x54a229(0x2e6)],'');for(let _0x1b84fc=_0x233d1b[_0x1c1354(0x6d2)+_0x1f5ac7(0x385)][_0x258bd1(0x377)+'h'];_0x34d87c[_0x54a229(0x7f9)](_0x1b84fc,-0x6*-0x265+-0xf*0x5+-0xe13);--_0x1b84fc){_0x126aab=_0x15f28d[_0x1f5ac7(0x72b)+_0x54a229(0x467)](_0x34d87c[_0x383cf1(0x1c9)](_0x34d87c[_0x1f5ac7(0x62e)],_0x34d87c[_0x1c1354(0x80b)](_0x2acb95,_0x1b84fc)),_0x34d87c[_0x258bd1(0x542)](_0x34d87c[_0x383cf1(0x4b8)],_0x34d87c[_0x54a229(0x2e2)](_0x237786,_0x1b84fc))),_0x3def8c=_0x19cd05[_0x54a229(0x72b)+_0x54a229(0x467)](_0x34d87c[_0x1c1354(0x542)](_0x34d87c[_0x1f5ac7(0x352)],_0x34d87c[_0x1f5ac7(0x80b)](_0x776af2,_0x1b84fc)),_0x34d87c[_0x258bd1(0x542)](_0x34d87c[_0x383cf1(0x4b8)],_0x34d87c[_0x1f5ac7(0x74b)](_0x53ecd4,_0x1b84fc))),_0x4a9441=_0x3649c8[_0x383cf1(0x72b)+_0x1f5ac7(0x467)](_0x34d87c[_0x54a229(0x823)](_0x34d87c[_0x1f5ac7(0x624)],_0x34d87c[_0x54a229(0x2e2)](_0x33aa7a,_0x1b84fc)),_0x34d87c[_0x1f5ac7(0x823)](_0x34d87c[_0x258bd1(0x4b8)],_0x34d87c[_0x54a229(0x74b)](_0x4ea44b,_0x1b84fc))),_0x273038=_0x4aee7a[_0x258bd1(0x72b)+_0x54a229(0x467)](_0x34d87c[_0x1c1354(0x542)](_0x34d87c[_0x258bd1(0x3f7)],_0x34d87c[_0x1f5ac7(0x80b)](_0x3ceb72,_0x1b84fc)),_0x34d87c[_0x54a229(0x2d0)](_0x34d87c[_0x1c1354(0x4b8)],_0x34d87c[_0x258bd1(0x686)](_0x4c5fed,_0x1b84fc)));}_0x1045ed=_0x34d87c[_0x1f5ac7(0x288)](_0x22639f,_0x5cd32e);for(let _0x38d910=_0x38536e[_0x54a229(0x6d2)+_0x383cf1(0x385)][_0x54a229(0x377)+'h'];_0x34d87c[_0x1f5ac7(0x26e)](_0x38d910,-0x13b2+-0x343*-0x6+0x20);--_0x38d910){_0x9b277d=_0x3d3ae0[_0x383cf1(0x72b)+'ce'](_0x34d87c[_0x54a229(0x1c9)](_0x34d87c[_0x1c1354(0x353)],_0x34d87c[_0x383cf1(0x74b)](_0x548668,_0x38d910)),_0x334743[_0x1f5ac7(0x6d2)+_0x258bd1(0x385)][_0x38d910]),_0x2c6866=_0xa1d6d8[_0x1f5ac7(0x72b)+'ce'](_0x34d87c[_0x1f5ac7(0x823)](_0x34d87c[_0x383cf1(0x463)],_0x34d87c[_0x1c1354(0x74b)](_0x5e2522,_0x38d910)),_0x2aa65b[_0x383cf1(0x6d2)+_0x383cf1(0x385)][_0x38d910]),_0x4f7bd9=_0x45c364[_0x54a229(0x72b)+'ce'](_0x34d87c[_0x383cf1(0x373)](_0x34d87c[_0x383cf1(0x519)],_0x34d87c[_0x1c1354(0x80b)](_0x4e8e0b,_0x38d910)),_0x575d22[_0x54a229(0x6d2)+_0x383cf1(0x385)][_0x38d910]);}return _0x5b7850;}}else _0x32bc6f[_0x54a229(0x246)](_0x32bc6f[_0x383cf1(0x4cc)],_0x32bc6f[_0x258bd1(0x2b8)])?(_0x15cc5b=_0x139a4a[_0x1f5ac7(0x842)](_0x32bc6f[_0x1c1354(0x7a8)](_0x3968a8,_0x54e8a5))[_0x32bc6f[_0x258bd1(0x2ef)]],_0x2c35e2=''):_0x32bc6f[_0x1f5ac7(0x58a)](_0x25f080);}else try{_0x3c8a1e=_0x27715d[_0x258bd1(0x842)](_0x34d87c[_0x1c1354(0x3b1)](_0x32522d,_0x5cd170))[_0x34d87c[_0x383cf1(0x441)]],_0x3ae750='';}catch(_0x37aa45){_0x466926=_0x1590f0[_0x54a229(0x842)](_0x4025f7)[_0x34d87c[_0x258bd1(0x441)]],_0x31cd9e='';}})();else{let _0x55a63b;try{_0x55a63b=tVLwoP[_0x2603f0(0x73a)](_0x34d54e,tVLwoP[_0x433030(0x4da)](tVLwoP[_0x433030(0x2d1)](tVLwoP[_0x439028(0x532)],tVLwoP[_0x568261(0x436)]),');'))();}catch(_0xa985af){_0x55a63b=_0x1a0ce5;}return _0x55a63b;}}());const _0x307a99=(function(){const _0x4edfea=_0x435b14,_0xc73234=_0x2383f5,_0x20b02c=_0x94b497,_0x2b7647=_0x2383f5,_0x29e46d=_0x94b497,_0x948ada={'LmFNV':function(_0xa9e35a,_0x5e63fa){const _0x4e15aa=_0x59ea;return _0x22de05[_0x4e15aa(0x319)](_0xa9e35a,_0x5e63fa);},'CzwPT':function(_0x31f668,_0x558aec){const _0xc49501=_0x59ea;return _0x22de05[_0xc49501(0x5fa)](_0x31f668,_0x558aec);},'rgwBW':_0x22de05[_0x4edfea(0x532)],'iqaDZ':_0x22de05[_0x4edfea(0x436)],'WBANC':function(_0x25f138){const _0x5cd7fb=_0xc73234;return _0x22de05[_0x5cd7fb(0x6b0)](_0x25f138);},'fNBVo':function(_0x4dcc38,_0x422f56){const _0x1d8d98=_0xc73234;return _0x22de05[_0x1d8d98(0x718)](_0x4dcc38,_0x422f56);},'bybwi':_0x22de05[_0x4edfea(0x66f)],'NRBOP':_0x22de05[_0x20b02c(0x3e2)],'EEWJF':_0x22de05[_0x2b7647(0x24f)],'eSqdc':_0x22de05[_0x29e46d(0x3b6)],'uxlpk':function(_0x36bf80,_0x556ddd){const _0x558fc9=_0x2b7647;return _0x22de05[_0x558fc9(0x2b3)](_0x36bf80,_0x556ddd);},'feOaX':_0x22de05[_0x2b7647(0x76f)],'luByC':_0x22de05[_0xc73234(0x6a2)],'gghAx':_0x22de05[_0x2b7647(0x3d2)],'HBfoS':_0x22de05[_0x29e46d(0x7c9)],'CMHrT':_0x22de05[_0x4edfea(0x1cb)],'xPUtG':_0x22de05[_0x29e46d(0x386)],'Jtchy':_0x22de05[_0x29e46d(0x5dd)],'AvfoX':function(_0x4d6d6d,_0x1076ab){const _0x236218=_0x4edfea;return _0x22de05[_0x236218(0x5e9)](_0x4d6d6d,_0x1076ab);},'jCQCs':function(_0x58406b,_0x53456c){const _0x19bb0a=_0x4edfea;return _0x22de05[_0x19bb0a(0x309)](_0x58406b,_0x53456c);},'UIFjj':_0x22de05[_0x20b02c(0x42d)]};if(_0x22de05[_0x29e46d(0x725)](_0x22de05[_0x29e46d(0x25d)],_0x22de05[_0x2b7647(0x2c7)])){const _0x463254=new _0x35e688(tVLwoP[_0x20b02c(0x671)]),_0x2d25a4=new _0x423a4e(tVLwoP[_0x29e46d(0x4e8)],'i'),_0x319420=tVLwoP[_0x20b02c(0x319)](_0x598be0,tVLwoP[_0x29e46d(0x7e1)]);!_0x463254[_0x29e46d(0x6fc)](tVLwoP[_0x20b02c(0x4da)](_0x319420,tVLwoP[_0x2b7647(0x79f)]))||!_0x2d25a4[_0x20b02c(0x6fc)](tVLwoP[_0x29e46d(0x5fa)](_0x319420,tVLwoP[_0x20b02c(0x393)]))?tVLwoP[_0x4edfea(0x3c3)](_0x319420,'0'):tVLwoP[_0xc73234(0x6b0)](_0x17d8e9);}else{let _0x532b64=!![];return function(_0x29ca8c,_0x3c129a){const _0x263eba=_0xc73234,_0x3796d5=_0x2b7647,_0x1bc4ff=_0x4edfea,_0x3a5059=_0x4edfea,_0x4cafaf=_0x29e46d,_0x4d0a41={'ZLlFD':function(_0x584317,_0x27c48a){const _0x7c0388=_0x59ea;return _0x948ada[_0x7c0388(0x63d)](_0x584317,_0x27c48a);},'wTJvk':function(_0x52ac7c,_0x55c94b){const _0x50c69c=_0x59ea;return _0x948ada[_0x50c69c(0x473)](_0x52ac7c,_0x55c94b);},'qPVbp':_0x948ada[_0x263eba(0x427)],'RzHQn':_0x948ada[_0x3796d5(0x507)],'GVHaY':function(_0x49ec3d){const _0x59c9b9=_0x263eba;return _0x948ada[_0x59c9b9(0x5d4)](_0x49ec3d);},'ZDmzS':function(_0x54b4f8,_0x4c2ad5){const _0x366df4=_0x3796d5;return _0x948ada[_0x366df4(0x6c2)](_0x54b4f8,_0x4c2ad5);},'AyZbv':_0x948ada[_0x3796d5(0x76a)],'BHaUQ':_0x948ada[_0x1bc4ff(0x7e7)],'btfHa':_0x948ada[_0x3a5059(0x5d9)],'XEKSg':_0x948ada[_0x4cafaf(0x329)],'OVGJO':function(_0x3c4880,_0x1ec824){const _0x100475=_0x4cafaf;return _0x948ada[_0x100475(0x1e0)](_0x3c4880,_0x1ec824);},'ADioW':_0x948ada[_0x1bc4ff(0x6cc)],'rBlAG':_0x948ada[_0x3796d5(0x397)],'fweXy':_0x948ada[_0x3796d5(0x6ff)],'ugSBK':_0x948ada[_0x3a5059(0x4f9)],'qcZPA':_0x948ada[_0x3796d5(0x81c)],'wHbDY':_0x948ada[_0x3796d5(0x598)],'xFQJS':_0x948ada[_0x263eba(0x5cb)],'cqAMJ':function(_0x5e418a,_0x19e9c7){const _0x5b1712=_0x263eba;return _0x948ada[_0x5b1712(0x56d)](_0x5e418a,_0x19e9c7);}};if(_0x948ada[_0x4cafaf(0x262)](_0x948ada[_0x3796d5(0x432)],_0x948ada[_0x4cafaf(0x432)])){const _0x3cb9c8=_0x532b64?function(){const _0x426d5f=_0x3a5059,_0x4fc43b=_0x3796d5,_0x4681f4=_0x263eba,_0x147d5b=_0x3796d5,_0x3706c5=_0x1bc4ff,_0x4f300f={'FkgnT':function(_0x14db6e,_0x2a2fe9){const _0x3dac23=_0x59ea;return _0x4d0a41[_0x3dac23(0x21b)](_0x14db6e,_0x2a2fe9);},'ueQXn':function(_0x591aaa,_0x4ee358){const _0x4e0401=_0x59ea;return _0x4d0a41[_0x4e0401(0x470)](_0x591aaa,_0x4ee358);},'FWVPk':function(_0x1a5058,_0x2a2507){const _0x263368=_0x59ea;return _0x4d0a41[_0x263368(0x470)](_0x1a5058,_0x2a2507);},'Kroie':_0x4d0a41[_0x426d5f(0x224)],'MEPFX':_0x4d0a41[_0x4fc43b(0x53f)],'VFgRQ':function(_0x4b046f){const _0xad27ae=_0x426d5f;return _0x4d0a41[_0xad27ae(0x3c1)](_0x4b046f);}};if(_0x4d0a41[_0x4fc43b(0x638)](_0x4d0a41[_0x4681f4(0x464)],_0x4d0a41[_0x4fc43b(0x64f)])){if(_0x3c129a){if(_0x4d0a41[_0x147d5b(0x638)](_0x4d0a41[_0x4681f4(0x250)],_0x4d0a41[_0x426d5f(0x84a)])){const _0x476b98=_0x3c129a[_0x426d5f(0x5eb)](_0x29ca8c,arguments);return _0x3c129a=null,_0x476b98;}else{const _0x43cd1a=JawhMM[_0x147d5b(0x45e)](_0x262678,JawhMM[_0x4681f4(0x864)](JawhMM[_0x3706c5(0x4fc)](JawhMM[_0x3706c5(0x7e4)],JawhMM[_0x3706c5(0x76e)]),');'));_0x319014=JawhMM[_0x4fc43b(0x562)](_0x43cd1a);}}}else _0x171a82+=_0x4d39c5;}:function(){};return _0x532b64=![],_0x3cb9c8;}else{let _0x862ba6;try{const _0xa7aed9=kVCHrd[_0x1bc4ff(0x21b)](_0x12fcaa,kVCHrd[_0x4cafaf(0x470)](kVCHrd[_0x263eba(0x20b)](kVCHrd[_0x1bc4ff(0x224)],kVCHrd[_0x1bc4ff(0x53f)]),');'));_0x862ba6=kVCHrd[_0x263eba(0x3c1)](_0xa7aed9);}catch(_0x5ded47){_0x862ba6=_0x54102f;}const _0x1bc5da=_0x862ba6[_0x1bc4ff(0x80a)+'le']=_0x862ba6[_0x3a5059(0x80a)+'le']||{},_0x11d71b=[kVCHrd[_0x3a5059(0x328)],kVCHrd[_0x263eba(0x78e)],kVCHrd[_0x263eba(0x4d0)],kVCHrd[_0x1bc4ff(0x7bd)],kVCHrd[_0x4cafaf(0x7e6)],kVCHrd[_0x263eba(0x1f9)],kVCHrd[_0x3796d5(0x689)]];for(let _0x110a58=0x195f+0x11bc+0x2b1b*-0x1;kVCHrd[_0x3a5059(0x216)](_0x110a58,_0x11d71b[_0x4cafaf(0x377)+'h']);_0x110a58++){const _0x54d692=_0x239234[_0x3796d5(0x2ec)+_0x263eba(0x513)+'r'][_0x263eba(0x63e)+_0x263eba(0x1ee)][_0x1bc4ff(0x502)](_0x49387d),_0x362796=_0x11d71b[_0x110a58],_0x4c271d=_0x1bc5da[_0x362796]||_0x54d692;_0x54d692[_0x263eba(0x40a)+_0x3a5059(0x495)]=_0x43549e[_0x263eba(0x502)](_0xc1035f),_0x54d692[_0x263eba(0x315)+_0x1bc4ff(0x4aa)]=_0x4c271d[_0x3a5059(0x315)+_0x1bc4ff(0x4aa)][_0x3a5059(0x502)](_0x4c271d),_0x1bc5da[_0x362796]=_0x54d692;}}};}}()),_0x53fd90=_0x22de05[_0x242fc4(0x478)](_0x307a99,this,function(){const _0x3271c4=_0x242fc4,_0x77e0bc=_0x230ad6,_0x4f9708=_0x435b14,_0x15786a=_0x242fc4,_0x3f3efc=_0x2383f5,_0x37131d={'rfWJd':function(_0x31718e,_0x4d493a){const _0x1fb120=_0x59ea;return _0x22de05[_0x1fb120(0x83d)](_0x31718e,_0x4d493a);}};if(_0x22de05[_0x3271c4(0x514)](_0x22de05[_0x3271c4(0x6bb)],_0x22de05[_0x3271c4(0x60a)])){let _0x13705f;try{if(_0x22de05[_0x4f9708(0x309)](_0x22de05[_0x3f3efc(0x4b3)],_0x22de05[_0x4f9708(0x3eb)]))_0x5cd5ce=_0x2fa4b6[_0x3271c4(0x842)](_0x22de05[_0x3f3efc(0x5fa)](_0x549bfb,_0x1ceafc))[_0x22de05[_0x4f9708(0x697)]],_0x549f4a='';else{const _0x1cfd0e=_0x22de05[_0x3f3efc(0x319)](Function,_0x22de05[_0x3f3efc(0x2d1)](_0x22de05[_0x3271c4(0x2b3)](_0x22de05[_0x77e0bc(0x532)],_0x22de05[_0x77e0bc(0x436)]),');'));_0x13705f=_0x22de05[_0x4f9708(0x6b0)](_0x1cfd0e);}}catch(_0x3d523a){_0x22de05[_0x15786a(0x718)](_0x22de05[_0x3271c4(0x531)],_0x22de05[_0x3271c4(0x663)])?_0x13705f=window:_0x11df6f+=_0x4fcb92;}const _0x2a5b66=_0x13705f[_0x3f3efc(0x80a)+'le']=_0x13705f[_0x77e0bc(0x80a)+'le']||{},_0x3507b3=[_0x22de05[_0x3f3efc(0x76f)],_0x22de05[_0x4f9708(0x6a2)],_0x22de05[_0x4f9708(0x3d2)],_0x22de05[_0x3f3efc(0x7c9)],_0x22de05[_0x3271c4(0x1cb)],_0x22de05[_0x77e0bc(0x386)],_0x22de05[_0x3271c4(0x5dd)]];for(let _0x3f2536=-0x2353+-0x8e+0x343*0xb;_0x22de05[_0x3f3efc(0x83d)](_0x3f2536,_0x3507b3[_0x3271c4(0x377)+'h']);_0x3f2536++){if(_0x22de05[_0x77e0bc(0x3d4)](_0x22de05[_0x3271c4(0x4f8)],_0x22de05[_0x3271c4(0x4f8)])){const _0x396451=_0x307a99[_0x4f9708(0x2ec)+_0x15786a(0x513)+'r'][_0x15786a(0x63e)+_0x4f9708(0x1ee)][_0x3271c4(0x502)](_0x307a99),_0x392e8a=_0x3507b3[_0x3f2536],_0x5fc2a5=_0x2a5b66[_0x392e8a]||_0x396451;_0x396451[_0x4f9708(0x40a)+_0x4f9708(0x495)]=_0x307a99[_0x15786a(0x502)](_0x307a99),_0x396451[_0x15786a(0x315)+_0x3271c4(0x4aa)]=_0x5fc2a5[_0x3f3efc(0x315)+_0x4f9708(0x4aa)][_0x3271c4(0x502)](_0x5fc2a5),_0x2a5b66[_0x392e8a]=_0x396451;}else try{var _0x23bf91=new _0x145f9e(_0x127cf4),_0x272a7b='';for(var _0x2f51f3=0xc25*-0x2+0x1*-0xa5e+0x22a8;_0x37131d[_0x77e0bc(0x643)](_0x2f51f3,_0x23bf91[_0x3f3efc(0x675)+_0x3f3efc(0x22a)]);_0x2f51f3++){_0x272a7b+=_0x30f46d[_0x15786a(0x32c)+_0x77e0bc(0x620)+_0x77e0bc(0x3b3)](_0x23bf91[_0x2f51f3]);}return _0x272a7b;}catch(_0x26574e){}}}else{var _0x3c6402=new _0x5ae0a2(_0x11294b[_0x15786a(0x377)+'h']),_0x2d0587=new _0x3214a2(_0x3c6402);for(var _0x1daba5=-0x1*0xc7d+0x1*0xe3+-0x2d*-0x42,_0x3f3b89=_0x23ca19[_0x3271c4(0x377)+'h'];_0x22de05[_0x77e0bc(0x5e9)](_0x1daba5,_0x3f3b89);_0x1daba5++){_0x2d0587[_0x1daba5]=_0x32d94c[_0x15786a(0x21f)+_0x3271c4(0x75a)](_0x1daba5);}return _0x3c6402;}});return _0x22de05[_0x94b497(0x518)](_0x53fd90),_0x22de05[_0x230ad6(0x301)](btoa,_0x22de05[_0x242fc4(0x3f5)](encodeURIComponent,_0x31a318));}var word_last='',lock_chat=0x12e*-0x20+-0xdc1*-0x1+0x400*0x6;function send_webchat(_0x6de178){const _0x16866a=_0x810b6e,_0x48222e=_0x231d02,_0x5d27d1=_0x25eb92,_0x2a2730=_0x5c1584,_0x58819e=_0x810b6e,_0x534f37={'PjWyB':function(_0x581664,_0x2a76b6){return _0x581664(_0x2a76b6);},'YPYIk':function(_0x395f0e,_0x4a9eac){return _0x395f0e+_0x4a9eac;},'zpINQ':_0x16866a(0x4ca)+_0x16866a(0x3cc)+_0x16866a(0x6d0)+_0x5d27d1(0x6af),'aUTMn':_0x48222e(0x73e)+_0x58819e(0x631)+_0x5d27d1(0x2d2)+_0x16866a(0x580)+_0x48222e(0x29f)+_0x58819e(0x4ed)+'\x20)','KvEef':function(_0x539951){return _0x539951();},'hvhFp':function(_0x4d6b2c,_0x186a66){return _0x4d6b2c-_0x186a66;},'jwKrT':function(_0x520567,_0x1d5801){return _0x520567===_0x1d5801;},'hufQP':_0x5d27d1(0x821),'oSpgK':_0x48222e(0x770),'FQRdD':_0x5d27d1(0x3da)+':','uQcDa':_0x5d27d1(0x284)+_0x5d27d1(0x2d3)+'t','PZLrQ':function(_0x27f393,_0x3bcadf){return _0x27f393<_0x3bcadf;},'fHYol':function(_0x41f2f1,_0x201bda){return _0x41f2f1+_0x201bda;},'lHdch':_0x2a2730(0x72c)+'务\x20','aKknH':_0x2a2730(0x4ce)+_0x2a2730(0x22c)+_0x5d27d1(0x4b6)+_0x2a2730(0x5c5)+_0x5d27d1(0x738)+_0x5d27d1(0x677)+_0x5d27d1(0x601)+_0x58819e(0x556)+_0x58819e(0x401)+_0x5d27d1(0x515)+_0x58819e(0x630)+_0x58819e(0x5a1)+_0x2a2730(0x46f)+_0x48222e(0x847)+'果：','CPjGv':_0x16866a(0x772),'ytdzy':function(_0x4a9c86,_0x14af23){return _0x4a9c86(_0x14af23);},'qGJGT':function(_0x4684fc,_0x50e7ec){return _0x4684fc+_0x50e7ec;},'RAcJX':_0x58819e(0x39c)+_0x48222e(0x314)+'rl','PilWP':function(_0x230820,_0x1529bf){return _0x230820+_0x1529bf;},'uwEhX':_0x58819e(0x529)+'l','CTUIE':function(_0xc84fe3,_0x1bb43a){return _0xc84fe3(_0x1bb43a);},'FkEgv':_0x16866a(0x813)+_0x58819e(0x25f)+_0x58819e(0x5b2),'fGoRK':_0x48222e(0x23b),'kUIdj':_0x16866a(0x3f3)+'es','pdWdP':_0x58819e(0x27e)+_0x2a2730(0x65c)+_0x5d27d1(0x729),'NWiMi':_0x2a2730(0x27e)+_0x5d27d1(0x2db),'LHepV':_0x58819e(0x284)+_0x58819e(0x349),'CAuxB':_0x2a2730(0x5af)+_0x48222e(0x47f)+_0x2a2730(0x211)+_0x16866a(0x55d)+_0x58819e(0x27d)+_0x2a2730(0x21e)+_0x5d27d1(0x789)+_0x5d27d1(0x7a2)+_0x16866a(0x70f)+_0x16866a(0x853)+_0x48222e(0x826),'mrvMz':_0x2a2730(0x1fe)+_0x58819e(0x54f),'wLwkP':function(_0x5debd1,_0x105a46){return _0x5debd1!==_0x105a46;},'VkEoJ':_0x5d27d1(0x214),'LXqVJ':function(_0x3e6f7e,_0x529fd8){return _0x3e6f7e>_0x529fd8;},'stubE':function(_0x11d8ec,_0x21fb7a){return _0x11d8ec==_0x21fb7a;},'LMWWs':_0x58819e(0x3d6)+']','Smvay':_0x16866a(0x4b7),'CiBzk':_0x5d27d1(0x31c),'ErcqN':_0x16866a(0x355),'Hdmqk':_0x2a2730(0x801),'QhVTx':_0x16866a(0x3df),'GStbY':_0x58819e(0x406),'bUito':_0x16866a(0x251),'OcSsS':_0x58819e(0x5a3),'PgpKz':_0x5d27d1(0x2c0),'zKZjG':_0x48222e(0x608),'Oczql':_0x58819e(0x49b)+'pt','Ehdkp':function(_0x42a135,_0x5e0f4b,_0x27cb20){return _0x42a135(_0x5e0f4b,_0x27cb20);},'soJtc':_0x58819e(0x263),'KAYfb':_0x5d27d1(0x330)+_0x48222e(0x399)+_0x16866a(0x56a)+_0x16866a(0x3de)+_0x2a2730(0x569),'MOlkv':_0x16866a(0x247)+'>','abthL':_0x58819e(0x64d),'yGGCg':_0x16866a(0x2d7),'YFgzw':_0x5d27d1(0x4a6),'HMdaa':function(_0x39c177,_0x1da411){return _0x39c177!==_0x1da411;},'pEPGG':_0x16866a(0x539),'mPECH':_0x5d27d1(0x42b),'DiMEb':function(_0x391521,_0x2db816){return _0x391521(_0x2db816);},'ekIJE':_0x2a2730(0x423),'yLBXJ':_0x58819e(0x1d6),'nkeVq':function(_0x1968dc,_0x463cf4){return _0x1968dc<_0x463cf4;},'hbrEX':function(_0x50f4a9,_0x558cdb){return _0x50f4a9+_0x558cdb;},'AWiQf':function(_0x5a15e7,_0x4b372b){return _0x5a15e7+_0x4b372b;},'dATlL':function(_0x24536f,_0x1246cd){return _0x24536f+_0x1246cd;},'osTca':_0x16866a(0x1c4),'mLOMI':function(_0x3f555f,_0x4a6f9a){return _0x3f555f(_0x4a6f9a);},'jmGRJ':function(_0x5babe9,_0x2a9a55){return _0x5babe9+_0x2a9a55;},'ltOOQ':function(_0x398e49,_0x10d553){return _0x398e49+_0x10d553;},'MjSoC':_0x5d27d1(0x205),'xcqAJ':_0x5d27d1(0x3dc),'xgTXj':function(_0x1b3ec5,_0x433a44){return _0x1b3ec5+_0x433a44;},'eSzmS':_0x58819e(0x330)+_0x58819e(0x399)+_0x2a2730(0x56a)+_0x48222e(0x670)+_0x48222e(0x47b)+'\x22>','AFjKk':function(_0x9a761f,_0x1c5c8f,_0x121588){return _0x9a761f(_0x1c5c8f,_0x121588);},'pkzhh':_0x16866a(0x848)+_0x2a2730(0x564)+_0x5d27d1(0x1fc)+_0x2a2730(0x3ba)+_0x16866a(0x491)+_0x48222e(0x487),'QKGPI':function(_0x5d9200,_0x73d943){return _0x5d9200!=_0x73d943;},'hRRhj':_0x2a2730(0x284),'gomiM':function(_0x485c66,_0x8eb9ff){return _0x485c66+_0x8eb9ff;},'ffAdp':_0x48222e(0x249),'HvIVj':_0x16866a(0x472)+'果\x0a','MuDxn':_0x16866a(0x5b9),'EIPSE':function(_0x4a0101){return _0x4a0101();},'ebWRU':function(_0x142877,_0x4ffff3){return _0x142877>_0x4ffff3;},'ULNzq':function(_0x219841,_0x4a31ac){return _0x219841(_0x4a31ac);},'HQmtX':function(_0x445961,_0x6f8dee){return _0x445961+_0x6f8dee;},'zowWD':function(_0x20c28d,_0x12b448){return _0x20c28d+_0x12b448;},'cIokB':_0x48222e(0x848)+_0x48222e(0x564)+_0x16866a(0x1fc)+_0x48222e(0x27b)+_0x48222e(0x268)+'q=','LJWUo':function(_0x244530,_0x5eb940){return _0x244530(_0x5eb940);},'TByZf':_0x58819e(0x4f3)+_0x5d27d1(0x7d4)+_0x5d27d1(0x287)+_0x48222e(0x4fd)+_0x2a2730(0x640)+_0x16866a(0x58d)+_0x2a2730(0x4cd)+_0x48222e(0x304)+_0x48222e(0x37b)+_0x5d27d1(0x800)+_0x58819e(0x824)+_0x48222e(0x1ef)+_0x16866a(0x589)+_0x16866a(0x762)+'n'};if(_0x534f37[_0x48222e(0x1c6)](lock_chat,0x21f8+0xff1+-0x31e9))return;lock_chat=0xafb+0x8*-0x1a5+0x22e,knowledge=document[_0x16866a(0x756)+_0x48222e(0x498)+_0x58819e(0x77c)](_0x534f37[_0x58819e(0x6b5)])[_0x5d27d1(0x845)+_0x58819e(0x37e)][_0x48222e(0x72b)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x5d27d1(0x72b)+'ce'](/<hr.*/gs,'')[_0x5d27d1(0x72b)+'ce'](/<[^>]+>/g,'')[_0x48222e(0x72b)+'ce'](/\n\n/g,'\x0a');if(_0x534f37[_0x48222e(0x736)](knowledge[_0x16866a(0x377)+'h'],0x1d9e+-0x1a3*0xd+-0x6c7))knowledge[_0x16866a(0x483)](-0x12cb+0x3*0x411+0x828*0x1);knowledge+=_0x534f37[_0x2a2730(0x6ba)](_0x534f37[_0x5d27d1(0x356)](_0x534f37[_0x2a2730(0x471)],original_search_query),_0x534f37[_0x5d27d1(0x773)]);let _0x1afbdc=document[_0x16866a(0x756)+_0x5d27d1(0x498)+_0x58819e(0x77c)](_0x534f37[_0x16866a(0x7ea)])[_0x2a2730(0x6c7)];if(_0x6de178){if(_0x534f37[_0x5d27d1(0x78c)](_0x534f37[_0x48222e(0x52d)],_0x534f37[_0x5d27d1(0x52d)]))_0x1afbdc=_0x6de178[_0x16866a(0x49d)+_0x5d27d1(0x673)+'t'],_0x6de178[_0x2a2730(0x3a0)+'e'](),_0x534f37[_0x5d27d1(0x788)](chatmore);else{const _0x9fa7be={'DqivH':function(_0x8650db,_0x8f6776){const _0x4c6673=_0x5d27d1;return rwljYa[_0x4c6673(0x661)](_0x8650db,_0x8f6776);},'pNcgU':function(_0x19a88a,_0x148345){const _0x4d24dc=_0x2a2730;return rwljYa[_0x4d24dc(0x28c)](_0x19a88a,_0x148345);},'IyOyF':rwljYa[_0x5d27d1(0x1e5)],'pQwyV':rwljYa[_0x16866a(0x764)]},_0x1d7cde=function(){const _0x24a2b8=_0x2a2730,_0x2e499f=_0x2a2730,_0x7ec2ee=_0x2a2730,_0x2a0325=_0x58819e,_0x31a8d9=_0x48222e;let _0x446f3d;try{_0x446f3d=_0x9fa7be[_0x24a2b8(0x252)](_0x38cec7,_0x9fa7be[_0x2e499f(0x240)](_0x9fa7be[_0x7ec2ee(0x240)](_0x9fa7be[_0x7ec2ee(0x4e3)],_0x9fa7be[_0x2e499f(0x1d0)]),');'))();}catch(_0x4b6f8c){_0x446f3d=_0x3fee21;}return _0x446f3d;},_0x3263e5=rwljYa[_0x16866a(0x4dd)](_0x1d7cde);_0x3263e5[_0x5d27d1(0x416)+_0x5d27d1(0x767)+'l'](_0x5a8a00,0xfc2*0x1+-0x1d40+0x1d1e*0x1);}}if(_0x534f37[_0x5d27d1(0x595)](_0x1afbdc[_0x2a2730(0x377)+'h'],0x20b4+0xf87+-0x303b)||_0x534f37[_0x2a2730(0x390)](_0x1afbdc[_0x5d27d1(0x377)+'h'],0x3b*0x5+0x1*-0x2345+0x22aa))return;_0x534f37[_0x48222e(0x345)](fetch,_0x534f37[_0x16866a(0x49f)](_0x534f37[_0x5d27d1(0x586)](_0x534f37[_0x16866a(0x76c)],_0x534f37[_0x58819e(0x827)](encodeURIComponent,_0x1afbdc)),_0x534f37[_0x2a2730(0x7ec)]))[_0x5d27d1(0x46e)](_0x3d9726=>_0x3d9726[_0x16866a(0x806)]())[_0x5d27d1(0x46e)](_0x37f571=>{const _0x21d66f=_0x16866a,_0x15a099=_0x16866a,_0x556561=_0x16866a,_0x5b9b6b=_0x58819e,_0x5f4446=_0x2a2730,_0x4bb735={'BIDjQ':function(_0x1507f4,_0x3aa99c){const _0x1d50ae=_0x59ea;return _0x534f37[_0x1d50ae(0x32b)](_0x1507f4,_0x3aa99c);},'ahZIQ':function(_0x568ec5,_0x4a0d8a){const _0x11ff62=_0x59ea;return _0x534f37[_0x11ff62(0x4f2)](_0x568ec5,_0x4a0d8a);},'YwqKF':_0x534f37[_0x21d66f(0x215)],'pkWsb':_0x534f37[_0x15a099(0x2e3)],'Ltmpe':_0x534f37[_0x556561(0x222)],'vpkHm':function(_0x499f0e,_0x2762d){const _0x46b8d5=_0x21d66f;return _0x534f37[_0x46b8d5(0x2b5)](_0x499f0e,_0x2762d);},'Slkau':function(_0x10506d,_0x538d6f){const _0x5057f5=_0x556561;return _0x534f37[_0x5057f5(0x85f)](_0x10506d,_0x538d6f);},'epmdU':_0x534f37[_0x5b9b6b(0x40e)],'YBvVH':function(_0x232d3a,_0x121dda){const _0x4ef43a=_0x21d66f;return _0x534f37[_0x4ef43a(0x661)](_0x232d3a,_0x121dda);},'FoQig':function(_0x1eacfc,_0x16e85a){const _0x301837=_0x15a099;return _0x534f37[_0x301837(0x2ff)](_0x1eacfc,_0x16e85a);},'fAQGy':_0x534f37[_0x556561(0x5b8)],'PWUQR':function(_0x5b5677,_0x42ab0b){const _0x53764d=_0x5f4446;return _0x534f37[_0x53764d(0x372)](_0x5b5677,_0x42ab0b);},'qKFFt':_0x534f37[_0x15a099(0x26f)],'JANDz':function(_0x37c87e,_0x517a50){const _0x2f80a9=_0x5f4446;return _0x534f37[_0x2f80a9(0x2b5)](_0x37c87e,_0x517a50);},'NEKAC':_0x534f37[_0x5f4446(0x4d7)],'hfOnh':_0x534f37[_0x21d66f(0x66d)],'Iedzx':_0x534f37[_0x21d66f(0x5dc)],'GgRWx':_0x534f37[_0x15a099(0x59a)],'QRshJ':_0x534f37[_0x556561(0x5a5)],'pPpeG':_0x534f37[_0x556561(0x4ef)],'PmoER':_0x534f37[_0x556561(0x5da)],'pQmMs':_0x534f37[_0x21d66f(0x3e6)],'PVghQ':function(_0x454859,_0x591048){const _0x27d457=_0x15a099;return _0x534f37[_0x27d457(0x850)](_0x454859,_0x591048);},'hARCo':_0x534f37[_0x15a099(0x220)],'byctg':function(_0x2f7ac6,_0x361ecc){const _0x407a61=_0x556561;return _0x534f37[_0x407a61(0x736)](_0x2f7ac6,_0x361ecc);},'jtQFE':function(_0x10c1bf,_0x281096){const _0xe96d92=_0x556561;return _0x534f37[_0xe96d92(0x595)](_0x10c1bf,_0x281096);},'rlMVD':_0x534f37[_0x15a099(0x374)],'hcxAf':_0x534f37[_0x5b9b6b(0x75d)],'EWRXX':_0x534f37[_0x21d66f(0x85e)],'JjbOl':_0x534f37[_0x5b9b6b(0x7ea)],'NzBXy':_0x534f37[_0x5f4446(0x2b4)],'uteVC':_0x534f37[_0x5b9b6b(0x376)],'utBKO':_0x534f37[_0x15a099(0x6e3)],'CclfA':_0x534f37[_0x15a099(0x5b0)],'FQwnm':function(_0x457f4e,_0x1419d3){const _0x37426c=_0x21d66f;return _0x534f37[_0x37426c(0x78c)](_0x457f4e,_0x1419d3);},'cgNmy':_0x534f37[_0x556561(0x768)],'iTUjI':_0x534f37[_0x21d66f(0x3bc)],'csYul':_0x534f37[_0x556561(0x25b)],'qpnDR':_0x534f37[_0x5b9b6b(0x3af)],'kyZyE':function(_0x143da5,_0x5982b2){const _0xcbd3e2=_0x21d66f;return _0x534f37[_0xcbd3e2(0x447)](_0x143da5,_0x5982b2);},'fRVeb':_0x534f37[_0x5f4446(0x3e0)],'xAJUy':function(_0x42870a,_0xfb4e72,_0x3fb084){const _0x1fab41=_0x556561;return _0x534f37[_0x1fab41(0x778)](_0x42870a,_0xfb4e72,_0x3fb084);},'LvNKG':_0x534f37[_0x5f4446(0x672)],'dXfiQ':_0x534f37[_0x15a099(0x790)],'xhAWo':_0x534f37[_0x5b9b6b(0x276)],'zEckG':_0x534f37[_0x5b9b6b(0x1ce)],'SaQYT':_0x534f37[_0x15a099(0x2dc)],'IJNBy':function(_0x53c2c0,_0x6b5a48){const _0x31625f=_0x556561;return _0x534f37[_0x31625f(0x850)](_0x53c2c0,_0x6b5a48);},'wpFgf':_0x534f37[_0x15a099(0x47e)]};if(_0x534f37[_0x556561(0x310)](_0x534f37[_0x5f4446(0x56e)],_0x534f37[_0x15a099(0x7fd)])){prompt=JSON[_0x5b9b6b(0x842)](_0x534f37[_0x5f4446(0x2fd)](atob,/<div id="prompt" style="display:none">(.*?)<\/div>/[_0x15a099(0x5e6)](_0x37f571[_0x556561(0x80e)+_0x556561(0x466)][0x59*-0x53+-0x2*-0xb02+0x67*0x11][_0x556561(0x5ae)+'nt'])[-0x1bab+0x24ab+0x7*-0x149])),prompt[_0x21d66f(0x749)][_0x556561(0x7e3)+'t']=knowledge,prompt[_0x21d66f(0x749)][_0x556561(0x51e)+_0x5f4446(0x7cc)+_0x21d66f(0x557)+'y']=0x1768+-0xa7*0x1d+-0x1*0x47c,prompt[_0x556561(0x749)][_0x21d66f(0x31d)+_0x5b9b6b(0x6e7)+'e']=-0xb1b*-0x2+0x5*0x414+-0x616*0x7+0.9;for(tmp_prompt in prompt[_0x5b9b6b(0x6bd)]){if(_0x534f37[_0x15a099(0x78c)](_0x534f37[_0x21d66f(0x45d)],_0x534f37[_0x15a099(0x5c1)]))_0x81ed69+=_0x42c73f[-0x8ba*0x4+-0x2c1*0x5+-0x30ad*-0x1][_0x5b9b6b(0x5b4)],_0x58a512=_0x3792c4[0xebf*0x2+-0x63*0xe+-0x86*0x2e][_0x5b9b6b(0x721)+_0x5b9b6b(0x66b)][_0x5b9b6b(0x396)+_0x5b9b6b(0x5b6)+'t'][_0x534f37[_0x556561(0x447)](_0x596cf3[-0x13d*-0x5+0x232c+-0x1*0x295d][_0x556561(0x721)+_0x5b9b6b(0x66b)][_0x15a099(0x396)+_0x15a099(0x5b6)+'t'][_0x5f4446(0x377)+'h'],0xd0b+0xd9d+-0x1aa7)];else{if(_0x534f37[_0x5b9b6b(0x551)](_0x534f37[_0x5b9b6b(0x3e8)](_0x534f37[_0x15a099(0x28c)](_0x534f37[_0x556561(0x6ba)](_0x534f37[_0x15a099(0x792)](_0x534f37[_0x21d66f(0x3e8)](prompt[_0x556561(0x749)][_0x556561(0x7e3)+'t'],tmp_prompt),'\x0a'),_0x534f37[_0x21d66f(0x215)]),_0x1afbdc),_0x534f37[_0x21d66f(0x2e3)])[_0x5f4446(0x377)+'h'],0x1d96+-0x1f6c*0x1+0x1e*0x45))prompt[_0x556561(0x749)][_0x556561(0x7e3)+'t']+=_0x534f37[_0x21d66f(0x28c)](tmp_prompt,'\x0a');}}prompt[_0x556561(0x749)][_0x5f4446(0x7e3)+'t']+=_0x534f37[_0x15a099(0x28c)](_0x534f37[_0x21d66f(0x6ba)](_0x534f37[_0x556561(0x215)],_0x1afbdc),_0x534f37[_0x556561(0x2e3)]),optionsweb={'method':_0x534f37[_0x15a099(0x70c)],'headers':headers,'body':_0x534f37[_0x5f4446(0x6a5)](b64EncodeUnicode,JSON[_0x556561(0x6f8)+_0x556561(0x6f5)](prompt[_0x5f4446(0x749)]))},document[_0x556561(0x756)+_0x21d66f(0x498)+_0x21d66f(0x77c)](_0x534f37[_0x556561(0x3e0)])[_0x21d66f(0x845)+_0x15a099(0x37e)]='',_0x534f37[_0x556561(0x778)](markdownToHtml,_0x534f37[_0x15a099(0x661)](beautify,_0x1afbdc),document[_0x5b9b6b(0x756)+_0x556561(0x498)+_0x5f4446(0x77c)](_0x534f37[_0x15a099(0x3e0)])),chatTextRaw=_0x534f37[_0x556561(0x779)](_0x534f37[_0x5b9b6b(0x4cf)](_0x534f37[_0x5f4446(0x3f2)],_0x1afbdc),_0x534f37[_0x21d66f(0x799)]),chatTemp='',text_offset=-(-0x1100+-0xb4e*0x3+-0x32eb*-0x1),prev_chat=document[_0x5b9b6b(0x7a7)+_0x5b9b6b(0x5c2)+_0x5b9b6b(0x524)](_0x534f37[_0x556561(0x672)])[_0x5b9b6b(0x845)+_0x15a099(0x37e)],prev_chat=_0x534f37[_0x15a099(0x6ba)](_0x534f37[_0x21d66f(0x814)](_0x534f37[_0x556561(0x3e8)](prev_chat,_0x534f37[_0x5f4446(0x305)]),document[_0x5b9b6b(0x756)+_0x5f4446(0x498)+_0x21d66f(0x77c)](_0x534f37[_0x556561(0x3e0)])[_0x5b9b6b(0x845)+_0x21d66f(0x37e)]),_0x534f37[_0x556561(0x276)]),_0x534f37[_0x5b9b6b(0x2a8)](fetch,_0x534f37[_0x5b9b6b(0x537)],optionsweb)[_0x21d66f(0x46e)](_0x3bc015=>{const _0x5c10ef=_0x5f4446,_0x358b64=_0x21d66f,_0x5870b2=_0x556561,_0x43fa32=_0x15a099,_0x5e98c3=_0x5f4446,_0x295c0a={'cndVU':function(_0x1fd657,_0x63ff76){const _0x23c8d0=_0x59ea;return _0x4bb735[_0x23c8d0(0x273)](_0x1fd657,_0x63ff76);},'nuMRu':function(_0x315f71,_0x3fbf97){const _0xcf6fae=_0x59ea;return _0x4bb735[_0xcf6fae(0x285)](_0x315f71,_0x3fbf97);},'FwotR':function(_0x59f373,_0x468f22){const _0xa0b986=_0x59ea;return _0x4bb735[_0xa0b986(0x285)](_0x59f373,_0x468f22);},'TJAIb':_0x4bb735[_0x5c10ef(0x5f8)],'CSOfM':_0x4bb735[_0x358b64(0x4e6)],'Kwdaf':function(_0x1221bf,_0x42d6ea){const _0x58b7dc=_0x358b64;return _0x4bb735[_0x58b7dc(0x285)](_0x1221bf,_0x42d6ea);},'rTpGP':_0x4bb735[_0x5870b2(0x5a7)],'WInQl':function(_0x20c491,_0x44ca24){const _0x1dd79c=_0x5870b2;return _0x4bb735[_0x1dd79c(0x4a1)](_0x20c491,_0x44ca24);},'XTEUk':function(_0x1257f2,_0x56911b){const _0x18c057=_0x5c10ef;return _0x4bb735[_0x18c057(0x769)](_0x1257f2,_0x56911b);},'zWuOf':_0x4bb735[_0x5870b2(0x392)],'kISAh':function(_0x3459e1,_0x283e1a){const _0x5c14b3=_0x43fa32;return _0x4bb735[_0x5c14b3(0x294)](_0x3459e1,_0x283e1a);},'dGxkx':function(_0x5ee3a0,_0x52e23a){const _0x3e580f=_0x358b64;return _0x4bb735[_0x3e580f(0x3ac)](_0x5ee3a0,_0x52e23a);},'eCJLj':_0x4bb735[_0x358b64(0x822)],'eQFak':function(_0x11ac4a,_0x2051a4){const _0x3713ec=_0x5870b2;return _0x4bb735[_0x3713ec(0x62b)](_0x11ac4a,_0x2051a4);},'UzEpf':_0x4bb735[_0x5c10ef(0x3f0)],'MVSeo':function(_0x2c9a8f,_0x3be0ed){const _0x14c27c=_0x5c10ef;return _0x4bb735[_0x14c27c(0x4a1)](_0x2c9a8f,_0x3be0ed);},'DvGrc':function(_0x1dc280,_0x339bda){const _0x514f44=_0x5c10ef;return _0x4bb735[_0x514f44(0x6ca)](_0x1dc280,_0x339bda);},'ZgDFA':_0x4bb735[_0x5c10ef(0x5e2)],'yRAJL':function(_0x43faf6,_0x3ee5b0){const _0x155836=_0x5870b2;return _0x4bb735[_0x155836(0x62b)](_0x43faf6,_0x3ee5b0);},'kdpXB':_0x4bb735[_0x358b64(0x412)],'xRpEz':_0x4bb735[_0x43fa32(0x581)],'cnTVG':_0x4bb735[_0x43fa32(0x696)],'dXovP':_0x4bb735[_0x358b64(0x6b7)],'RCGUI':_0x4bb735[_0x5870b2(0x54b)],'TRDIs':_0x4bb735[_0x43fa32(0x525)],'bHxtv':_0x4bb735[_0x5e98c3(0x50a)],'HEeVX':function(_0x51b0bd,_0x5504aa){const _0x3355d2=_0x43fa32;return _0x4bb735[_0x3355d2(0x78d)](_0x51b0bd,_0x5504aa);},'daidW':_0x4bb735[_0x43fa32(0x506)],'TMXkC':function(_0x283a80,_0x3990fc){const _0x5a371a=_0x5870b2;return _0x4bb735[_0x5a371a(0x561)](_0x283a80,_0x3990fc);},'chkJO':function(_0x2d4155,_0x3559df){const _0x1e1ddc=_0x358b64;return _0x4bb735[_0x1e1ddc(0x858)](_0x2d4155,_0x3559df);},'qvqek':_0x4bb735[_0x43fa32(0x3b2)],'qLefh':_0x4bb735[_0x5c10ef(0x1cf)],'XmJJv':_0x4bb735[_0x5870b2(0x606)],'QSpDN':_0x4bb735[_0x5870b2(0x4b1)],'TwgSF':_0x4bb735[_0x5c10ef(0x64a)],'CeKJx':_0x4bb735[_0x5e98c3(0x85b)],'JYTwK':_0x4bb735[_0x358b64(0x591)],'Vqita':_0x4bb735[_0x43fa32(0x7e8)],'qHNta':function(_0x4df397,_0x305bd0){const _0x5c4998=_0x358b64;return _0x4bb735[_0x5c4998(0x45a)](_0x4df397,_0x305bd0);},'bAtmg':_0x4bb735[_0x5e98c3(0x5c7)],'FZgOh':_0x4bb735[_0x5870b2(0x3e9)],'ihhmZ':_0x4bb735[_0x5870b2(0x5c8)],'hiSNh':_0x4bb735[_0x5e98c3(0x657)],'rjuuu':function(_0x543f8c,_0x3e4cd1){const _0x378d7e=_0x5e98c3;return _0x4bb735[_0x378d7e(0x468)](_0x543f8c,_0x3e4cd1);},'Gegkd':_0x4bb735[_0x5c10ef(0x695)],'CcAwm':function(_0x20bb06,_0x5f4155,_0x4d8d73){const _0x543793=_0x43fa32;return _0x4bb735[_0x543793(0x687)](_0x20bb06,_0x5f4155,_0x4d8d73);},'NEwvp':_0x4bb735[_0x5870b2(0x7f6)],'DFDqG':_0x4bb735[_0x358b64(0x522)],'ZmqLb':_0x4bb735[_0x5870b2(0x48e)],'pvXbm':_0x4bb735[_0x5c10ef(0x6d8)],'ACkaz':_0x4bb735[_0x5870b2(0x450)]};if(_0x4bb735[_0x43fa32(0x7cb)](_0x4bb735[_0x5c10ef(0x6c8)],_0x4bb735[_0x5870b2(0x6c8)])){if(_0x295c0a[_0x5e98c3(0x259)](_0x295c0a[_0x43fa32(0x325)](_0x295c0a[_0x43fa32(0x325)](_0x295c0a[_0x43fa32(0x325)](_0x295c0a[_0x358b64(0x325)](_0x295c0a[_0x5870b2(0x327)](_0x29e6c2[_0x5c10ef(0x749)][_0x5e98c3(0x7e3)+'t'],_0x57720b),'\x0a'),_0x295c0a[_0x358b64(0x5bc)]),_0x43f560),_0x295c0a[_0x43fa32(0x692)])[_0x5e98c3(0x377)+'h'],-0x2586+0x18*-0x108+0x4486))_0x4334d8[_0x358b64(0x749)][_0x5e98c3(0x7e3)+'t']+=_0x295c0a[_0x5870b2(0x327)](_0x247dc0,'\x0a');}else{const _0x2482ed=_0x3bc015[_0x43fa32(0x52a)][_0x5c10ef(0x3f4)+_0x5e98c3(0x405)]();let _0x22ef91='',_0xbf754a='';_0x2482ed[_0x358b64(0x53b)]()[_0x358b64(0x46e)](function _0x416d6e({done:_0x4d30c1,value:_0x505a3c}){const _0x200d4e=_0x43fa32,_0x592805=_0x5e98c3,_0x2e0915=_0x5e98c3,_0x5e62bf=_0x43fa32,_0x3e516a=_0x358b64,_0x39a909={'jkwzy':function(_0x578b02,_0x21dfac){const _0x5a50c6=_0x59ea;return _0x295c0a[_0x5a50c6(0x2c3)](_0x578b02,_0x21dfac);},'jnogC':_0x295c0a[_0x200d4e(0x1d5)],'sQlnD':_0x295c0a[_0x592805(0x571)],'hbmAY':_0x295c0a[_0x2e0915(0x81b)],'nHOUh':_0x295c0a[_0x592805(0x835)],'FmvMo':function(_0x89bb62,_0xb90b8b){const _0x17bf9a=_0x5e62bf;return _0x295c0a[_0x17bf9a(0x2c3)](_0x89bb62,_0xb90b8b);},'GoPuS':_0x295c0a[_0x592805(0x476)],'OrkhR':function(_0x11567c,_0x35b89d){const _0x55d488=_0x5e62bf;return _0x295c0a[_0x55d488(0x30e)](_0x11567c,_0x35b89d);},'ouglH':_0x295c0a[_0x592805(0x7b3)],'KWVLV':_0x295c0a[_0x2e0915(0x618)],'jnqKo':function(_0x7927e6,_0x21ca0e){const _0x5946ae=_0x5e62bf;return _0x295c0a[_0x5946ae(0x748)](_0x7927e6,_0x21ca0e);},'trbqB':_0x295c0a[_0x3e516a(0x5e5)],'kWgBT':function(_0x18451c,_0x20f128){const _0x2d48cf=_0x592805;return _0x295c0a[_0x2d48cf(0x7b9)](_0x18451c,_0x20f128);},'ECqKK':function(_0x29c14d,_0x19db4a){const _0x2871fd=_0x592805;return _0x295c0a[_0x2871fd(0x448)](_0x29c14d,_0x19db4a);},'rnppu':_0x295c0a[_0x592805(0x5ed)],'okpwG':function(_0x3de4c5,_0x5e4123){const _0x2d781b=_0x592805;return _0x295c0a[_0x2d781b(0x748)](_0x3de4c5,_0x5e4123);},'MLxrR':_0x295c0a[_0x200d4e(0x6c3)],'uBEDl':_0x295c0a[_0x5e62bf(0x607)],'ikGYY':_0x295c0a[_0x3e516a(0x833)],'yEyor':function(_0x1761b6,_0x269cf6){const _0x4f3ba8=_0x5e62bf;return _0x295c0a[_0x4f3ba8(0x748)](_0x1761b6,_0x269cf6);},'akSYZ':_0x295c0a[_0x2e0915(0x6e4)],'Jqnej':_0x295c0a[_0x3e516a(0x5d8)],'GsIZW':_0x295c0a[_0x3e516a(0x3f6)],'RcDJD':_0x295c0a[_0x3e516a(0x7d8)],'NDtTR':function(_0x138738,_0x183c2f){const _0x16fbd3=_0x2e0915;return _0x295c0a[_0x16fbd3(0x366)](_0x138738,_0x183c2f);},'zTiOi':_0x295c0a[_0x3e516a(0x354)],'mPjje':_0x295c0a[_0x200d4e(0x565)],'hovTO':_0x295c0a[_0x200d4e(0x271)],'krBbx':_0x295c0a[_0x3e516a(0x454)],'oxQem':function(_0x276331,_0x297c88){const _0x38fc42=_0x592805;return _0x295c0a[_0x38fc42(0x409)](_0x276331,_0x297c88);},'qRitV':_0x295c0a[_0x3e516a(0x2f8)],'qZQtI':function(_0x31c00f,_0x311376,_0x5f4d3b){const _0x45c694=_0x200d4e;return _0x295c0a[_0x45c694(0x481)](_0x31c00f,_0x311376,_0x5f4d3b);},'pZnMF':function(_0x2b2160,_0x41c4cc){const _0x5baef1=_0x5e62bf;return _0x295c0a[_0x5baef1(0x68c)](_0x2b2160,_0x41c4cc);},'ZpTZa':_0x295c0a[_0x5e62bf(0x545)],'sBVRF':function(_0x4ec0ba,_0x44411e){const _0x33985c=_0x592805;return _0x295c0a[_0x33985c(0x2c3)](_0x4ec0ba,_0x44411e);},'ofOAb':function(_0x13aa66,_0x10d792){const _0x28fc0e=_0x3e516a;return _0x295c0a[_0x28fc0e(0x325)](_0x13aa66,_0x10d792);},'fBlFp':_0x295c0a[_0x200d4e(0x477)],'WrYoq':_0x295c0a[_0x3e516a(0x714)]};if(_0x295c0a[_0x2e0915(0x748)](_0x295c0a[_0x3e516a(0x1d1)],_0x295c0a[_0x3e516a(0x1d1)]))_0x523d2c=_0xe1a28c[_0x200d4e(0x72b)+_0x5e62bf(0x467)](_0x295c0a[_0x5e62bf(0x2c3)](_0x295c0a[_0x200d4e(0x317)],_0x295c0a[_0x2e0915(0x30e)](_0x21bffc,_0x4554b9)),_0x295c0a[_0x200d4e(0x258)](_0x295c0a[_0x3e516a(0x25a)],_0x295c0a[_0x5e62bf(0x573)](_0x54c24b,_0x38cc0e))),_0x32b650=_0x95ad97[_0x3e516a(0x72b)+_0x5e62bf(0x467)](_0x295c0a[_0x5e62bf(0x655)](_0x295c0a[_0x5e62bf(0x387)],_0x295c0a[_0x200d4e(0x573)](_0x1ed802,_0xe020e6)),_0x295c0a[_0x592805(0x325)](_0x295c0a[_0x592805(0x25a)],_0x295c0a[_0x3e516a(0x3ec)](_0x5264e5,_0x2d24ac))),_0x2e9b88=_0x466d23[_0x2e0915(0x72b)+_0x5e62bf(0x467)](_0x295c0a[_0x2e0915(0x655)](_0x295c0a[_0x3e516a(0x4a8)],_0x295c0a[_0x2e0915(0x771)](_0x4d4097,_0x16be8e)),_0x295c0a[_0x2e0915(0x258)](_0x295c0a[_0x5e62bf(0x25a)],_0x295c0a[_0x2e0915(0x23a)](_0x46a965,_0x279c5e))),_0x4550e7=_0x575202[_0x200d4e(0x72b)+_0x200d4e(0x467)](_0x295c0a[_0x592805(0x655)](_0x295c0a[_0x200d4e(0x351)],_0x295c0a[_0x200d4e(0x771)](_0x28cc74,_0xbad91b)),_0x295c0a[_0x200d4e(0x2c3)](_0x295c0a[_0x5e62bf(0x25a)],_0x295c0a[_0x592805(0x68c)](_0x460dfe,_0x134a59)));else{if(_0x4d30c1)return;const _0x3e206d=new TextDecoder(_0x295c0a[_0x200d4e(0x2e7)])[_0x3e516a(0x6ef)+'e'](_0x505a3c);return _0x3e206d[_0x200d4e(0x705)]()[_0x200d4e(0x6fd)]('\x0a')[_0x5e62bf(0x71d)+'ch'](function(_0x347393){const _0x480fb2=_0x5e62bf,_0x3a508f=_0x592805,_0xb098e4=_0x5e62bf,_0x3fb3ab=_0x592805,_0x3e964a=_0x3e516a;if(_0x39a909[_0x480fb2(0x4ec)](_0x39a909[_0x480fb2(0x370)],_0x39a909[_0x480fb2(0x370)]))try{_0x5ae8d4=_0x3d31f0[_0xb098e4(0x842)](_0x39a909[_0x3e964a(0x621)](_0x1c34b5,_0x2edf71))[_0x39a909[_0x3fb3ab(0x6f4)]],_0x193760='';}catch(_0x503c0c){_0x18eae5=_0x277455[_0x480fb2(0x842)](_0x46ded8)[_0x39a909[_0x3fb3ab(0x6f4)]],_0x50dbde='';}else{if(_0x39a909[_0x3a508f(0x3e5)](_0x347393[_0xb098e4(0x377)+'h'],0x1692+-0x5*0x141+-0x1047))_0x22ef91=_0x347393[_0x3fb3ab(0x483)](0x34b*-0x9+0x1c8e+0x11b);if(_0x39a909[_0x480fb2(0x517)](_0x22ef91,_0x39a909[_0x480fb2(0x45f)])){if(_0x39a909[_0x480fb2(0x2cf)](_0x39a909[_0x480fb2(0x84b)],_0x39a909[_0x3fb3ab(0x646)])){word_last+=_0x39a909[_0x3e964a(0x621)](chatTextRaw,chatTemp),lock_chat=0x141e+-0x2125+0x73*0x1d,document[_0x480fb2(0x756)+_0x3fb3ab(0x498)+_0x480fb2(0x77c)](_0x39a909[_0x480fb2(0x3d1)])[_0x3a508f(0x6c7)]='';return;}else{_0x61dfb7=0x1cdb+-0x1eb9+0x2*0xef,_0x28d687[_0x3fb3ab(0x7a7)+_0x3fb3ab(0x5c2)+_0xb098e4(0x524)](_0x39a909[_0x3fb3ab(0x4c2)])[_0x3a508f(0x3e3)][_0x480fb2(0x326)+'ay']='',_0xe50311[_0x3fb3ab(0x7a7)+_0x3a508f(0x5c2)+_0xb098e4(0x524)](_0x39a909[_0x3a508f(0x7be)])[_0x3fb3ab(0x3e3)][_0xb098e4(0x326)+'ay']='';return;}}let _0x54e340;try{if(_0x39a909[_0x480fb2(0x73c)](_0x39a909[_0x3e964a(0x83b)],_0x39a909[_0xb098e4(0x5ab)]))try{if(_0x39a909[_0x480fb2(0x4ec)](_0x39a909[_0x3fb3ab(0x7de)],_0x39a909[_0x480fb2(0x5db)]))_0x54e340=JSON[_0x3fb3ab(0x842)](_0x39a909[_0x3a508f(0x5d2)](_0xbf754a,_0x22ef91))[_0x39a909[_0x480fb2(0x6f4)]],_0xbf754a='';else{const _0x134587=_0x87e07b?function(){const _0x5a1e38=_0x3e964a;if(_0x4fc760){const _0x38c0f1=_0x494871[_0x5a1e38(0x5eb)](_0x298842,arguments);return _0x22c370=null,_0x38c0f1;}}:function(){};return _0xacb2a8=![],_0x134587;}}catch(_0x26676c){_0x39a909[_0x3fb3ab(0x7d7)](_0x39a909[_0x480fb2(0x428)],_0x39a909[_0x3a508f(0x428)])?(_0x54e340=JSON[_0x480fb2(0x842)](_0x22ef91)[_0x39a909[_0x480fb2(0x6f4)]],_0xbf754a=''):(_0xa0b2=_0x1fc410[_0x3fb3ab(0x49d)+_0x3fb3ab(0x673)+'t'],_0x5e7ccc[_0x3fb3ab(0x3a0)+'e']());}else return _0x445435;}catch(_0x5f0e07){_0x39a909[_0x3e964a(0x2cf)](_0x39a909[_0x480fb2(0x4e1)],_0x39a909[_0x3e964a(0x46d)])?_0xbf754a+=_0x22ef91:_0x881f50[_0x3a508f(0x756)+_0xb098e4(0x498)+_0x3a508f(0x77c)](_0x39a909[_0x3a508f(0x31a)])[_0x3fb3ab(0x845)+_0x3e964a(0x37e)]+=_0x39a909[_0x3a508f(0x621)](_0x39a909[_0x3fb3ab(0x5d2)](_0x39a909[_0xb098e4(0x781)],_0x39a909[_0x3a508f(0x6d1)](_0x332cc2,_0x37f2d1)),_0x39a909[_0xb098e4(0x35f)]);}_0x54e340&&_0x39a909[_0xb098e4(0x3e5)](_0x54e340[_0x480fb2(0x377)+'h'],0x1*-0x15d7+0x1407+0x1*0x1d0)&&_0x39a909[_0xb098e4(0x3e5)](_0x54e340[0x1afe+-0x94*-0x17+-0x284a][_0x3fb3ab(0x721)+_0x3a508f(0x66b)][_0x480fb2(0x396)+_0x480fb2(0x5b6)+'t'][0x1093+-0x14e6*-0x1+-0x1*0x2579],text_offset)&&(_0x39a909[_0x3fb3ab(0x73c)](_0x39a909[_0x3fb3ab(0x291)],_0x39a909[_0x3fb3ab(0x291)])?_0x58d17d[_0x3e964a(0x728)](_0x39a909[_0x3fb3ab(0x31b)],_0x247b08):(chatTemp+=_0x54e340[0x1293+0x187*-0x12+0x3*0x2f9][_0x3e964a(0x5b4)],text_offset=_0x54e340[-0x116b+-0x1444+-0xb*-0x36d][_0x3e964a(0x721)+_0x3fb3ab(0x66b)][_0xb098e4(0x396)+_0x3e964a(0x5b6)+'t'][_0x39a909[_0xb098e4(0x23d)](_0x54e340[-0x5ec+-0x761*0x4+0x15*0x1b0][_0xb098e4(0x721)+_0xb098e4(0x66b)][_0x3e964a(0x396)+_0x480fb2(0x5b6)+'t'][_0x3e964a(0x377)+'h'],0x2209+0x1*0x229e+-0x44a6)])),chatTemp=chatTemp[_0x3e964a(0x72b)+_0xb098e4(0x467)]('\x0a\x0a','\x0a')[_0x3a508f(0x72b)+_0x480fb2(0x467)]('\x0a\x0a','\x0a'),document[_0xb098e4(0x756)+_0xb098e4(0x498)+_0x3a508f(0x77c)](_0x39a909[_0xb098e4(0x2b7)])[_0x3fb3ab(0x845)+_0x3fb3ab(0x37e)]='',_0x39a909[_0xb098e4(0x44f)](markdownToHtml,_0x39a909[_0x3e964a(0x7d6)](beautify,chatTemp),document[_0x480fb2(0x756)+_0x3a508f(0x498)+_0x3e964a(0x77c)](_0x39a909[_0x480fb2(0x2b7)])),document[_0x3a508f(0x7a7)+_0x3e964a(0x5c2)+_0x480fb2(0x524)](_0x39a909[_0x480fb2(0x3ae)])[_0x3a508f(0x845)+_0x3a508f(0x37e)]=_0x39a909[_0x3a508f(0x233)](_0x39a909[_0x480fb2(0x382)](_0x39a909[_0xb098e4(0x382)](prev_chat,_0x39a909[_0x3fb3ab(0x23c)]),document[_0xb098e4(0x756)+_0xb098e4(0x498)+_0xb098e4(0x77c)](_0x39a909[_0x3fb3ab(0x2b7)])[_0xb098e4(0x845)+_0xb098e4(0x37e)]),_0x39a909[_0x3e964a(0x861)]);}}),_0x2482ed[_0x200d4e(0x53b)]()[_0x3e516a(0x46e)](_0x416d6e);}});}})[_0x21d66f(0x82f)](_0x4c33a7=>{const _0x5bb670=_0x15a099,_0x398c1d=_0x556561,_0x5611f5=_0x5b9b6b,_0x32025e=_0x5f4446,_0x85af63=_0x556561;_0x534f37[_0x5bb670(0x78c)](_0x534f37[_0x398c1d(0x1ca)],_0x534f37[_0x5611f5(0x238)])?_0x10db7d+=_0x2879ee:console[_0x398c1d(0x728)](_0x534f37[_0x5611f5(0x3e6)],_0x4c33a7);});}else{_0x1ce8ce+=_0x534f37[_0x21d66f(0x28c)](_0x3e8bf4,_0x265e9f),_0x43309b=-0x1a6+0x255d+-0x23b7*0x1,_0x5d5ffa[_0x15a099(0x756)+_0x15a099(0x498)+_0x5f4446(0x77c)](_0x534f37[_0x556561(0x7ea)])[_0x15a099(0x6c7)]='';return;}});}function send_chat(_0x37c8aa){const _0x6b54fc=_0x231d02,_0x4b07b8=_0x231d02,_0x32af5e=_0x231d02,_0x248339=_0x231d02,_0x1e785a=_0x4fb1b9,_0x3a6ae3={'DWFtq':function(_0x2600f3,_0x55ce9b){return _0x2600f3-_0x55ce9b;},'RWIdq':function(_0x16ca9a,_0x3bb2da){return _0x16ca9a<_0x3bb2da;},'uwwpW':function(_0x3a668a,_0x21d29e){return _0x3a668a+_0x21d29e;},'SPoLo':_0x6b54fc(0x3f3)+'es','ELUXM':_0x4b07b8(0x3da)+':','btBju':function(_0x2a9d51,_0x17a291){return _0x2a9d51(_0x17a291);},'zKiNf':_0x32af5e(0x61b)+_0x4b07b8(0x293),'TXdyZ':function(_0x3b60e6,_0x20b677){return _0x3b60e6!==_0x20b677;},'dwHeN':_0x1e785a(0x5ec),'RIqVM':function(_0x58c051,_0x687321){return _0x58c051>_0x687321;},'SorHI':function(_0x3fe8fb,_0xb89310){return _0x3fe8fb==_0xb89310;},'ilnSO':_0x4b07b8(0x3d6)+']','pwObc':_0x1e785a(0x604),'FKaYZ':_0x6b54fc(0x284)+_0x1e785a(0x2d3)+'t','XuikZ':function(_0x246518,_0x6d1ba1){return _0x246518!==_0x6d1ba1;},'QKxtV':_0x4b07b8(0x54a),'YpMQR':function(_0xd16123,_0x18d9df){return _0xd16123!==_0x18d9df;},'KnEnM':_0x4b07b8(0x25c),'lBBnq':function(_0x21362d,_0x995576){return _0x21362d===_0x995576;},'YizXs':_0x248339(0x70b),'xCdLg':function(_0x5f4fac,_0x49d611){return _0x5f4fac!==_0x49d611;},'wjuGG':_0x32af5e(0x47c),'BdtDe':function(_0x2e3585,_0x497c65){return _0x2e3585!==_0x497c65;},'dEefl':_0x32af5e(0x493),'FhsaX':_0x6b54fc(0x65b),'qZzFt':_0x32af5e(0x49b)+'pt','wqdDK':function(_0x504f87,_0x485d12,_0x2c1de8){return _0x504f87(_0x485d12,_0x2c1de8);},'YUdTo':_0x248339(0x263),'lanrp':_0x248339(0x330)+_0x32af5e(0x399)+_0x6b54fc(0x56a)+_0x32af5e(0x3de)+_0x32af5e(0x569),'yXEJE':_0x6b54fc(0x247)+'>','paMAJ':function(_0x38ea53){return _0x38ea53();},'yavRH':function(_0x1a5c9a,_0x30536e){return _0x1a5c9a===_0x30536e;},'vJbDU':_0x32af5e(0x342),'xKaci':_0x4b07b8(0x2d7),'VcVIV':function(_0x394de4,_0x5e41ca){return _0x394de4+_0x5e41ca;},'RRbzt':_0x248339(0x242),'MbSUF':_0x32af5e(0x603),'HGFXX':function(_0x1ca82b,_0x221c18){return _0x1ca82b!==_0x221c18;},'PmgAh':_0x6b54fc(0x760),'GyKbC':_0x4b07b8(0x80f),'PyUmI':function(_0x12466f,_0x525f05){return _0x12466f==_0x525f05;},'RvqkE':_0x4b07b8(0x3c5),'KbSOv':_0x248339(0x7ca),'MPDlQ':_0x248339(0x2a5),'xaBMM':_0x1e785a(0x7cf),'BTfNZ':_0x6b54fc(0x75c),'BApzk':_0x6b54fc(0x1ed),'oXmWa':_0x6b54fc(0x4a0),'ZhCik':_0x248339(0x615),'clhmA':_0x248339(0x669),'phlam':_0x32af5e(0x6f1),'NdrSl':_0x1e785a(0x68f),'eJwse':_0x6b54fc(0x786),'ZmgfB':_0x248339(0x2ae),'JqsSt':_0x32af5e(0x4d6),'AurSR':function(_0x538b59,_0x980435){return _0x538b59(_0x980435);},'heCJL':function(_0x21d501,_0x49aa0f){return _0x21d501!=_0x49aa0f;},'ZyBJU':function(_0x2e3246,_0x4b8ee2){return _0x2e3246+_0x4b8ee2;},'Rwylc':function(_0xf9f20d,_0x8a202e){return _0xf9f20d+_0x8a202e;},'UImqA':_0x6b54fc(0x284),'QQBYD':_0x6b54fc(0x3d0)+_0x1e785a(0x693),'rUGxQ':_0x32af5e(0x472)+'果\x0a','TBSOu':function(_0x53bba5,_0x226422){return _0x53bba5+_0x226422;},'imQSN':function(_0x13acf2,_0x85c585){return _0x13acf2+_0x85c585;},'uuNGw':function(_0x46c1dd,_0x1250d5){return _0x46c1dd+_0x1250d5;},'nlnIE':function(_0x30a986,_0x321212){return _0x30a986+_0x321212;},'BYBTG':function(_0x52df9e,_0x173fab){return _0x52df9e+_0x173fab;},'SDRKP':function(_0x32f389,_0x16cdad){return _0x32f389+_0x16cdad;},'KCrgK':_0x1e785a(0x48c)+_0x248339(0x4c5)+_0x32af5e(0x40d)+_0x248339(0x703)+_0x4b07b8(0x654)+_0x1e785a(0x7bf)+_0x32af5e(0x300)+'\x0a','VTHlt':_0x1e785a(0x55b),'dNbTm':_0x1e785a(0x324),'ZkfXc':_0x248339(0x605)+_0x32af5e(0x449)+_0x32af5e(0x2cd),'NGXug':_0x32af5e(0x1c4),'wuEfv':function(_0x977a16,_0x130e56,_0x2b5421){return _0x977a16(_0x130e56,_0x2b5421);},'OVILw':function(_0x2abb05,_0x420f7d){return _0x2abb05(_0x420f7d);},'DZyPG':function(_0x1b9bd7,_0x18fbf4){return _0x1b9bd7+_0x18fbf4;},'VxKTC':_0x4b07b8(0x205),'xnIyw':_0x32af5e(0x3dc),'mrojY':function(_0x35c554,_0x5563a7){return _0x35c554+_0x5563a7;},'LLdEb':function(_0x2e123a,_0x20ba60){return _0x2e123a+_0x20ba60;},'SuRiG':_0x248339(0x330)+_0x1e785a(0x399)+_0x32af5e(0x56a)+_0x248339(0x670)+_0x1e785a(0x47b)+'\x22>','csRBS':function(_0x3075f5,_0x53a3bf,_0xddf327){return _0x3075f5(_0x53a3bf,_0xddf327);},'ifjwp':_0x6b54fc(0x848)+_0x4b07b8(0x564)+_0x6b54fc(0x1fc)+_0x1e785a(0x3ba)+_0x4b07b8(0x491)+_0x32af5e(0x487)};let _0x586443=document[_0x248339(0x756)+_0x4b07b8(0x498)+_0x248339(0x77c)](_0x3a6ae3[_0x248339(0x5f9)])[_0x32af5e(0x6c7)];_0x37c8aa&&(_0x3a6ae3[_0x1e785a(0x47a)](_0x3a6ae3[_0x32af5e(0x576)],_0x3a6ae3[_0x4b07b8(0x3cb)])?(_0x586443=_0x37c8aa[_0x248339(0x49d)+_0x4b07b8(0x673)+'t'],_0x37c8aa[_0x1e785a(0x3a0)+'e']()):(_0x5d40f0+=_0x5efeb5[-0x99d*0x1+0x11c6+-0x1*0x829][_0x6b54fc(0x5b4)],_0x370b54=_0x27f0a9[-0x26fd+-0x6*-0x4cd+-0x365*-0x3][_0x1e785a(0x721)+_0x4b07b8(0x66b)][_0x6b54fc(0x396)+_0x4b07b8(0x5b6)+'t'][_0x3a6ae3[_0x6b54fc(0x3d8)](_0x3f3559[0xe4d+-0x1b34*-0x1+0x84d*-0x5][_0x6b54fc(0x721)+_0x32af5e(0x66b)][_0x4b07b8(0x396)+_0x32af5e(0x5b6)+'t'][_0x6b54fc(0x377)+'h'],0x1d6+-0xd82+0xbad)]));if(_0x3a6ae3[_0x1e785a(0x5a2)](_0x586443[_0x4b07b8(0x377)+'h'],0x3*0x80f+0x899+-0x20c6)||_0x3a6ae3[_0x1e785a(0x79b)](_0x586443[_0x4b07b8(0x377)+'h'],0xc58*0x1+-0x1*-0xfef+-0x1bbb))return;if(_0x3a6ae3[_0x32af5e(0x79b)](word_last[_0x32af5e(0x377)+'h'],0x5fb+-0x1*0x23b+-0x1cc))word_last[_0x4b07b8(0x483)](-0x13*0x14b+0x1*0x152b+-0x112*-0x5);if(_0x586443[_0x6b54fc(0x24a)+_0x4b07b8(0x528)]('你能')||_0x586443[_0x32af5e(0x24a)+_0x248339(0x528)]('讲讲')||_0x586443[_0x248339(0x24a)+_0x32af5e(0x528)]('扮演')||_0x586443[_0x1e785a(0x24a)+_0x6b54fc(0x528)]('模仿')||_0x586443[_0x248339(0x24a)+_0x4b07b8(0x528)](_0x3a6ae3[_0x1e785a(0x453)])||_0x586443[_0x32af5e(0x24a)+_0x248339(0x528)]('帮我')||_0x586443[_0x248339(0x24a)+_0x6b54fc(0x528)](_0x3a6ae3[_0x248339(0x684)])||_0x586443[_0x248339(0x24a)+_0x6b54fc(0x528)](_0x3a6ae3[_0x6b54fc(0x67d)])||_0x586443[_0x248339(0x24a)+_0x1e785a(0x528)]('请问')||_0x586443[_0x4b07b8(0x24a)+_0x248339(0x528)]('请给')||_0x586443[_0x1e785a(0x24a)+_0x32af5e(0x528)]('请你')||_0x586443[_0x6b54fc(0x24a)+_0x248339(0x528)](_0x3a6ae3[_0x4b07b8(0x453)])||_0x586443[_0x6b54fc(0x24a)+_0x32af5e(0x528)](_0x3a6ae3[_0x6b54fc(0x32d)])||_0x586443[_0x4b07b8(0x24a)+_0x6b54fc(0x528)](_0x3a6ae3[_0x32af5e(0x2a3)])||_0x586443[_0x4b07b8(0x24a)+_0x32af5e(0x528)](_0x3a6ae3[_0x248339(0x2b6)])||_0x586443[_0x4b07b8(0x24a)+_0x4b07b8(0x528)](_0x3a6ae3[_0x248339(0x860)])||_0x586443[_0x6b54fc(0x24a)+_0x248339(0x528)](_0x3a6ae3[_0x4b07b8(0x274)])||_0x586443[_0x248339(0x24a)+_0x6b54fc(0x528)]('怎样')||_0x586443[_0x4b07b8(0x24a)+_0x4b07b8(0x528)]('给我')||_0x586443[_0x1e785a(0x24a)+_0x32af5e(0x528)]('如何')||_0x586443[_0x248339(0x24a)+_0x32af5e(0x528)]('谁是')||_0x586443[_0x1e785a(0x24a)+_0x6b54fc(0x528)]('查询')||_0x586443[_0x4b07b8(0x24a)+_0x248339(0x528)](_0x3a6ae3[_0x4b07b8(0x3ef)])||_0x586443[_0x32af5e(0x24a)+_0x32af5e(0x528)](_0x3a6ae3[_0x6b54fc(0x333)])||_0x586443[_0x1e785a(0x24a)+_0x248339(0x528)](_0x3a6ae3[_0x248339(0x292)])||_0x586443[_0x1e785a(0x24a)+_0x1e785a(0x528)](_0x3a6ae3[_0x32af5e(0x6fe)])||_0x586443[_0x4b07b8(0x24a)+_0x248339(0x528)]('哪个')||_0x586443[_0x248339(0x24a)+_0x4b07b8(0x528)]('哪些')||_0x586443[_0x32af5e(0x24a)+_0x248339(0x528)](_0x3a6ae3[_0x4b07b8(0x226)])||_0x586443[_0x6b54fc(0x24a)+_0x4b07b8(0x528)](_0x3a6ae3[_0x4b07b8(0x2a9)])||_0x586443[_0x4b07b8(0x24a)+_0x6b54fc(0x528)]('啥是')||_0x586443[_0x6b54fc(0x24a)+_0x4b07b8(0x528)]('为啥')||_0x586443[_0x4b07b8(0x24a)+_0x6b54fc(0x528)]('怎么'))return _0x3a6ae3[_0x4b07b8(0x2ee)](send_webchat,_0x37c8aa);if(_0x3a6ae3[_0x1e785a(0x549)](lock_chat,0xed1*-0x1+0x24a*0x2+0xa3d))return;lock_chat=0x2204+-0x547+-0x1cbc;const _0x39d9bb=_0x3a6ae3[_0x1e785a(0x413)](_0x3a6ae3[_0x248339(0x3aa)](_0x3a6ae3[_0x32af5e(0x62c)](document[_0x6b54fc(0x756)+_0x1e785a(0x498)+_0x32af5e(0x77c)](_0x3a6ae3[_0x4b07b8(0x7ff)])[_0x248339(0x845)+_0x32af5e(0x37e)][_0x248339(0x72b)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x4b07b8(0x72b)+'ce'](/<hr.*/gs,'')[_0x6b54fc(0x72b)+'ce'](/<[^>]+>/g,'')[_0x1e785a(0x72b)+'ce'](/\n\n/g,'\x0a'),_0x3a6ae3[_0x6b54fc(0x713)]),search_queryquery),_0x3a6ae3[_0x6b54fc(0x221)]);let _0x1980ce=_0x3a6ae3[_0x6b54fc(0x588)](_0x3a6ae3[_0x32af5e(0x237)](_0x3a6ae3[_0x4b07b8(0x42a)](_0x3a6ae3[_0x6b54fc(0x2af)](_0x3a6ae3[_0x248339(0x237)](_0x3a6ae3[_0x6b54fc(0x3b7)](_0x3a6ae3[_0x32af5e(0x278)](_0x3a6ae3[_0x32af5e(0x647)],_0x3a6ae3[_0x248339(0x535)]),_0x39d9bb),'\x0a'),word_last),_0x3a6ae3[_0x248339(0x2f3)]),_0x586443),_0x3a6ae3[_0x4b07b8(0x3fc)]);const _0x35248d={};_0x35248d[_0x1e785a(0x7e3)+'t']=_0x1980ce,_0x35248d[_0x248339(0x642)+_0x4b07b8(0x30f)]=0x3e8,_0x35248d[_0x6b54fc(0x31d)+_0x1e785a(0x6e7)+'e']=0.9,_0x35248d[_0x6b54fc(0x67b)]=0x1,_0x35248d[_0x6b54fc(0x7b8)+_0x32af5e(0x55c)+_0x6b54fc(0x775)+'ty']=0x0,_0x35248d[_0x32af5e(0x51e)+_0x1e785a(0x7cc)+_0x32af5e(0x557)+'y']=0x1,_0x35248d[_0x32af5e(0x45b)+'of']=0x1,_0x35248d[_0x6b54fc(0x6aa)]=![],_0x35248d[_0x1e785a(0x721)+_0x6b54fc(0x66b)]=0x0,_0x35248d[_0x6b54fc(0x566)+'m']=!![];const _0x5068ca={'method':_0x3a6ae3[_0x6b54fc(0x6df)],'headers':headers,'body':_0x3a6ae3[_0x6b54fc(0x5d7)](b64EncodeUnicode,JSON[_0x6b54fc(0x6f8)+_0x1e785a(0x6f5)](_0x35248d))};_0x586443=_0x586443[_0x32af5e(0x72b)+_0x1e785a(0x467)]('\x0a\x0a','\x0a')[_0x248339(0x72b)+_0x248339(0x467)]('\x0a\x0a','\x0a'),document[_0x32af5e(0x756)+_0x4b07b8(0x498)+_0x32af5e(0x77c)](_0x3a6ae3[_0x32af5e(0x404)])[_0x248339(0x845)+_0x1e785a(0x37e)]='',_0x3a6ae3[_0x6b54fc(0x74c)](markdownToHtml,_0x3a6ae3[_0x32af5e(0x209)](beautify,_0x586443),document[_0x4b07b8(0x756)+_0x4b07b8(0x498)+_0x4b07b8(0x77c)](_0x3a6ae3[_0x32af5e(0x404)])),chatTextRaw=_0x3a6ae3[_0x1e785a(0x3aa)](_0x3a6ae3[_0x32af5e(0x6dd)](_0x3a6ae3[_0x1e785a(0x715)],_0x586443),_0x3a6ae3[_0x6b54fc(0x754)]),chatTemp='',text_offset=-(0xb07+-0x233+-0x8d3),prev_chat=document[_0x248339(0x7a7)+_0x32af5e(0x5c2)+_0x248339(0x524)](_0x3a6ae3[_0x6b54fc(0x85c)])[_0x248339(0x845)+_0x6b54fc(0x37e)],prev_chat=_0x3a6ae3[_0x1e785a(0x3a4)](_0x3a6ae3[_0x4b07b8(0x3a4)](_0x3a6ae3[_0x6b54fc(0x20a)](prev_chat,_0x3a6ae3[_0x4b07b8(0x68a)]),document[_0x4b07b8(0x756)+_0x248339(0x498)+_0x6b54fc(0x77c)](_0x3a6ae3[_0x248339(0x404)])[_0x6b54fc(0x845)+_0x1e785a(0x37e)]),_0x3a6ae3[_0x6b54fc(0x6a1)]),_0x3a6ae3[_0x32af5e(0x633)](fetch,_0x3a6ae3[_0x32af5e(0x42e)],_0x5068ca)[_0x32af5e(0x46e)](_0xa2aa6c=>{const _0x189dc2=_0x4b07b8,_0x5eb659=_0x4b07b8,_0x5d9f74=_0x4b07b8,_0x40f9a9=_0x248339,_0x468d5f=_0x1e785a,_0x1134af={'QYgEs':function(_0x597c00,_0x411cd9){const _0x2404c0=_0x59ea;return _0x3a6ae3[_0x2404c0(0x27a)](_0x597c00,_0x411cd9);},'ablUO':_0x3a6ae3[_0x189dc2(0x2d9)]};if(_0x3a6ae3[_0x5eb659(0x1df)](_0x3a6ae3[_0x5d9f74(0x229)],_0x3a6ae3[_0x5d9f74(0x229)])){const _0x50f280=_0xa2aa6c[_0x40f9a9(0x52a)][_0x468d5f(0x3f4)+_0x5eb659(0x405)]();let _0x34f758='',_0x5552da='';_0x50f280[_0x5eb659(0x53b)]()[_0x468d5f(0x46e)](function _0x243107({done:_0x9af8ce,value:_0x1ad41a}){const _0xf3e545=_0x40f9a9,_0x136355=_0x5d9f74,_0x7d5882=_0x5d9f74,_0x36a443=_0x40f9a9,_0x59b089=_0x468d5f,_0x5a2b13={'aEnNY':function(_0x305005,_0x2fdb52){const _0x5e16c9=_0x59ea;return _0x3a6ae3[_0x5e16c9(0x3d8)](_0x305005,_0x2fdb52);},'CTEQq':function(_0x43d648,_0xb9d1ad){const _0x5d1420=_0x59ea;return _0x3a6ae3[_0x5d1420(0x5f3)](_0x43d648,_0xb9d1ad);},'qZzGl':function(_0x49719c,_0x1a4d17){const _0x21153f=_0x59ea;return _0x3a6ae3[_0x21153f(0x413)](_0x49719c,_0x1a4d17);},'cooXn':_0x3a6ae3[_0xf3e545(0x2d9)],'hAiJK':_0x3a6ae3[_0x136355(0x36b)],'NIvrX':function(_0x12f3ee,_0x391b23){const _0x56191d=_0xf3e545;return _0x3a6ae3[_0x56191d(0x5d7)](_0x12f3ee,_0x391b23);},'hnDak':_0x3a6ae3[_0x136355(0x28b)],'tOuUw':function(_0x10ccbc,_0xaae5c){const _0x10ead9=_0x7d5882;return _0x3a6ae3[_0x10ead9(0x3d7)](_0x10ccbc,_0xaae5c);},'jyHcJ':_0x3a6ae3[_0x7d5882(0x6ed)],'CZKRI':function(_0x1cc304,_0x1d6ad8){const _0x18f6af=_0x136355;return _0x3a6ae3[_0x18f6af(0x79b)](_0x1cc304,_0x1d6ad8);},'SSSMv':function(_0x34c443,_0x3b9904){const _0x201b57=_0x7d5882;return _0x3a6ae3[_0x201b57(0x303)](_0x34c443,_0x3b9904);},'rLwFX':_0x3a6ae3[_0x59b089(0x7fe)],'mJsqa':_0x3a6ae3[_0x36a443(0x82a)],'EOlTU':_0x3a6ae3[_0xf3e545(0x5f9)],'ZpUCe':function(_0x2bc8f4,_0x59936d){const _0xb890d1=_0x136355;return _0x3a6ae3[_0xb890d1(0x204)](_0x2bc8f4,_0x59936d);},'SIIRz':_0x3a6ae3[_0x7d5882(0x7f5)],'xNDnz':function(_0x35a2b5,_0xebce80){const _0x2fee04=_0x136355;return _0x3a6ae3[_0x2fee04(0x21d)](_0x35a2b5,_0xebce80);},'HIjKW':_0x3a6ae3[_0x36a443(0x719)],'NCWhu':function(_0x19e446,_0x416e9f){const _0x3a49ea=_0xf3e545;return _0x3a6ae3[_0x3a49ea(0x77d)](_0x19e446,_0x416e9f);},'tEqcj':_0x3a6ae3[_0xf3e545(0x22d)],'bjKUq':function(_0x17d7d5,_0x21af58){const _0x3c6eed=_0x136355;return _0x3a6ae3[_0x3c6eed(0x727)](_0x17d7d5,_0x21af58);},'ZhhvF':_0x3a6ae3[_0x136355(0x74d)],'yMDQy':function(_0x30f4c6,_0x2f3491){const _0x12b769=_0x59b089;return _0x3a6ae3[_0x12b769(0x79b)](_0x30f4c6,_0x2f3491);},'ZZGbc':function(_0x5d3d1a,_0x4adc90){const _0x270e02=_0x59b089;return _0x3a6ae3[_0x270e02(0x362)](_0x5d3d1a,_0x4adc90);},'SGbpr':_0x3a6ae3[_0xf3e545(0x50b)],'abqHD':_0x3a6ae3[_0x136355(0x1dc)],'Nrjjq':_0x3a6ae3[_0xf3e545(0x404)],'kaUoI':function(_0x3c3d89,_0x36c2eb,_0x4ac873){const _0xde42e9=_0xf3e545;return _0x3a6ae3[_0xde42e9(0x3a5)](_0x3c3d89,_0x36c2eb,_0x4ac873);},'Mjdgh':_0x3a6ae3[_0x36a443(0x85c)],'QdsWG':_0x3a6ae3[_0x36a443(0x617)],'TsJFY':_0x3a6ae3[_0x36a443(0x6a1)],'tWgoG':function(_0x5de0c0){const _0x29287e=_0x7d5882;return _0x3a6ae3[_0x29287e(0x41b)](_0x5de0c0);}};if(_0x3a6ae3[_0x59b089(0x1df)](_0x3a6ae3[_0x7d5882(0x4f5)],_0x3a6ae3[_0xf3e545(0x4f5)])){if(_0x9af8ce)return;const _0x5a96ee=new TextDecoder(_0x3a6ae3[_0x36a443(0x594)])[_0x7d5882(0x6ef)+'e'](_0x1ad41a);return _0x5a96ee[_0x136355(0x705)]()[_0x36a443(0x6fd)]('\x0a')[_0x136355(0x71d)+'ch'](function(_0x161a71){const _0x452d60=_0x59b089,_0x5c1792=_0x7d5882,_0x4e0d2b=_0x7d5882,_0x5edfe3=_0xf3e545,_0x383bf8=_0xf3e545,_0x44e103={'OZHyz':_0x5a2b13[_0x452d60(0x57b)],'LSQFa':function(_0x1231f5,_0x5dde39){const _0x41d673=_0x452d60;return _0x5a2b13[_0x41d673(0x5b7)](_0x1231f5,_0x5dde39);},'fsiEr':_0x5a2b13[_0x452d60(0x509)]};if(_0x5a2b13[_0x4e0d2b(0x4c4)](_0x5a2b13[_0x452d60(0x504)],_0x5a2b13[_0x4e0d2b(0x504)])){const _0x2ea202='['+_0x550bb9++ +_0x452d60(0x660)+_0x12b02e[_0x4e0d2b(0x6c7)+'s']()[_0x452d60(0x6ce)]()[_0x452d60(0x6c7)],_0x28240c='[^'+_0x5a2b13[_0x5c1792(0x265)](_0xc9a5a8,0x1*0x258b+-0x2*-0x11a2+-0x48ce)+_0x383bf8(0x660)+_0x237920[_0x452d60(0x6c7)+'s']()[_0x5edfe3(0x6ce)]()[_0x5edfe3(0x6c7)];_0x543451=_0x39b29a+'\x0a\x0a'+_0x28240c,_0x3a0a41[_0x383bf8(0x5a6)+'e'](_0x3c783d[_0x5edfe3(0x6c7)+'s']()[_0x4e0d2b(0x6ce)]()[_0x5edfe3(0x6c7)]);}else{if(_0x5a2b13[_0x5c1792(0x394)](_0x161a71[_0x5c1792(0x377)+'h'],0x137*0x1f+0x665*0x3+-0x38d2))_0x34f758=_0x161a71[_0x452d60(0x483)](-0x1b94+0x1ee6+-0x34c*0x1);if(_0x5a2b13[_0x5c1792(0x596)](_0x34f758,_0x5a2b13[_0x383bf8(0x7fb)])){if(_0x5a2b13[_0x4e0d2b(0x4c4)](_0x5a2b13[_0x5c1792(0x335)],_0x5a2b13[_0x5edfe3(0x335)]))_0x16b052+=_0x177f15[0x5*0x8b+0x23b*-0x2+-0x1*-0x1bf][_0x5c1792(0x5b4)],_0x5488eb=_0x145f97[0x1a5*-0x7+0x1408+0x1*-0x885][_0x383bf8(0x721)+_0x452d60(0x66b)][_0x452d60(0x396)+_0x5c1792(0x5b6)+'t'][_0x5a2b13[_0x4e0d2b(0x265)](_0x108db3[-0x14bc+-0x2*0xf60+0x337c][_0x5c1792(0x721)+_0x452d60(0x66b)][_0x452d60(0x396)+_0x452d60(0x5b6)+'t'][_0x4e0d2b(0x377)+'h'],0x1e26+0x78c+0x25b1*-0x1)];else{word_last+=_0x5a2b13[_0x383bf8(0x819)](chatTextRaw,chatTemp),lock_chat=-0x8*-0x4b4+0x641*-0x1+-0x1f5f,document[_0x5c1792(0x756)+_0x383bf8(0x498)+_0x5edfe3(0x77c)](_0x5a2b13[_0x452d60(0x66c)])[_0x4e0d2b(0x6c7)]='';return;}}let _0x1df895;try{if(_0x5a2b13[_0x452d60(0x312)](_0x5a2b13[_0x4e0d2b(0x733)],_0x5a2b13[_0x383bf8(0x733)])){if(!_0x115953)return;try{var _0x20e878=new _0x838c64(_0x4586fb[_0x4e0d2b(0x377)+'h']),_0x2b4f38=new _0x3840de(_0x20e878);for(var _0x2233ca=-0xdf+0xd*-0xc7+-0x1*-0xafa,_0x33964d=_0x14b207[_0x5edfe3(0x377)+'h'];_0x5a2b13[_0x5edfe3(0x283)](_0x2233ca,_0x33964d);_0x2233ca++){_0x2b4f38[_0x2233ca]=_0x21439b[_0x5edfe3(0x21f)+_0x383bf8(0x75a)](_0x2233ca);}return _0x20e878;}catch(_0xf3c0ca){}}else try{_0x5a2b13[_0x4e0d2b(0x6f3)](_0x5a2b13[_0x4e0d2b(0x69e)],_0x5a2b13[_0x5c1792(0x69e)])?_0xd26972[_0x452d60(0x728)](_0x44e103[_0x5edfe3(0x682)],_0x42473a):(_0x1df895=JSON[_0x452d60(0x842)](_0x5a2b13[_0x5c1792(0x819)](_0x5552da,_0x34f758))[_0x5a2b13[_0x4e0d2b(0x2f5)]],_0x5552da='');}catch(_0x1b17fa){if(_0x5a2b13[_0x452d60(0x7c3)](_0x5a2b13[_0x452d60(0x1fd)],_0x5a2b13[_0x452d60(0x1fd)]))_0x1df895=JSON[_0x4e0d2b(0x842)](_0x34f758)[_0x5a2b13[_0x4e0d2b(0x2f5)]],_0x5552da='';else{_0x39c931=_0x44e103[_0x4e0d2b(0x38b)](_0x57d6ab,_0x3ca974);const _0x2234b5={};return _0x2234b5[_0x4e0d2b(0x3fe)]=_0x44e103[_0x383bf8(0x5ea)],_0x496111[_0x452d60(0x58f)+'e'][_0x4e0d2b(0x4a3)+'pt'](_0x2234b5,_0x127800,_0x5c8313);}}}catch(_0x186b5e){if(_0x5a2b13[_0x5edfe3(0x7f2)](_0x5a2b13[_0x452d60(0x210)],_0x5a2b13[_0x383bf8(0x210)]))try{_0x17e6c3=_0x347345[_0x5edfe3(0x842)](_0x5a2b13[_0x5c1792(0x819)](_0x5f27ef,_0x2b5407))[_0x5a2b13[_0x5edfe3(0x2f5)]],_0x4c234a='';}catch(_0xf9af9b){_0x2b505c=_0x2061f8[_0x383bf8(0x842)](_0x36074f)[_0x5a2b13[_0x452d60(0x2f5)]],_0x257b8f='';}else _0x5552da+=_0x34f758;}_0x1df895&&_0x5a2b13[_0x4e0d2b(0x395)](_0x1df895[_0x383bf8(0x377)+'h'],-0x4*-0x501+-0x538+-0x1*0xecc)&&_0x5a2b13[_0x452d60(0x394)](_0x1df895[0xe57*-0x2+-0x1e2*-0x4+0x1526][_0x5edfe3(0x721)+_0x383bf8(0x66b)][_0x4e0d2b(0x396)+_0x5edfe3(0x5b6)+'t'][0x2302+0x4fb+-0x27fd],text_offset)&&(_0x5a2b13[_0x5c1792(0x6a6)](_0x5a2b13[_0x383bf8(0x6b4)],_0x5a2b13[_0x452d60(0x6e1)])?(chatTemp+=_0x1df895[-0x23d3+0x2436*-0x1+0x4809][_0x5c1792(0x5b4)],text_offset=_0x1df895[-0x128b+-0x1638+-0x1*-0x28c3][_0x5edfe3(0x721)+_0x383bf8(0x66b)][_0x5edfe3(0x396)+_0x5c1792(0x5b6)+'t'][_0x5a2b13[_0x4e0d2b(0x265)](_0x1df895[-0x2b4+0x1141*-0x1+-0x27*-0x83][_0x5edfe3(0x721)+_0x5c1792(0x66b)][_0x5edfe3(0x396)+_0x4e0d2b(0x5b6)+'t'][_0x5edfe3(0x377)+'h'],-0x61f*0x3+0x39e*-0x4+-0x106b*-0x2)]):_0x4b79cb=_0x39b2a9),chatTemp=chatTemp[_0x383bf8(0x72b)+_0x383bf8(0x467)]('\x0a\x0a','\x0a')[_0x4e0d2b(0x72b)+_0x5edfe3(0x467)]('\x0a\x0a','\x0a'),document[_0x5edfe3(0x756)+_0x5edfe3(0x498)+_0x4e0d2b(0x77c)](_0x5a2b13[_0x5edfe3(0x639)])[_0x452d60(0x845)+_0x5edfe3(0x37e)]='',_0x5a2b13[_0x4e0d2b(0x23f)](markdownToHtml,_0x5a2b13[_0x4e0d2b(0x5b7)](beautify,chatTemp),document[_0x452d60(0x756)+_0x452d60(0x498)+_0x5c1792(0x77c)](_0x5a2b13[_0x5c1792(0x639)])),document[_0x452d60(0x7a7)+_0x383bf8(0x5c2)+_0x5c1792(0x524)](_0x5a2b13[_0x383bf8(0x7eb)])[_0x383bf8(0x845)+_0x4e0d2b(0x37e)]=_0x5a2b13[_0x452d60(0x819)](_0x5a2b13[_0x452d60(0x819)](_0x5a2b13[_0x5c1792(0x819)](prev_chat,_0x5a2b13[_0x4e0d2b(0x2e4)]),document[_0x4e0d2b(0x756)+_0x5c1792(0x498)+_0x5edfe3(0x77c)](_0x5a2b13[_0x5edfe3(0x639)])[_0x4e0d2b(0x845)+_0x4e0d2b(0x37e)]),_0x5a2b13[_0x5edfe3(0x462)]);}}),_0x50f280[_0x36a443(0x53b)]()[_0x7d5882(0x46e)](_0x243107);}else DbNRgX[_0x36a443(0x318)](_0x14af90);});}else _0xabf8bc=_0x2c6d2b[_0x5d9f74(0x842)](_0x1134af[_0x40f9a9(0x84c)](_0x24cff5,_0x63b098))[_0x1134af[_0x189dc2(0x632)]],_0x59ef77='';})[_0x4b07b8(0x82f)](_0xb2b9a1=>{const _0x1dbfed=_0x32af5e,_0x328500=_0x248339,_0x1494cf=_0x32af5e,_0x2b1ef8=_0x1e785a,_0x5e744c=_0x32af5e;if(_0x3a6ae3[_0x1dbfed(0x1df)](_0x3a6ae3[_0x328500(0x2d4)],_0x3a6ae3[_0x1494cf(0x2d4)]))console[_0x1dbfed(0x728)](_0x3a6ae3[_0x2b1ef8(0x36b)],_0xb2b9a1);else{if(_0x28da09){const _0x3da18f=_0x5cb1d3[_0x1494cf(0x5eb)](_0x1ff8e3,arguments);return _0xd3018b=null,_0x3da18f;}}});}function replaceUrlWithFootnote(_0x118ae8){const _0x3e4e3c=_0x231d02,_0x157f0f=_0x810b6e,_0x1c089d=_0x810b6e,_0x40879f=_0x5c1584,_0x32274f=_0x4fb1b9,_0x161427={'tsHHq':function(_0x547584,_0x5405e3){return _0x547584(_0x5405e3);},'KvYpI':function(_0x52b98e,_0x36324a){return _0x52b98e+_0x36324a;},'ikdfL':_0x3e4e3c(0x4ca)+_0x3e4e3c(0x3cc)+_0x3e4e3c(0x6d0)+_0x157f0f(0x6af),'XOxJx':_0x157f0f(0x73e)+_0x1c089d(0x631)+_0x1c089d(0x2d2)+_0x3e4e3c(0x580)+_0x40879f(0x29f)+_0x3e4e3c(0x4ed)+'\x20)','fqXNT':_0x40879f(0x3da)+':','hSiAG':function(_0x37328e,_0x439fad){return _0x37328e===_0x439fad;},'CZzjo':_0x157f0f(0x1e3),'wAdiE':function(_0x5c97e0,_0x1af726){return _0x5c97e0!==_0x1af726;},'FfURY':_0x3e4e3c(0x6b6),'fdZai':function(_0x4b1677,_0x2046f3){return _0x4b1677+_0x2046f3;},'NiQaK':function(_0x4197dd,_0xc6a17){return _0x4197dd-_0xc6a17;},'xVfxu':function(_0x16b176,_0x4feff7){return _0x16b176<=_0x4feff7;},'WpTmX':function(_0x5b99bd,_0x382a92){return _0x5b99bd>_0x382a92;},'eocgD':_0x1c089d(0x2b9),'tdAgk':_0x1c089d(0x2f1)},_0x4cce7c=/\((https?:\/\/[^\s()]+(?:\s|;)?(?:https?:\/\/[^\s()]+)*)\)/g,_0x3f5db5=new Set(),_0x580c5e=(_0x287c97,_0x377aac)=>{const _0x4718d4=_0x40879f,_0x257129=_0x32274f,_0x429241=_0x3e4e3c,_0xc54bbb=_0x1c089d,_0x1a07f5=_0x40879f,_0x200f65={'JDAGD':function(_0x40f6aa,_0x4c6b9c){const _0x1b37d8=_0x59ea;return _0x161427[_0x1b37d8(0x7a1)](_0x40f6aa,_0x4c6b9c);},'lzUVL':function(_0xa142f9,_0x23e1d4){const _0x12e06e=_0x59ea;return _0x161427[_0x12e06e(0x5df)](_0xa142f9,_0x23e1d4);},'UaXAm':_0x161427[_0x4718d4(0x856)],'NAatz':_0x161427[_0x257129(0x7b0)],'rmiGm':_0x161427[_0x4718d4(0x24c)]};if(_0x161427[_0xc54bbb(0x299)](_0x161427[_0x429241(0x7cd)],_0x161427[_0x429241(0x7cd)])){if(_0x3f5db5[_0x429241(0x64e)](_0x377aac)){if(_0x161427[_0x429241(0x480)](_0x161427[_0x1a07f5(0x361)],_0x161427[_0x4718d4(0x361)]))_0x4da358=ZnjYpq[_0x1a07f5(0x73f)](_0x4f2a91,ZnjYpq[_0x429241(0x637)](ZnjYpq[_0xc54bbb(0x637)](ZnjYpq[_0xc54bbb(0x4d1)],ZnjYpq[_0xc54bbb(0x757)]),');'))();else return _0x287c97;}const _0x383394=_0x377aac[_0xc54bbb(0x6fd)](/[;,；、，]/),_0x49585a=_0x383394[_0x1a07f5(0x3bb)](_0x2ff873=>'['+_0x2ff873+']')[_0x257129(0x622)]('\x20'),_0x179446=_0x383394[_0x257129(0x3bb)](_0x2cf9fd=>'['+_0x2cf9fd+']')[_0x4718d4(0x622)]('\x0a');_0x383394[_0x429241(0x71d)+'ch'](_0x19c40c=>_0x3f5db5[_0xc54bbb(0x5bf)](_0x19c40c)),res='\x20';for(var _0x25ba36=_0x161427[_0x1a07f5(0x6cd)](_0x161427[_0x257129(0x804)](_0x3f5db5[_0x257129(0x4a2)],_0x383394[_0x257129(0x377)+'h']),0x167c*0x1+0x9*-0x28b+-0x1a*-0x4);_0x161427[_0x1a07f5(0x720)](_0x25ba36,_0x3f5db5[_0x257129(0x4a2)]);++_0x25ba36)res+='[^'+_0x25ba36+']\x20';return res;}else _0x2b6a00[_0xc54bbb(0x728)](_0x200f65[_0x1a07f5(0x7af)],_0x564a36);};let _0x10bda8=-0x7c7*0x3+-0x326*-0x1+0x1430,_0x36b729=_0x118ae8[_0x157f0f(0x72b)+'ce'](_0x4cce7c,_0x580c5e);while(_0x161427[_0x157f0f(0x810)](_0x3f5db5[_0x3e4e3c(0x4a2)],0x28+-0x2479+0x409*0x9)){if(_0x161427[_0x1c089d(0x480)](_0x161427[_0x3e4e3c(0x7d9)],_0x161427[_0x3e4e3c(0x7ce)])){const _0x28fb96='['+_0x10bda8++ +_0x3e4e3c(0x660)+_0x3f5db5[_0x1c089d(0x6c7)+'s']()[_0x3e4e3c(0x6ce)]()[_0x1c089d(0x6c7)],_0x2e3dc9='[^'+_0x161427[_0x32274f(0x804)](_0x10bda8,-0x9f*-0xd+-0x193+-0x1*0x67f)+_0x32274f(0x660)+_0x3f5db5[_0x157f0f(0x6c7)+'s']()[_0x1c089d(0x6ce)]()[_0x40879f(0x6c7)];_0x36b729=_0x36b729+'\x0a\x0a'+_0x2e3dc9,_0x3f5db5[_0x1c089d(0x5a6)+'e'](_0x3f5db5[_0x157f0f(0x6c7)+'s']()[_0x157f0f(0x6ce)]()[_0x1c089d(0x6c7)]);}else{const _0x2d820d=_0x4aa3a0?function(){const _0x86452b=_0x3e4e3c;if(_0x1c2e3d){const _0x1090d=_0x39e991[_0x86452b(0x5eb)](_0x18f692,arguments);return _0x23a0f9=null,_0x1090d;}}:function(){};return _0x54b79d=![],_0x2d820d;}}return _0x36b729;}function beautify(_0x358cef){const _0x41d946=_0x4fb1b9,_0x484ce5=_0x231d02,_0x1c4079=_0x5c1584,_0x35695f=_0x231d02,_0x290f4b=_0x25eb92,_0x590fdf={'QcsMd':_0x41d946(0x3f3)+'es','cTmuD':function(_0x2b4bef,_0x47496c){return _0x2b4bef+_0x47496c;},'yJJGb':_0x484ce5(0x284)+_0x1c4079(0x2d3)+'t','lWIEP':_0x484ce5(0x681),'qpHqp':_0x484ce5(0x6e6),'qEawN':function(_0x1aadd7,_0x39ebd7){return _0x1aadd7>=_0x39ebd7;},'vxufe':function(_0x4a99dc,_0x4122a3){return _0x4a99dc===_0x4122a3;},'rtMbl':_0x290f4b(0x232),'TfkaS':_0x35695f(0x772),'rXLKn':function(_0x3040ec,_0x415347){return _0x3040ec(_0x415347);},'oyrrp':function(_0x506cd0,_0x1d0146){return _0x506cd0+_0x1d0146;},'EVSlL':_0x35695f(0x39c)+_0x290f4b(0x314)+'rl','RLoeC':function(_0x1e6786,_0x4764ba){return _0x1e6786(_0x4764ba);},'DUSdq':_0x41d946(0x529)+'l','iKepo':function(_0x8c2b01,_0x559812){return _0x8c2b01(_0x559812);},'xonlE':function(_0x4f89e7,_0x506422){return _0x4f89e7+_0x506422;},'JxGGZ':_0x35695f(0x813)+_0x41d946(0x25f)+_0x1c4079(0x5b2),'FHJRE':function(_0x53c8d6,_0xeb4f95){return _0x53c8d6(_0xeb4f95);},'wOTxT':function(_0x85fef7,_0x273c7f){return _0x85fef7+_0x273c7f;},'TjoAh':_0x484ce5(0x23b),'hVUiV':function(_0x69624c,_0x32225d){return _0x69624c(_0x32225d);},'YgKpZ':function(_0x219552,_0x28fc01){return _0x219552(_0x28fc01);},'dzHyv':function(_0x3aabe6,_0x2f92fc){return _0x3aabe6(_0x2f92fc);},'QZnQO':function(_0x3dc9a3,_0x219c83){return _0x3dc9a3>=_0x219c83;},'NSenV':function(_0x1e2cff,_0x341d1d){return _0x1e2cff!==_0x341d1d;},'wMNvW':_0x35695f(0x530),'XAjIF':_0x484ce5(0x848)+_0x41d946(0x724)+'l','iHciN':function(_0x5ff00e,_0x8e7e6){return _0x5ff00e(_0x8e7e6);},'DfnyZ':_0x1c4079(0x848)+_0x290f4b(0x6ab),'aCAra':function(_0x4f404e,_0x241ca5){return _0x4f404e(_0x241ca5);},'Duqqz':function(_0x39427b,_0x104f86){return _0x39427b+_0x104f86;},'LAmGi':_0x484ce5(0x6ab),'DsysG':function(_0x27420b,_0x33c152){return _0x27420b(_0x33c152);}};new_text=_0x358cef[_0x484ce5(0x72b)+_0x1c4079(0x467)]('（','(')[_0x484ce5(0x72b)+_0x290f4b(0x467)]('）',')')[_0x484ce5(0x72b)+_0x41d946(0x467)](',\x20',',')[_0x41d946(0x72b)+_0x41d946(0x467)](_0x590fdf[_0x484ce5(0x7db)],'')[_0x484ce5(0x72b)+_0x290f4b(0x467)](_0x590fdf[_0x35695f(0x2c8)],'');for(let _0x800c49=prompt[_0x484ce5(0x6d2)+_0x35695f(0x385)][_0x484ce5(0x377)+'h'];_0x590fdf[_0x1c4079(0x43a)](_0x800c49,-0xbf9+-0x1*-0x26c5+-0x1acc);--_0x800c49){_0x590fdf[_0x290f4b(0x424)](_0x590fdf[_0x35695f(0x444)],_0x590fdf[_0x1c4079(0x444)])?(new_text=new_text[_0x35695f(0x72b)+_0x290f4b(0x467)](_0x590fdf[_0x35695f(0x5f5)](_0x590fdf[_0x290f4b(0x34a)],_0x590fdf[_0x41d946(0x43b)](String,_0x800c49)),_0x590fdf[_0x484ce5(0x828)](_0x590fdf[_0x35695f(0x500)],_0x590fdf[_0x290f4b(0x41f)](String,_0x800c49))),new_text=new_text[_0x1c4079(0x72b)+_0x484ce5(0x467)](_0x590fdf[_0x484ce5(0x828)](_0x590fdf[_0x290f4b(0x1e4)],_0x590fdf[_0x1c4079(0x2ac)](String,_0x800c49)),_0x590fdf[_0x484ce5(0x6ad)](_0x590fdf[_0x484ce5(0x500)],_0x590fdf[_0x41d946(0x43b)](String,_0x800c49))),new_text=new_text[_0x290f4b(0x72b)+_0x41d946(0x467)](_0x590fdf[_0x41d946(0x5f5)](_0x590fdf[_0x484ce5(0x4d4)],_0x590fdf[_0x484ce5(0x527)](String,_0x800c49)),_0x590fdf[_0x35695f(0x831)](_0x590fdf[_0x290f4b(0x500)],_0x590fdf[_0x35695f(0x41f)](String,_0x800c49))),new_text=new_text[_0x35695f(0x72b)+_0x35695f(0x467)](_0x590fdf[_0x35695f(0x5f5)](_0x590fdf[_0x484ce5(0x852)],_0x590fdf[_0x35695f(0x208)](String,_0x800c49)),_0x590fdf[_0x290f4b(0x6ad)](_0x590fdf[_0x35695f(0x500)],_0x590fdf[_0x1c4079(0x422)](String,_0x800c49)))):(_0x9e65c9=_0x27545d[_0x35695f(0x842)](_0x23c4d0)[_0x590fdf[_0x35695f(0x658)]],_0x326deb='');}new_text=_0x590fdf[_0x35695f(0x1fa)](replaceUrlWithFootnote,new_text);for(let _0x51996d=prompt[_0x1c4079(0x6d2)+_0x290f4b(0x385)][_0x35695f(0x377)+'h'];_0x590fdf[_0x484ce5(0x458)](_0x51996d,-0x83*-0x3b+0x3d*0x89+-0x3ed6);--_0x51996d){if(_0x590fdf[_0x1c4079(0x587)](_0x590fdf[_0x290f4b(0x82e)],_0x590fdf[_0x484ce5(0x82e)])){_0x48280c+=_0x590fdf[_0x41d946(0x5f5)](_0x392716,_0x54989d),_0x429065=0x2*-0x1231+-0x1983+0x3de5,_0x11fd78[_0x290f4b(0x756)+_0x41d946(0x498)+_0x35695f(0x77c)](_0x590fdf[_0x35695f(0x73b)])[_0x1c4079(0x6c7)]='';return;}else new_text=new_text[_0x484ce5(0x72b)+'ce'](_0x590fdf[_0x35695f(0x828)](_0x590fdf[_0x484ce5(0x4e9)],_0x590fdf[_0x484ce5(0x559)](String,_0x51996d)),prompt[_0x41d946(0x6d2)+_0x35695f(0x385)][_0x51996d]),new_text=new_text[_0x1c4079(0x72b)+'ce'](_0x590fdf[_0x1c4079(0x831)](_0x590fdf[_0x1c4079(0x260)],_0x590fdf[_0x290f4b(0x33e)](String,_0x51996d)),prompt[_0x1c4079(0x6d2)+_0x484ce5(0x385)][_0x51996d]),new_text=new_text[_0x484ce5(0x72b)+'ce'](_0x590fdf[_0x1c4079(0x763)](_0x590fdf[_0x1c4079(0x44a)],_0x590fdf[_0x484ce5(0x65d)](String,_0x51996d)),prompt[_0x35695f(0x6d2)+_0x41d946(0x385)][_0x51996d]);}return new_text;}function chatmore(){const _0x28aea5=_0x4fb1b9,_0x53b899=_0x231d02,_0x591ab0=_0x231d02,_0x4e9e1e=_0x810b6e,_0x15065d=_0x231d02,_0x40e058={'PScKL':function(_0x24512f,_0x2c5daa){return _0x24512f(_0x2c5daa);},'shZGV':function(_0x1c95d2,_0x4fc39a){return _0x1c95d2<_0x4fc39a;},'TZNjk':function(_0x11daaf,_0x251ac){return _0x11daaf!==_0x251ac;},'btZMO':_0x28aea5(0x219),'RHdQM':_0x53b899(0x284)+_0x53b899(0x349),'AKJIM':function(_0x1d89f4,_0x4b71c1){return _0x1d89f4+_0x4b71c1;},'SuTNG':_0x591ab0(0x5af)+_0x28aea5(0x47f)+_0x28aea5(0x211)+_0x28aea5(0x55d)+_0x53b899(0x27d)+_0x591ab0(0x21e)+_0x28aea5(0x789)+_0x15065d(0x7a2)+_0x28aea5(0x70f)+_0x15065d(0x853)+_0x28aea5(0x826),'FIbtS':function(_0x5e4783,_0x153e67){return _0x5e4783(_0x153e67);},'gJzcp':_0x4e9e1e(0x1fe)+_0x15065d(0x54f),'EfubM':function(_0x32d17d,_0x24c8d){return _0x32d17d!==_0x24c8d;},'XiOps':_0x53b899(0x644),'brLkC':_0x28aea5(0x7d5),'YKUYb':_0x4e9e1e(0x1c4),'KuIgD':function(_0x1650ba,_0x3506c6){return _0x1650ba+_0x3506c6;},'hFIrj':function(_0x5377f1,_0x4ba84b){return _0x5377f1+_0x4ba84b;},'zpcCD':_0x53b899(0x284),'cJysa':_0x591ab0(0x5ac),'hOizd':_0x4e9e1e(0x3e4)+_0x53b899(0x43f)+_0x15065d(0x795)+_0x53b899(0x411)+_0x4e9e1e(0x791)+_0x53b899(0x69c)+_0x15065d(0x704)+_0x15065d(0x5ef)+_0x28aea5(0x4cb)+_0x53b899(0x5f2)+_0x15065d(0x434)+_0x28aea5(0x341)+_0x591ab0(0x82b),'Rwrtf':function(_0x297a65,_0x1eed23){return _0x297a65!=_0x1eed23;},'amMKj':function(_0x4fce22,_0xb044ec,_0x260423){return _0x4fce22(_0xb044ec,_0x260423);},'wLmql':_0x4e9e1e(0x848)+_0x591ab0(0x564)+_0x53b899(0x1fc)+_0x4e9e1e(0x3ba)+_0x591ab0(0x491)+_0x53b899(0x487)},_0x591346={'method':_0x40e058[_0x15065d(0x732)],'headers':headers,'body':_0x40e058[_0x28aea5(0x841)](b64EncodeUnicode,JSON[_0x591ab0(0x6f8)+_0x15065d(0x6f5)]({'prompt':_0x40e058[_0x4e9e1e(0x7d3)](_0x40e058[_0x53b899(0x7d3)](_0x40e058[_0x4e9e1e(0x6ec)](_0x40e058[_0x591ab0(0x77f)](document[_0x4e9e1e(0x756)+_0x15065d(0x498)+_0x15065d(0x77c)](_0x40e058[_0x15065d(0x4af)])[_0x591ab0(0x845)+_0x15065d(0x37e)][_0x53b899(0x72b)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x15065d(0x72b)+'ce'](/<hr.*/gs,'')[_0x591ab0(0x72b)+'ce'](/<[^>]+>/g,'')[_0x53b899(0x72b)+'ce'](/\n\n/g,'\x0a'),'\x0a'),_0x40e058[_0x53b899(0x7c0)]),original_search_query),_0x40e058[_0x53b899(0x5c0)]),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':![]}))};if(_0x40e058[_0x15065d(0x4f0)](document[_0x53b899(0x756)+_0x53b899(0x498)+_0x53b899(0x77c)](_0x40e058[_0x15065d(0x2a7)])[_0x53b899(0x845)+_0x28aea5(0x37e)],''))return;_0x40e058[_0x28aea5(0x2da)](fetch,_0x40e058[_0x28aea5(0x298)],_0x591346)[_0x28aea5(0x46e)](_0xfb5b51=>_0xfb5b51[_0x15065d(0x806)]())[_0x591ab0(0x46e)](_0x181a99=>{const _0x1eb9e8=_0x15065d,_0x55d814=_0x591ab0,_0xe51b7=_0x15065d,_0x20a9fd=_0x15065d,_0x54aaba=_0x4e9e1e,_0x117e96={'AEagi':function(_0x258fed,_0x524131){const _0x4fda18=_0x59ea;return _0x40e058[_0x4fda18(0x843)](_0x258fed,_0x524131);},'ssTeB':function(_0x57de7f,_0xc01aec){const _0x5a0bcd=_0x59ea;return _0x40e058[_0x5a0bcd(0x540)](_0x57de7f,_0xc01aec);},'WyJIJ':_0x40e058[_0x1eb9e8(0x3e1)],'DwRgS':_0x40e058[_0x1eb9e8(0x2a7)],'wFlUB':function(_0x5df1d3,_0x1b2469){const _0x22eba7=_0x55d814;return _0x40e058[_0x22eba7(0x7d3)](_0x5df1d3,_0x1b2469);},'SbwoA':function(_0x45db02,_0x4efae1){const _0x3d1ee8=_0x1eb9e8;return _0x40e058[_0x3d1ee8(0x7d3)](_0x45db02,_0x4efae1);},'GnsyJ':_0x40e058[_0x1eb9e8(0x417)],'OuzET':function(_0x4b87e3,_0x4c2db8){const _0xd69439=_0x1eb9e8;return _0x40e058[_0xd69439(0x37d)](_0x4b87e3,_0x4c2db8);},'ogQtV':_0x40e058[_0x55d814(0x6db)]};_0x40e058[_0x1eb9e8(0x699)](_0x40e058[_0x55d814(0x751)],_0x40e058[_0x1eb9e8(0x80c)])?JSON[_0x20a9fd(0x842)](_0x181a99[_0x20a9fd(0x3f3)+'es'][0x249c+-0x34b*0x8+-0xa44][_0x20a9fd(0x5b4)][_0x1eb9e8(0x72b)+_0xe51b7(0x467)]('\x0a',''))[_0x1eb9e8(0x71d)+'ch'](_0x4da527=>{const _0x37adc1=_0xe51b7,_0x4973a7=_0xe51b7,_0x51722a=_0x54aaba,_0x180a32=_0x20a9fd,_0x56b226=_0x54aaba;if(_0x117e96[_0x37adc1(0x33f)](_0x117e96[_0x4973a7(0x266)],_0x117e96[_0x51722a(0x266)])){var _0x26d6bb=new _0x1e678a(_0x9e7775),_0x402db4='';for(var _0x5550f4=0x1d9f+0x2*0x8fb+-0xd*0x3a9;_0x117e96[_0x180a32(0x82d)](_0x5550f4,_0x26d6bb[_0x180a32(0x675)+_0x56b226(0x22a)]);_0x5550f4++){_0x402db4+=_0x11de9c[_0x51722a(0x32c)+_0x56b226(0x620)+_0x180a32(0x3b3)](_0x26d6bb[_0x5550f4]);}return _0x402db4;}else document[_0x51722a(0x756)+_0x180a32(0x498)+_0x37adc1(0x77c)](_0x117e96[_0x56b226(0x72d)])[_0x180a32(0x845)+_0x56b226(0x37e)]+=_0x117e96[_0x4973a7(0x384)](_0x117e96[_0x180a32(0x7b1)](_0x117e96[_0x37adc1(0x759)],_0x117e96[_0x4973a7(0x2bd)](String,_0x4da527)),_0x117e96[_0x51722a(0x59b)]);}):CQyYuQ[_0x20a9fd(0x841)](_0x4a240e,'0');})[_0x28aea5(0x82f)](_0xd0c9cb=>console[_0x15065d(0x728)](_0xd0c9cb)),chatTextRawPlusComment=_0x40e058[_0x53b899(0x6ec)](chatTextRaw,'\x0a\x0a'),text_offset=-(0xb4a*0x3+0x2*0xd81+-0x3cdf);}let chatTextRaw='',text_offset=-(-0x1a8+-0x1*0x16fc+0x2bd*0x9);const _0x204d4b={};_0x204d4b[_0x810b6e(0x2d8)+_0x231d02(0x5f7)+'pe']=_0x231d02(0x830)+_0x25eb92(0x338)+_0x4fb1b9(0x36d)+'n';const headers=_0x204d4b;let prompt=JSON[_0x5c1584(0x842)](atob(document[_0x4fb1b9(0x756)+_0x25eb92(0x498)+_0x231d02(0x77c)](_0x5c1584(0x49b)+'pt')[_0x231d02(0x49d)+_0x5c1584(0x673)+'t']));chatTextRawIntro='',text_offset=-(0x2*0xc36+-0x35*-0x21+-0x1f40);const _0x1a6e95={};_0x1a6e95[_0x25eb92(0x7e3)+'t']=_0x231d02(0x69f)+_0x25eb92(0x57c)+_0x25eb92(0x79a)+_0x231d02(0x3a7)+_0x231d02(0x74a)+_0x5c1584(0x5ce)+original_search_query+(_0x810b6e(0x3b5)+_0x25eb92(0x321)+_0x5c1584(0x61d)+_0x5c1584(0x783)+_0x4fb1b9(0x3dd)+_0x25eb92(0x838)+_0x4fb1b9(0x5d1)+_0x231d02(0x543)+_0x25eb92(0x649)+_0x5c1584(0x659)),_0x1a6e95[_0x25eb92(0x642)+_0x810b6e(0x30f)]=0x400,_0x1a6e95[_0x5c1584(0x31d)+_0x25eb92(0x6e7)+'e']=0.2,_0x1a6e95[_0x25eb92(0x67b)]=0x1,_0x1a6e95[_0x25eb92(0x7b8)+_0x231d02(0x55c)+_0x5c1584(0x775)+'ty']=0x0,_0x1a6e95[_0x5c1584(0x51e)+_0x231d02(0x7cc)+_0x4fb1b9(0x557)+'y']=0.5,_0x1a6e95[_0x4fb1b9(0x45b)+'of']=0x1,_0x1a6e95[_0x4fb1b9(0x6aa)]=![],_0x1a6e95[_0x810b6e(0x721)+_0x4fb1b9(0x66b)]=0x0,_0x1a6e95[_0x810b6e(0x566)+'m']=!![];const optionsIntro={'method':_0x5c1584(0x1c4),'headers':headers,'body':b64EncodeUnicode(JSON[_0x810b6e(0x6f8)+_0x5c1584(0x6f5)](_0x1a6e95))};fetch(_0x5c1584(0x848)+_0x810b6e(0x564)+_0x231d02(0x1fc)+_0x4fb1b9(0x3ba)+_0x25eb92(0x491)+_0x5c1584(0x487),optionsIntro)[_0x5c1584(0x46e)](_0x44f033=>{const _0x1cb309=_0x4fb1b9,_0x5d1a07=_0x5c1584,_0x4e5e5a=_0x4fb1b9,_0x31916a=_0x4fb1b9,_0x4a5ffa=_0x4fb1b9,_0x995e0f={'afYNJ':function(_0x2ae85f,_0x480b24){return _0x2ae85f(_0x480b24);},'AwDMJ':_0x1cb309(0x61b)+_0x5d1a07(0x293),'lwPdv':function(_0x2acfa0,_0x23523d){return _0x2acfa0+_0x23523d;},'lgSpN':_0x1cb309(0x3f3)+'es','kDUJs':function(_0x276040,_0x1e08ed){return _0x276040(_0x1e08ed);},'pPiBn':function(_0x224dd7){return _0x224dd7();},'Vxizk':function(_0x142158,_0x17a5c5){return _0x142158!==_0x17a5c5;},'QciNg':_0x31916a(0x815),'OCaXg':function(_0x57c1ee,_0xbccaea){return _0x57c1ee>_0xbccaea;},'akUXC':function(_0x5e866f,_0x2be59a){return _0x5e866f==_0x2be59a;},'XBTFr':_0x4a5ffa(0x3d6)+']','dLFfB':function(_0x1f04e4,_0x502d9d){return _0x1f04e4===_0x502d9d;},'MPPuK':_0x5d1a07(0x2f7),'pBihk':_0x4e5e5a(0x27f),'Oxajz':_0x4a5ffa(0x27e)+_0x1cb309(0x65c)+_0x1cb309(0x729),'HHQZJ':_0x4e5e5a(0x27e)+_0x4a5ffa(0x2db),'JSncY':_0x31916a(0x583),'ZcuSf':_0x4e5e5a(0x33c),'sQPIZ':_0x31916a(0x1c8),'UoZvo':function(_0x63daa5,_0x400944){return _0x63daa5+_0x400944;},'hyVpr':_0x4e5e5a(0x7c1),'yZvRE':_0x4e5e5a(0x2cb),'GbmoN':_0x4e5e5a(0x295),'TVCvS':function(_0x4245e0,_0x1d8c3b){return _0x4245e0>_0x1d8c3b;},'tmSar':_0x31916a(0x6f2),'UjvQw':_0x1cb309(0x85d),'Axwnc':function(_0x5547dd,_0x44bf1e){return _0x5547dd-_0x44bf1e;},'kfBIM':function(_0x4663d8,_0x5b04ea,_0x477224){return _0x4663d8(_0x5b04ea,_0x477224);},'wPkgP':_0x5d1a07(0x263),'wGzyS':_0x31916a(0x7e9),'DPsmC':_0x4e5e5a(0x72f),'ULpur':_0x4e5e5a(0x744)+_0x31916a(0x572)+'t','UaURu':_0x4a5ffa(0x3ea),'uIfYv':_0x5d1a07(0x277),'BcRvY':_0x31916a(0x2d7),'shklA':_0x1cb309(0x3a3),'uXAGC':_0x31916a(0x5ff),'aIvtx':_0x5d1a07(0x4de),'RtwtZ':_0x1cb309(0x3da)+':','SaxAG':_0x1cb309(0x5e8)+_0x31916a(0x400)+_0x31916a(0x7c4),'nOwQQ':_0x4e5e5a(0x1d2)+'er','NmNrB':_0x4e5e5a(0x755),'NIvge':_0x5d1a07(0x62d),'gAJpC':_0x31916a(0x706),'VcUxY':_0x1cb309(0x429),'WQXTX':_0x31916a(0x284)+_0x31916a(0x349),'xHmVX':_0x31916a(0x1c4),'XbNPQ':function(_0x245180,_0x335038){return _0x245180+_0x335038;},'lqHSe':_0x4a5ffa(0x75b)+'“','gnsAU':_0x31916a(0x6dc)+_0x4a5ffa(0x408)+_0x4e5e5a(0x357)+_0x31916a(0x2e8)+_0x4a5ffa(0x449)+_0x4a5ffa(0x2c2)+_0x5d1a07(0x49c)+_0x1cb309(0x625),'TrQAd':_0x5d1a07(0x284),'uZRZF':_0x4a5ffa(0x848)+_0x4e5e5a(0x564)+_0x5d1a07(0x1fc)+_0x4a5ffa(0x3ba)+_0x5d1a07(0x491)+_0x31916a(0x487),'IvXki':_0x4e5e5a(0x6ea),'HuaHP':_0x4a5ffa(0x4eb),'OEEZj':_0x5d1a07(0x3b0),'dUiqn':_0x1cb309(0x5e7),'vllBm':_0x4a5ffa(0x460),'HbxHC':_0x31916a(0x707),'QaUDc':_0x5d1a07(0x79d),'XdbiH':_0x31916a(0x3c6),'wtJcy':function(_0x2c2308,_0x5a2671,_0x5e3a11){return _0x2c2308(_0x5a2671,_0x5e3a11);},'NDyHV':function(_0x1f6926,_0x25722a){return _0x1f6926!==_0x25722a;},'WoorF':_0x4e5e5a(0x774),'VhfYu':_0x1cb309(0x709),'mLpje':function(_0x5426b1,_0x2f4757){return _0x5426b1+_0x2f4757;},'vwesL':_0x5d1a07(0x39d),'fmBOC':_0x4e5e5a(0x785),'qcvPf':_0x4e5e5a(0x40b)+_0x4a5ffa(0x28f)+_0x31916a(0x43e)+_0x4e5e5a(0x5de)+_0x31916a(0x2a2)+'--','beexG':_0x1cb309(0x40b)+_0x4e5e5a(0x554)+_0x4e5e5a(0x544)+_0x31916a(0x63f)+_0x1cb309(0x40b),'fwgXd':function(_0x41cf06,_0x2f2eee){return _0x41cf06(_0x2f2eee);},'gUQLe':function(_0x100d13,_0x4e14cc){return _0x100d13(_0x4e14cc);},'Zeidg':_0x4e5e5a(0x5f6),'ILDmv':_0x31916a(0x380)+'56','fTcuu':_0x1cb309(0x4a3)+'pt','rJPrn':function(_0x4b264a,_0x138059){return _0x4b264a!==_0x138059;},'eGbVE':_0x4e5e5a(0x320),'kKFie':function(_0x4f688d,_0x18e322){return _0x4f688d>_0x18e322;},'CnNMl':_0x1cb309(0x3db),'Ksdbq':function(_0x2421d2,_0x50c893){return _0x2421d2(_0x50c893);},'osvIC':function(_0x3a3430,_0x5a50ec){return _0x3a3430===_0x5a50ec;},'xJlgT':_0x31916a(0x837),'KVpoo':function(_0x5f50a5,_0x1acaa3){return _0x5f50a5===_0x1acaa3;},'ULHAE':_0x5d1a07(0x29e),'gouaF':_0x31916a(0x346),'CqGtf':_0x1cb309(0x6b9),'CEfGi':function(_0x4e775a,_0x5e6ba7){return _0x4e775a===_0x5e6ba7;},'LJOLM':_0x5d1a07(0x3a9),'hTfNl':function(_0x2dc536,_0x3ef3e5){return _0x2dc536>_0x3ef3e5;},'wPPXh':function(_0x38a107,_0x22935b){return _0x38a107>_0x22935b;},'TUqQo':function(_0x5d31cf,_0x416005){return _0x5d31cf!==_0x416005;},'tqVRp':_0x1cb309(0x698),'aYcfH':function(_0x116b5a,_0x120973,_0x321002){return _0x116b5a(_0x120973,_0x321002);},'nFbKw':function(_0x1195b0,_0x1959e9){return _0x1195b0(_0x1959e9);},'rZaeo':_0x5d1a07(0x27e)+_0x31916a(0x688),'OErwe':_0x31916a(0x599)+_0x1cb309(0x652)+_0x31916a(0x3ed)+')','tUvYY':_0x5d1a07(0x244)+_0x4e5e5a(0x5c3)+_0x31916a(0x4a9)+_0x31916a(0x494)+_0x5d1a07(0x7aa)+_0x4a5ffa(0x51c)+_0x31916a(0x5e3),'piTZg':function(_0x342b38,_0x408c13){return _0x342b38(_0x408c13);},'WBRWZ':_0x31916a(0x368),'ryXWO':function(_0x376461,_0x28a013){return _0x376461+_0x28a013;},'BLtgT':_0x4a5ffa(0x550),'NGjXM':_0x5d1a07(0x39e),'isjSD':function(_0x1ef966,_0xc53c4f,_0x41c29f){return _0x1ef966(_0xc53c4f,_0x41c29f);},'DnACe':function(_0x3df46e,_0x35c3ac){return _0x3df46e-_0x35c3ac;},'incHF':function(_0x23ee9b,_0x42019b){return _0x23ee9b<=_0x42019b;},'ziRIX':function(_0x11c3a3,_0x376ab7){return _0x11c3a3>_0x376ab7;},'kIBjB':_0x1cb309(0x3c2),'DrbZc':_0x4a5ffa(0x207),'wtFfp':_0x31916a(0x55f)+_0x1cb309(0x3c9)+'+$','wTpeg':_0x4e5e5a(0x57a),'SSaMh':_0x31916a(0x60c)},_0x3cedb7=_0x44f033[_0x5d1a07(0x52a)][_0x1cb309(0x3f4)+_0x4e5e5a(0x405)]();let _0x2caeed='',_0x58152='';_0x3cedb7[_0x31916a(0x53b)]()[_0x5d1a07(0x46e)](function _0x46a595({done:_0x34a058,value:_0x552169}){const _0x153c9f=_0x1cb309,_0x1e6ce1=_0x31916a,_0x58bc48=_0x5d1a07,_0x4ebeb9=_0x1cb309,_0x5572c5=_0x4e5e5a,_0x397f71={'Dcqbc':_0x995e0f[_0x153c9f(0x489)],'thYRW':_0x995e0f[_0x153c9f(0x809)],'MBthR':function(_0x595da5,_0x4601c2){const _0x48b9fe=_0x153c9f;return _0x995e0f[_0x48b9fe(0x311)](_0x595da5,_0x4601c2);},'NRaqQ':_0x995e0f[_0x153c9f(0x53d)],'RBPwf':function(_0x39959e,_0x566309){const _0x3f26a3=_0x58bc48;return _0x995e0f[_0x3f26a3(0x4c8)](_0x39959e,_0x566309);},'NvPGW':_0x995e0f[_0x58bc48(0x425)],'YEMYe':_0x995e0f[_0x5572c5(0x665)],'bRFiZ':function(_0x18578d){const _0x6f382b=_0x58bc48;return _0x995e0f[_0x6f382b(0x410)](_0x18578d);},'bnmvs':function(_0x2ec777,_0x4f6d22,_0x559136){const _0xb9f79e=_0x58bc48;return _0x995e0f[_0xb9f79e(0x308)](_0x2ec777,_0x4f6d22,_0x559136);},'jJHhV':function(_0x12ee7d,_0x415ec8){const _0x3fc388=_0x1e6ce1;return _0x995e0f[_0x3fc388(0x32a)](_0x12ee7d,_0x415ec8);},'LiWcU':function(_0x10ebb9,_0x36c402){const _0x12a892=_0x4ebeb9;return _0x995e0f[_0x12a892(0x5cc)](_0x10ebb9,_0x36c402);},'dsxHa':function(_0xc14184,_0x18fd2b){const _0x198dfb=_0x1e6ce1;return _0x995e0f[_0x198dfb(0x60d)](_0xc14184,_0x18fd2b);},'PtmzB':function(_0x3be473,_0x204364){const _0x1d8dc4=_0x58bc48;return _0x995e0f[_0x1d8dc4(0x623)](_0x3be473,_0x204364);},'mqcZv':function(_0x270318,_0x2030a3){const _0x3e9f6f=_0x1e6ce1;return _0x995e0f[_0x3e9f6f(0x20c)](_0x270318,_0x2030a3);},'ltbeF':_0x995e0f[_0x5572c5(0x485)],'wyXgu':_0x995e0f[_0x153c9f(0x6b3)],'cahWs':function(_0xa65b93,_0x1c691e){const _0x4506b1=_0x153c9f;return _0x995e0f[_0x4506b1(0x469)](_0xa65b93,_0x1c691e);},'aQykV':_0x995e0f[_0x1e6ce1(0x780)],'YWkRA':function(_0x276334,_0x3bfcc4){const _0x1a38a5=_0x1e6ce1;return _0x995e0f[_0x1a38a5(0x48b)](_0x276334,_0x3bfcc4);},'petdg':_0x995e0f[_0x5572c5(0x784)]};if(_0x995e0f[_0x4ebeb9(0x391)](_0x995e0f[_0x1e6ce1(0x479)],_0x995e0f[_0x58bc48(0x282)]))try{_0x3b684c=_0x995e0f[_0x153c9f(0x555)](_0x3729ff,_0x25b7e1);const _0x387327={};return _0x387327[_0x1e6ce1(0x3fe)]=_0x995e0f[_0x58bc48(0x20d)],_0x3be72b[_0x5572c5(0x58f)+'e'][_0x1e6ce1(0x255)+'pt'](_0x387327,_0x4a684c,_0x10bd41);}catch(_0x17f312){}else{if(_0x34a058)return;const _0x348b80=new TextDecoder(_0x995e0f[_0x1e6ce1(0x307)])[_0x153c9f(0x6ef)+'e'](_0x552169);return _0x348b80[_0x153c9f(0x705)]()[_0x1e6ce1(0x6fd)]('\x0a')[_0x1e6ce1(0x71d)+'ch'](function(_0xca29dc){const _0x3b6d87=_0x4ebeb9,_0x52c00c=_0x1e6ce1,_0x2b9117=_0x1e6ce1,_0x2a798c=_0x5572c5,_0x45b000=_0x1e6ce1,_0x47de26={'vGycU':function(_0x5a884b,_0x35215c){const _0x55159a=_0x59ea;return _0x995e0f[_0x55159a(0x7ac)](_0x5a884b,_0x35215c);},'GCeyK':_0x995e0f[_0x3b6d87(0x784)],'dbEfX':function(_0x59b546,_0x91bde9){const _0x5cbe9b=_0x3b6d87;return _0x995e0f[_0x5cbe9b(0x418)](_0x59b546,_0x91bde9);},'HwAvW':function(_0x4c2a84){const _0x2bba89=_0x3b6d87;return _0x995e0f[_0x2bba89(0x410)](_0x4c2a84);},'NWtSt':function(_0x5f1ca8,_0x1c5d9e){const _0x23f443=_0x3b6d87;return _0x995e0f[_0x23f443(0x5d5)](_0x5f1ca8,_0x1c5d9e);},'WCvQB':_0x995e0f[_0x3b6d87(0x574)],'jGBzN':function(_0x452e64,_0x18a4b0){const _0x328a81=_0x3b6d87;return _0x995e0f[_0x328a81(0x419)](_0x452e64,_0x18a4b0);},'YqQHo':function(_0x17fd6f,_0x3bc14f){const _0x5ba3ea=_0x52c00c;return _0x995e0f[_0x5ba3ea(0x57d)](_0x17fd6f,_0x3bc14f);},'AMmGj':_0x995e0f[_0x52c00c(0x766)],'CcbKQ':function(_0xa4d753,_0x2b4e3b){const _0x2af971=_0x3b6d87;return _0x995e0f[_0x2af971(0x730)](_0xa4d753,_0x2b4e3b);},'ePmKd':_0x995e0f[_0x52c00c(0x7ee)],'TCdKH':_0x995e0f[_0x2b9117(0x840)],'mcLVm':_0x995e0f[_0x2a798c(0x668)],'HyNEX':_0x995e0f[_0x52c00c(0x43c)],'BoTxQ':_0x995e0f[_0x2b9117(0x505)],'PSbxb':_0x995e0f[_0x2b9117(0x84f)],'gLIGW':_0x995e0f[_0x3b6d87(0x7ef)],'rTGzf':function(_0x5915f4,_0x42293b){const _0x375e46=_0x2b9117;return _0x995e0f[_0x375e46(0x48b)](_0x5915f4,_0x42293b);},'tjzoz':_0x995e0f[_0x2a798c(0x21c)],'sOYBM':_0x995e0f[_0x2b9117(0x7df)],'lFJcN':_0x995e0f[_0x2a798c(0x5bd)],'HhCkP':function(_0x50c4c9,_0x13f4c8){const _0x2754aa=_0x2a798c;return _0x995e0f[_0x2754aa(0x286)](_0x50c4c9,_0x13f4c8);},'ZmdUY':_0x995e0f[_0x2b9117(0x4ac)],'oXmfI':_0x995e0f[_0x52c00c(0x4b9)],'TCtYA':function(_0x34dcaf,_0x5eb9d3){const _0x40078e=_0x3b6d87;return _0x995e0f[_0x40078e(0x469)](_0x34dcaf,_0x5eb9d3);},'YLkER':function(_0x19ff67,_0x5bb363,_0x37cffd){const _0x2f97f3=_0x2a798c;return _0x995e0f[_0x2f97f3(0x57e)](_0x19ff67,_0x5bb363,_0x37cffd);},'qkYFy':_0x995e0f[_0x45b000(0x4f7)],'teTug':_0x995e0f[_0x2a798c(0x20d)],'AGlGh':_0x995e0f[_0x3b6d87(0x42f)],'KDuef':_0x995e0f[_0x3b6d87(0x65f)],'UlcED':_0x995e0f[_0x45b000(0x7e5)],'siEXu':_0x995e0f[_0x52c00c(0x2a0)],'fYxQp':_0x995e0f[_0x45b000(0x6c6)],'qnJzK':_0x995e0f[_0x52c00c(0x307)],'GVcqK':_0x995e0f[_0x3b6d87(0x200)],'rsdjZ':function(_0x38ec7d,_0x5ad4a4){const _0x52845e=_0x45b000;return _0x995e0f[_0x52845e(0x5d5)](_0x38ec7d,_0x5ad4a4);},'mgVoJ':_0x995e0f[_0x2a798c(0x7a0)],'PIQkF':_0x995e0f[_0x3b6d87(0x72e)],'LdnDt':_0x995e0f[_0x2a798c(0x5fb)],'bwXco':function(_0x478392,_0x47a2da){const _0x47117f=_0x2a798c;return _0x995e0f[_0x47117f(0x418)](_0x478392,_0x47a2da);},'CNEHU':_0x995e0f[_0x2b9117(0x1eb)],'VfWcY':_0x995e0f[_0x45b000(0x336)],'RSKVk':_0x995e0f[_0x2b9117(0x4bf)],'wDEps':_0x995e0f[_0x2b9117(0x1e9)],'XABtp':function(_0x4f30e6,_0x312ed0){const _0x2aae6=_0x52c00c;return _0x995e0f[_0x2aae6(0x5d5)](_0x4f30e6,_0x312ed0);},'ePnJn':_0x995e0f[_0x2b9117(0x2fe)],'phVgW':_0x995e0f[_0x2b9117(0x63b)],'xMCnU':_0x995e0f[_0x3b6d87(0x700)],'TYcLk':_0x995e0f[_0x2b9117(0x81a)],'FzWIN':function(_0x90c1f1,_0x2b34b2){const _0x42737f=_0x2b9117;return _0x995e0f[_0x42737f(0x32a)](_0x90c1f1,_0x2b34b2);},'GYEnm':_0x995e0f[_0x45b000(0x3b4)],'OUExX':_0x995e0f[_0x45b000(0x5c4)],'xCFgH':_0x995e0f[_0x3b6d87(0x4b0)],'CuFTg':_0x995e0f[_0x45b000(0x6e8)],'olGyP':_0x995e0f[_0x2a798c(0x803)],'ZUIKE':_0x995e0f[_0x2b9117(0x592)],'LyEMU':_0x995e0f[_0x2b9117(0x6eb)],'STLtb':function(_0xfe8dc,_0x411850){const _0x40d03b=_0x45b000;return _0x995e0f[_0x40d03b(0x32a)](_0xfe8dc,_0x411850);},'EgLEE':_0x995e0f[_0x45b000(0x24b)],'OYCxg':_0x995e0f[_0x52c00c(0x217)],'qWyfx':_0x995e0f[_0x2b9117(0x388)],'jzAmP':_0x995e0f[_0x3b6d87(0x26a)],'UAbZx':_0x995e0f[_0x3b6d87(0x1f0)],'FIgAn':function(_0x3a359e,_0xf97c70,_0x44192b){const _0x3b1960=_0x45b000;return _0x995e0f[_0x3b1960(0x2ea)](_0x3a359e,_0xf97c70,_0x44192b);},'VSIXf':function(_0x58b106,_0x1e655b){const _0x150e9c=_0x2b9117;return _0x995e0f[_0x150e9c(0x235)](_0x58b106,_0x1e655b);},'KWieB':_0x995e0f[_0x52c00c(0x2ed)],'QmyYh':_0x995e0f[_0x2b9117(0x239)],'rfFCf':function(_0x2b5165,_0x23529e){const _0x5b79eb=_0x52c00c;return _0x995e0f[_0x5b79eb(0x7fa)](_0x2b5165,_0x23529e);},'UkSux':function(_0x44d18d,_0x180b6f){const _0x2abdde=_0x3b6d87;return _0x995e0f[_0x2abdde(0x235)](_0x44d18d,_0x180b6f);},'BprxI':_0x995e0f[_0x2b9117(0x53c)],'LWkrJ':_0x995e0f[_0x52c00c(0x582)],'fMSrE':_0x995e0f[_0x2b9117(0x72a)],'ZPhWN':_0x995e0f[_0x2a798c(0x398)],'tdIgz':function(_0x12cbb9,_0x2eb4c6){const _0x425370=_0x3b6d87;return _0x995e0f[_0x425370(0x6e0)](_0x12cbb9,_0x2eb4c6);},'kPYUp':function(_0xf3ef6a,_0x1bf582){const _0x452fed=_0x3b6d87;return _0x995e0f[_0x452fed(0x348)](_0xf3ef6a,_0x1bf582);},'YTMXa':_0x995e0f[_0x45b000(0x7c8)],'ZeHXi':_0x995e0f[_0x52c00c(0x257)],'ZeOgl':_0x995e0f[_0x52c00c(0x44e)]};if(_0x995e0f[_0x52c00c(0x20c)](_0x995e0f[_0x52c00c(0x67c)],_0x995e0f[_0x52c00c(0x67c)]))try{_0xb4928e=_0x30feb9[_0x3b6d87(0x842)](_0x47de26[_0x2b9117(0x28d)](_0x238c7b,_0x322dd6))[_0x47de26[_0x2a798c(0x723)]],_0x55bb21='';}catch(_0x2f437f){_0x4f42b3=_0x4bc010[_0x3b6d87(0x842)](_0x222d46)[_0x47de26[_0x45b000(0x723)]],_0x80524a='';}else{if(_0x995e0f[_0x3b6d87(0x5b5)](_0xca29dc[_0x52c00c(0x377)+'h'],0x2046+0x1*0x47+-0x2087))_0x2caeed=_0xca29dc[_0x52c00c(0x483)](-0x22f4+-0x2202+0xa*0x6e6);if(_0x995e0f[_0x52c00c(0x57d)](_0x2caeed,_0x995e0f[_0x2b9117(0x766)])){if(_0x995e0f[_0x3b6d87(0x5d5)](_0x995e0f[_0x45b000(0x34e)],_0x995e0f[_0x2a798c(0x34e)])){const _0x29e703={'INrtY':YLPsQt[_0x2b9117(0x5ca)],'kgsoe':YLPsQt[_0x2a798c(0x1e8)],'TTAJP':function(_0x52eccf,_0x884ddd){const _0xd288bd=_0x2a798c;return YLPsQt[_0xd288bd(0x855)](_0x52eccf,_0x884ddd);},'BVVBd':YLPsQt[_0x45b000(0x49e)],'OaqnV':function(_0x3c2c7a,_0x83e607){const _0x4768e9=_0x52c00c;return YLPsQt[_0x4768e9(0x2dd)](_0x3c2c7a,_0x83e607);},'fLRwh':YLPsQt[_0x45b000(0x521)],'htVNk':function(_0x57c798,_0x4e8b85){const _0x47826d=_0x45b000;return YLPsQt[_0x47826d(0x2dd)](_0x57c798,_0x4e8b85);},'mwjaU':YLPsQt[_0x52c00c(0x223)],'wqYCt':function(_0x4ac79e){const _0x384b7d=_0x45b000;return YLPsQt[_0x384b7d(0x726)](_0x4ac79e);}};YLPsQt[_0x3b6d87(0x4c0)](_0x1725e8,this,function(){const _0x517825=_0x2a798c,_0x895cc=_0x2a798c,_0x28d170=_0x2a798c,_0x31d155=_0x2a798c,_0x95393e=_0x45b000,_0x142339=new _0x55d16b(_0x29e703[_0x517825(0x2ba)]),_0x7d3c7=new _0x54f55a(_0x29e703[_0x517825(0x31f)],'i'),_0x99777b=_0x29e703[_0x895cc(0x1dd)](_0x385587,_0x29e703[_0x28d170(0x54e)]);!_0x142339[_0x31d155(0x6fc)](_0x29e703[_0x895cc(0x834)](_0x99777b,_0x29e703[_0x517825(0x42c)]))||!_0x7d3c7[_0x28d170(0x6fc)](_0x29e703[_0x895cc(0x5b3)](_0x99777b,_0x29e703[_0x517825(0x3c4)]))?_0x29e703[_0x95393e(0x1dd)](_0x99777b,'0'):_0x29e703[_0x95393e(0x4b5)](_0x4e69f5);})();}else{text_offset=-(-0x15*0x1a5+-0x1e4d+-0x21*-0x1f7);const _0x2f7fd2={'method':_0x995e0f[_0x3b6d87(0x81a)],'headers':headers,'body':_0x995e0f[_0x2a798c(0x805)](b64EncodeUnicode,JSON[_0x2b9117(0x6f8)+_0x45b000(0x6f5)](prompt[_0x52c00c(0x749)]))};_0x995e0f[_0x3b6d87(0x57e)](fetch,_0x995e0f[_0x3b6d87(0x6e8)],_0x2f7fd2)[_0x3b6d87(0x46e)](_0x1beec6=>{const _0x2ad796=_0x52c00c,_0x3bffda=_0x2a798c,_0x1e7dbc=_0x2b9117,_0x126201=_0x2a798c,_0x4ce5b9=_0x2a798c,_0x4abf28={'UZkNx':function(_0x184cf8,_0xc5c37f){const _0x12b151=_0x59ea;return _0x397f71[_0x12b151(0x445)](_0x184cf8,_0xc5c37f);},'FBuEO':function(_0x7ba03f,_0x4b2107){const _0x2614ad=_0x59ea;return _0x397f71[_0x2614ad(0x516)](_0x7ba03f,_0x4b2107);},'NYymR':function(_0x3be4b7,_0x346359){const _0x591fdd=_0x59ea;return _0x397f71[_0x591fdd(0x71b)](_0x3be4b7,_0x346359);},'HeXjU':function(_0x18bf53,_0x5a5118){const _0x41e3d7=_0x59ea;return _0x397f71[_0x41e3d7(0x7bb)](_0x18bf53,_0x5a5118);},'aVXMM':function(_0x2b8393,_0x3a4933){const _0x3ac4c1=_0x59ea;return _0x397f71[_0x3ac4c1(0x516)](_0x2b8393,_0x3a4933);}};if(_0x397f71[_0x2ad796(0x6c1)](_0x397f71[_0x3bffda(0x22e)],_0x397f71[_0x2ad796(0x41c)])){const _0x3bdfef=_0x1beec6[_0x3bffda(0x52a)][_0x126201(0x3f4)+_0x126201(0x405)]();let _0x2e10a7='',_0x33e8ad='';_0x3bdfef[_0x126201(0x53b)]()[_0x4ce5b9(0x46e)](function _0x414b36({done:_0x59a379,value:_0x345a02}){const _0x151467=_0x1e7dbc,_0x172967=_0x3bffda,_0x46cda0=_0x2ad796,_0x120c2c=_0x2ad796,_0x2e0506=_0x2ad796,_0x29113c={'jFmAj':function(_0x1a1966,_0x458970){const _0x5c3acb=_0x59ea;return _0x47de26[_0x5c3acb(0x52c)](_0x1a1966,_0x458970);},'AkyVB':_0x47de26[_0x151467(0x723)],'aPOVx':function(_0x105583){const _0x56ceac=_0x151467;return _0x47de26[_0x56ceac(0x1f7)](_0x105583);},'HDuHa':function(_0x3c7b2e,_0x2aaa4e){const _0x5a8ae5=_0x151467;return _0x47de26[_0x5a8ae5(0x289)](_0x3c7b2e,_0x2aaa4e);},'YEoSe':_0x47de26[_0x151467(0x55a)],'lIsKn':function(_0x3ffd95,_0x11e4a6){const _0x1027c7=_0x172967;return _0x47de26[_0x1027c7(0x340)](_0x3ffd95,_0x11e4a6);},'gZBJa':function(_0x3302c1,_0x48cb6d){const _0x5719df=_0x151467;return _0x47de26[_0x5719df(0x81d)](_0x3302c1,_0x48cb6d);},'MfOsg':_0x47de26[_0x172967(0x3f1)],'gRWto':function(_0x59fd4e,_0x38482b){const _0x2475c5=_0x46cda0;return _0x47de26[_0x2475c5(0x817)](_0x59fd4e,_0x38482b);},'Myokk':_0x47de26[_0x120c2c(0x486)],'fceit':_0x47de26[_0x120c2c(0x6d7)],'kMvlp':_0x47de26[_0x46cda0(0x6fa)],'jKDsC':_0x47de26[_0x46cda0(0x254)],'PzhxH':_0x47de26[_0x120c2c(0x1c7)],'xVfzd':_0x47de26[_0x120c2c(0x415)],'zehYi':_0x47de26[_0x2e0506(0x6d6)],'simJD':function(_0xdfaae9,_0x108b8a){const _0x2aca2d=_0x151467;return _0x47de26[_0x2aca2d(0x77e)](_0xdfaae9,_0x108b8a);},'YlsRl':_0x47de26[_0x120c2c(0x420)],'PKGti':_0x47de26[_0x2e0506(0x34d)],'lHkQf':_0x47de26[_0x151467(0x7c5)],'LsnVa':function(_0x3a76b5,_0x31b83e){const _0x3d275a=_0x151467;return _0x47de26[_0x3d275a(0x272)](_0x3a76b5,_0x31b83e);},'tjMbq':_0x47de26[_0x151467(0x5d3)],'AOdhi':_0x47de26[_0x172967(0x746)],'PSZsQ':function(_0x431c46,_0x333567){const _0x208d7a=_0x46cda0;return _0x47de26[_0x208d7a(0x50d)](_0x431c46,_0x333567);},'KXzoj':function(_0x24d6b3,_0x4e9022,_0x437bf6){const _0x2199ab=_0x120c2c;return _0x47de26[_0x2199ab(0x440)](_0x24d6b3,_0x4e9022,_0x437bf6);},'kYQZN':_0x47de26[_0x2e0506(0x5f4)],'KUziz':_0x47de26[_0x46cda0(0x39f)],'pqrGE':function(_0x592d1c,_0x13c052){const _0x5de424=_0x46cda0;return _0x47de26[_0x5de424(0x77e)](_0x592d1c,_0x13c052);},'Meaxe':_0x47de26[_0x46cda0(0x43d)],'rGbQt':_0x47de26[_0x2e0506(0x2a1)],'wnyHr':_0x47de26[_0x172967(0x71f)],'XvLcd':_0x47de26[_0x46cda0(0x610)],'WPoIj':_0x47de26[_0x172967(0x862)],'sAPeR':_0x47de26[_0x46cda0(0x52e)],'cVCsz':_0x47de26[_0x172967(0x6a7)],'mtLPj':function(_0x26c83d,_0x57a68f){const _0x4761d0=_0x46cda0;return _0x47de26[_0x4761d0(0x28e)](_0x26c83d,_0x57a68f);},'ITgIG':_0x47de26[_0x120c2c(0x794)],'yQTFW':_0x47de26[_0x172967(0x4df)],'gtltK':_0x47de26[_0x120c2c(0x2de)],'ayOZF':function(_0x27e177,_0x1dd21){const _0x5363a6=_0x46cda0;return _0x47de26[_0x5363a6(0x457)](_0x27e177,_0x1dd21);},'YEVWo':_0x47de26[_0x46cda0(0x761)],'Qxked':_0x47de26[_0x46cda0(0x667)],'rpApb':function(_0x2b6d86,_0x3a0b59){const _0x273130=_0x2e0506;return _0x47de26[_0x273130(0x289)](_0x2b6d86,_0x3a0b59);},'ZbHkJ':_0x47de26[_0x120c2c(0x363)],'lisqM':_0x47de26[_0x172967(0x414)],'bvpXC':function(_0x1f1cb4,_0x6f7159){const _0x56607b=_0x151467;return _0x47de26[_0x56607b(0x81d)](_0x1f1cb4,_0x6f7159);},'ByIdW':function(_0x2035da,_0x35a0b0){const _0x527b5=_0x172967;return _0x47de26[_0x527b5(0x1f4)](_0x2035da,_0x35a0b0);},'VMlgk':_0x47de26[_0x151467(0x7c2)],'HmMGp':_0x47de26[_0x46cda0(0x611)],'GQyBc':_0x47de26[_0x2e0506(0x1da)],'pRmYj':_0x47de26[_0x172967(0x2e5)],'VgoyD':function(_0x58e96e,_0x65b47d){const _0x1fac5f=_0x2e0506;return _0x47de26[_0x1fac5f(0x52c)](_0x58e96e,_0x65b47d);},'EMxIV':function(_0x71a5e3,_0x317faf){const _0x2f4fff=_0x120c2c;return _0x47de26[_0x2f4fff(0x332)](_0x71a5e3,_0x317faf);},'RJHRM':_0x47de26[_0x151467(0x538)],'TTGnX':_0x47de26[_0x120c2c(0x4db)],'oWxEy':_0x47de26[_0x120c2c(0x4fb)],'vgZiW':function(_0x5c2acf,_0x4d2162,_0x75236e){const _0x3edb99=_0x46cda0;return _0x47de26[_0x3edb99(0x440)](_0x5c2acf,_0x4d2162,_0x75236e);},'zWgWg':_0x47de26[_0x172967(0x6cb)],'NiNCa':_0x47de26[_0x151467(0x22b)],'VtTNN':_0x47de26[_0x151467(0x2be)],'Ohlxy':_0x47de26[_0x120c2c(0x548)],'VLhdG':function(_0x14cb72,_0xd033b5){const _0x3a8e43=_0x120c2c;return _0x47de26[_0x3a8e43(0x34c)](_0x14cb72,_0xd033b5);},'pIPFG':_0x47de26[_0x2e0506(0x47d)],'XFZky':function(_0x369dcf,_0x347149){const _0x5286ee=_0x172967;return _0x47de26[_0x5286ee(0x817)](_0x369dcf,_0x347149);},'YKfpQ':_0x47de26[_0x120c2c(0x4bd)],'rifUc':_0x47de26[_0x120c2c(0x863)],'usfwk':_0x47de26[_0x151467(0x83a)],'PyARf':_0x47de26[_0x120c2c(0x4d3)],'bmpQg':function(_0x56f9e5,_0x2fb411,_0x3d8ef3){const _0x2a449b=_0x120c2c;return _0x47de26[_0x2a449b(0x6b1)](_0x56f9e5,_0x2fb411,_0x3d8ef3);}};if(_0x47de26[_0x151467(0x203)](_0x47de26[_0x2e0506(0x438)],_0x47de26[_0x46cda0(0x3ce)])){if(_0x59a379)return;const _0x3f14df=new TextDecoder(_0x47de26[_0x2e0506(0x52e)])[_0x2e0506(0x6ef)+'e'](_0x345a02);return _0x3f14df[_0x151467(0x705)]()[_0x151467(0x6fd)]('\x0a')[_0x2e0506(0x71d)+'ch'](function(_0xa714a4){const _0x4a7eb0=_0x172967,_0x4c1fc8=_0x120c2c,_0x311470=_0x120c2c,_0x4d1345=_0x2e0506,_0x454de9=_0x46cda0,_0x15ea58={'ElXZq':function(_0x54ddaf){const _0x102f4a=_0x59ea;return _0x29113c[_0x102f4a(0x641)](_0x54ddaf);},'ulJYL':_0x29113c[_0x4a7eb0(0x4f1)],'pBjFc':function(_0x174583,_0x90a69c){const _0x629afc=_0x4a7eb0;return _0x29113c[_0x629afc(0x797)](_0x174583,_0x90a69c);},'yuwfE':_0x29113c[_0x4c1fc8(0x2c4)],'lXtmS':function(_0x27ad96,_0x9ebfbe){const _0x3eb7d4=_0x4a7eb0;return _0x29113c[_0x3eb7d4(0x7fc)](_0x27ad96,_0x9ebfbe);},'XJjuU':function(_0x1b2060,_0x2ee9b8){const _0x23a828=_0x4a7eb0;return _0x29113c[_0x23a828(0x28a)](_0x1b2060,_0x2ee9b8);},'AbzdU':_0x29113c[_0x4a7eb0(0x742)],'RPiGo':function(_0x1d9458,_0x3dff93){const _0x4ab7dd=_0x4c1fc8;return _0x29113c[_0x4ab7dd(0x798)](_0x1d9458,_0x3dff93);},'VzeYO':_0x29113c[_0x4a7eb0(0x67f)],'BTmoH':_0x29113c[_0x4c1fc8(0x2bc)],'OAQaz':_0x29113c[_0x4a7eb0(0x23e)],'ApGAU':_0x29113c[_0x4d1345(0x584)],'ZtFcn':_0x29113c[_0x311470(0x4d9)],'tOWoI':_0x29113c[_0x4d1345(0x1c5)],'kIvrC':_0x29113c[_0x4d1345(0x597)],'tzxdw':function(_0x1b1436,_0x53deb5){const _0x5b5d45=_0x4c1fc8;return _0x29113c[_0x5b5d45(0x5cd)](_0x1b1436,_0x53deb5);},'vhsiv':_0x29113c[_0x454de9(0x626)],'kiirW':_0x29113c[_0x311470(0x694)],'bmIhN':_0x29113c[_0x311470(0x33d)],'UKNdY':function(_0x1ed57c,_0xccd091){const _0x144213=_0x4a7eb0;return _0x29113c[_0x144213(0x2e9)](_0x1ed57c,_0xccd091);},'pkwJE':function(_0x3c967b,_0x3ed489){const _0x5ab223=_0x4a7eb0;return _0x29113c[_0x5ab223(0x2e9)](_0x3c967b,_0x3ed489);},'xzsic':_0x29113c[_0x311470(0x6f7)],'tUMls':_0x29113c[_0x454de9(0x79e)],'bLwdO':function(_0x4ade24,_0x7bcf67){const _0x3b2ebe=_0x454de9;return _0x29113c[_0x3b2ebe(0x750)](_0x4ade24,_0x7bcf67);},'dOvom':function(_0x32ec11,_0xf517b7,_0x2eff1c){const _0x59da5a=_0x454de9;return _0x29113c[_0x59da5a(0x722)](_0x32ec11,_0xf517b7,_0x2eff1c);},'nJTqg':function(_0x1b4669,_0x258b74){const _0x273820=_0x4d1345;return _0x29113c[_0x273820(0x64c)](_0x1b4669,_0x258b74);},'ECdgu':_0x29113c[_0x4a7eb0(0x37a)],'GhEmx':_0x29113c[_0x4d1345(0x29a)],'CRpjN':function(_0x3eb229,_0x3b8bf7){const _0x44794f=_0x4a7eb0;return _0x29113c[_0x44794f(0x490)](_0x3eb229,_0x3b8bf7);},'tMTGr':_0x29113c[_0x311470(0x2bf)],'GXaNI':_0x29113c[_0x454de9(0x36e)],'PgrRu':_0x29113c[_0x4a7eb0(0x54c)],'tFrQZ':_0x29113c[_0x454de9(0x67a)],'FPUWQ':_0x29113c[_0x4a7eb0(0x347)],'GRiKc':_0x29113c[_0x4c1fc8(0x60f)],'BCdYN':_0x29113c[_0x4d1345(0x443)],'lFKfb':function(_0x2fc7f9,_0x593373){const _0x47320c=_0x4d1345;return _0x29113c[_0x47320c(0x6d5)](_0x2fc7f9,_0x593373);},'rlCxd':_0x29113c[_0x454de9(0x1e6)],'OjjaA':_0x29113c[_0x4c1fc8(0x30a)],'NQJOJ':_0x29113c[_0x454de9(0x39a)],'Itvsd':function(_0x664da8,_0xb85224){const _0x1effe6=_0x311470;return _0x29113c[_0x1effe6(0x402)](_0x664da8,_0xb85224);},'ynVSh':_0x29113c[_0x4a7eb0(0x407)],'yEqzJ':_0x29113c[_0x4a7eb0(0x1d4)]};if(_0x29113c[_0x454de9(0x75f)](_0x29113c[_0x4a7eb0(0x66a)],_0x29113c[_0x4c1fc8(0x7a9)])){if(_0x29113c[_0x4a7eb0(0x7fc)](_0xa714a4[_0x4a7eb0(0x377)+'h'],0x5a*-0x4a+0x6a1*-0x1+0x20ab))_0x2e10a7=_0xa714a4[_0x4c1fc8(0x483)](0x53a+0xd23+-0x1257);if(_0x29113c[_0x311470(0x364)](_0x2e10a7,_0x29113c[_0x4c1fc8(0x742)])){if(_0x29113c[_0x454de9(0x275)](_0x29113c[_0x4c1fc8(0x2c6)],_0x29113c[_0x311470(0x1e2)])){document[_0x4a7eb0(0x756)+_0x311470(0x498)+_0x4a7eb0(0x77c)](_0x29113c[_0x454de9(0x4d8)])[_0x311470(0x845)+_0x4d1345(0x37e)]='',_0x29113c[_0x4c1fc8(0x641)](chatmore);const _0x5676bc={'method':_0x29113c[_0x311470(0x50f)],'headers':headers,'body':_0x29113c[_0x311470(0x4ee)](b64EncodeUnicode,JSON[_0x4a7eb0(0x6f8)+_0x4a7eb0(0x6f5)]({'prompt':_0x29113c[_0x311470(0x490)](_0x29113c[_0x454de9(0x6c4)](_0x29113c[_0x311470(0x5cd)](_0x29113c[_0x311470(0x490)](_0x29113c[_0x311470(0x241)],original_search_query),_0x29113c[_0x4d1345(0x6e2)]),document[_0x4c1fc8(0x756)+_0x4d1345(0x498)+_0x311470(0x77c)](_0x29113c[_0x454de9(0x35b)])[_0x311470(0x845)+_0x311470(0x37e)][_0x4c1fc8(0x72b)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x4a7eb0(0x72b)+'ce'](/<hr.*/gs,'')[_0x4d1345(0x72b)+'ce'](/<[^>]+>/g,'')[_0x4d1345(0x72b)+'ce'](/\n\n/g,'\x0a')),'\x0a'),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':!![]}))};_0x29113c[_0x454de9(0x201)](fetch,_0x29113c[_0x4c1fc8(0x455)],_0x5676bc)[_0x4c1fc8(0x46e)](_0x34d9ba=>{const _0x2e7ef7=_0x311470,_0x50f743=_0x454de9,_0x5a8627=_0x4a7eb0,_0x1238d8=_0x311470,_0x470e18=_0x4d1345,_0x37cbcb={'EZgSd':function(_0x3880d1){const _0x1a9604=_0x59ea;return _0x15ea58[_0x1a9604(0x58e)](_0x3880d1);},'pBzWB':_0x15ea58[_0x2e7ef7(0x59c)],'QEuOV':function(_0x7b6816,_0x25908d){const _0x283466=_0x2e7ef7;return _0x15ea58[_0x283466(0x740)](_0x7b6816,_0x25908d);},'Pyhuq':_0x15ea58[_0x2e7ef7(0x2ce)],'hWcFt':function(_0x53057b,_0x565292){const _0xb2d4bd=_0x2e7ef7;return _0x15ea58[_0xb2d4bd(0x54d)](_0x53057b,_0x565292);},'QaYvk':function(_0x1e11b4,_0x38924c){const _0x295abc=_0x50f743;return _0x15ea58[_0x295abc(0x600)](_0x1e11b4,_0x38924c);},'KknnG':_0x15ea58[_0x5a8627(0x758)],'dXXBi':function(_0x5ac290,_0x202ced){const _0x28cadf=_0x50f743;return _0x15ea58[_0x28cadf(0x6fb)](_0x5ac290,_0x202ced);},'vQmmp':_0x15ea58[_0x5a8627(0x52f)],'NRDyu':_0x15ea58[_0x2e7ef7(0x793)],'uwdPs':_0x15ea58[_0x5a8627(0x484)],'WBnmr':_0x15ea58[_0x470e18(0x796)],'rXvHR':_0x15ea58[_0x470e18(0x7a5)],'OCMxI':_0x15ea58[_0x50f743(0x61f)],'uqmBq':_0x15ea58[_0x5a8627(0x836)],'XPwuh':function(_0x38faa9,_0x583a20){const _0x3a7ce5=_0x5a8627;return _0x15ea58[_0x3a7ce5(0x765)](_0x38faa9,_0x583a20);},'tjNqP':_0x15ea58[_0x5a8627(0x4c9)],'SsHZT':function(_0x4e24e2,_0x12e9c1){const _0x80be02=_0x1238d8;return _0x15ea58[_0x80be02(0x6fb)](_0x4e24e2,_0x12e9c1);},'sGHVZ':_0x15ea58[_0x5a8627(0x4f6)],'LkyVC':_0x15ea58[_0x5a8627(0x680)],'gutpn':function(_0x58b8d9,_0x40b340){const _0x3c56c0=_0x5a8627;return _0x15ea58[_0x3c56c0(0x701)](_0x58b8d9,_0x40b340);},'EVItV':function(_0x11cb02,_0x897acb){const _0x269507=_0x5a8627;return _0x15ea58[_0x269507(0x653)](_0x11cb02,_0x897acb);},'TYKts':_0x15ea58[_0x50f743(0x5fc)],'FLQgu':_0x15ea58[_0x50f743(0x270)],'VRWqo':function(_0x197537,_0x281d18){const _0x107756=_0x470e18;return _0x15ea58[_0x107756(0x430)](_0x197537,_0x281d18);},'fMGyo':function(_0x4ffbc1,_0x4bdbdc,_0x323341){const _0x12df32=_0x470e18;return _0x15ea58[_0x12df32(0x619)](_0x4ffbc1,_0x4bdbdc,_0x323341);},'POyhK':function(_0x372f27,_0x5bb485){const _0x567f7f=_0x470e18;return _0x15ea58[_0x567f7f(0x4ff)](_0x372f27,_0x5bb485);},'ckjkk':_0x15ea58[_0x50f743(0x741)],'zfTba':_0x15ea58[_0x5a8627(0x499)],'IPPlg':function(_0x4bbf5,_0x32f80b){const _0x5a91b4=_0x5a8627;return _0x15ea58[_0x5a91b4(0x674)](_0x4bbf5,_0x32f80b);},'Wnmnz':_0x15ea58[_0x5a8627(0x267)],'sSEPp':_0x15ea58[_0x5a8627(0x5f0)],'abAgP':_0x15ea58[_0x50f743(0x553)],'DbFYE':_0x15ea58[_0x50f743(0x313)],'KwafV':_0x15ea58[_0x2e7ef7(0x2e0)],'iErbb':_0x15ea58[_0x5a8627(0x492)]};if(_0x15ea58[_0x50f743(0x6fb)](_0x15ea58[_0x5a8627(0x4a5)],_0x15ea58[_0x470e18(0x4a5)])){const _0x125a6f=_0x34d9ba[_0x1238d8(0x52a)][_0x5a8627(0x3f4)+_0x2e7ef7(0x405)]();let _0x79bd40='',_0x2e0f2d='';_0x125a6f[_0x470e18(0x53b)]()[_0x5a8627(0x46e)](function _0x52a003({done:_0x5d5055,value:_0x1343c2}){const _0x25889c=_0x470e18,_0x4d0917=_0x2e7ef7,_0x5ca4fd=_0x1238d8,_0x4efcb0=_0x50f743,_0x2425e7=_0x1238d8,_0x3ba1dd={'BdGmT':_0x37cbcb[_0x25889c(0x51f)],'eUgxv':function(_0x2201e6,_0x14c863){const _0xc79de5=_0x25889c;return _0x37cbcb[_0xc79de5(0x570)](_0x2201e6,_0x14c863);},'bqAGG':_0x37cbcb[_0x4d0917(0x40f)],'ExWov':function(_0x29fa13,_0x2564b1){const _0x320a2b=_0x4d0917;return _0x37cbcb[_0x320a2b(0x628)](_0x29fa13,_0x2564b1);},'clLjQ':_0x37cbcb[_0x25889c(0x371)],'tsvFG':_0x37cbcb[_0x25889c(0x34f)],'yPKCY':_0x37cbcb[_0x25889c(0x369)]};if(_0x37cbcb[_0x2425e7(0x2eb)](_0x37cbcb[_0x2425e7(0x683)],_0x37cbcb[_0x2425e7(0x344)])){if(_0x5d5055)return;const _0x3aadfd=new TextDecoder(_0x37cbcb[_0x2425e7(0x4ea)])[_0x4efcb0(0x6ef)+'e'](_0x1343c2);return _0x3aadfd[_0x5ca4fd(0x705)]()[_0x4d0917(0x6fd)]('\x0a')[_0x25889c(0x71d)+'ch'](function(_0x8d8893){const _0x528157=_0x25889c,_0x161fb8=_0x4efcb0,_0x483112=_0x4efcb0,_0x5ef5a8=_0x4efcb0,_0x2eff3d=_0x5ca4fd,_0x24e6bc={'kMqUm':function(_0xce5c4f){const _0x2a723c=_0x59ea;return _0x37cbcb[_0x2a723c(0x30b)](_0xce5c4f);},'EKlSg':_0x37cbcb[_0x528157(0x51f)]};if(_0x37cbcb[_0x528157(0x2eb)](_0x37cbcb[_0x483112(0x456)],_0x37cbcb[_0x161fb8(0x456)]))_0x440543=_0x946d80[_0x2eff3d(0x842)](_0xcaa24d)[_0x3ba1dd[_0x528157(0x511)]],_0x538ef0='';else{if(_0x37cbcb[_0x2eff3d(0x648)](_0x8d8893[_0x161fb8(0x377)+'h'],0x2412+-0x10ab+-0x1361))_0x79bd40=_0x8d8893[_0x528157(0x483)](-0x22d*-0xe+0x1c33*-0x1+-0x23d);if(_0x37cbcb[_0x161fb8(0x859)](_0x79bd40,_0x37cbcb[_0x483112(0x41d)])){if(_0x37cbcb[_0x2eff3d(0x2e1)](_0x37cbcb[_0x2eff3d(0x536)],_0x37cbcb[_0x2eff3d(0x33a)]))_0x2dc776=_0x31c118[_0x2eff3d(0x49d)+_0x5ef5a8(0x673)+'t'],_0x53ca42[_0x483112(0x3a0)+'e'](),_0x24e6bc[_0x483112(0x593)](_0x19e118);else{lock_chat=-0x623*-0x3+0x1*-0x2197+0x86*0x1d,document[_0x5ef5a8(0x7a7)+_0x483112(0x5c2)+_0x2eff3d(0x524)](_0x37cbcb[_0x528157(0x6c5)])[_0x161fb8(0x3e3)][_0x5ef5a8(0x326)+'ay']='',document[_0x483112(0x7a7)+_0x528157(0x5c2)+_0x528157(0x524)](_0x37cbcb[_0x483112(0x4c7)])[_0x2eff3d(0x3e3)][_0x5ef5a8(0x326)+'ay']='';return;}}let _0x227b30;try{if(_0x37cbcb[_0x528157(0x2eb)](_0x37cbcb[_0x528157(0x20f)],_0x37cbcb[_0x161fb8(0x337)]))try{_0x37cbcb[_0x483112(0x2e1)](_0x37cbcb[_0x483112(0x1e1)],_0x37cbcb[_0x2eff3d(0x1e1)])?(_0x227b30=JSON[_0x2eff3d(0x842)](_0x37cbcb[_0x528157(0x70e)](_0x2e0f2d,_0x79bd40))[_0x37cbcb[_0x5ef5a8(0x51f)]],_0x2e0f2d=''):(_0x56f0be=_0x50e0db[_0x2eff3d(0x842)](_0x5c424b)[_0x24e6bc[_0x161fb8(0x2fc)]],_0x43f016='');}catch(_0x1237ed){if(_0x37cbcb[_0x5ef5a8(0x2eb)](_0x37cbcb[_0x483112(0x579)],_0x37cbcb[_0x5ef5a8(0x579)]))return!![];else _0x227b30=JSON[_0x161fb8(0x842)](_0x79bd40)[_0x37cbcb[_0x2eff3d(0x51f)]],_0x2e0f2d='';}else{if(_0x53033c){const _0x418229=_0x24734d[_0x483112(0x5eb)](_0x24d7b3,arguments);return _0x2c2575=null,_0x418229;}}}catch(_0x5d6cbc){if(_0x37cbcb[_0x161fb8(0x1f8)](_0x37cbcb[_0x161fb8(0x1ff)],_0x37cbcb[_0x528157(0x656)])){_0x29f351=_0x3ba1dd[_0x2eff3d(0x24d)](_0x149162,_0x3810e9);const _0x591e41={};return _0x591e41[_0x483112(0x3fe)]=_0x3ba1dd[_0x483112(0x49a)],_0x17ec2d[_0x2eff3d(0x58f)+'e'][_0x5ef5a8(0x255)+'pt'](_0x591e41,_0x49ab2a,_0x4aa4bb);}else _0x2e0f2d+=_0x79bd40;}_0x227b30&&_0x37cbcb[_0x2eff3d(0x4c3)](_0x227b30[_0x528157(0x377)+'h'],0x235e+-0x11d1*0x1+-0x118d)&&_0x37cbcb[_0x483112(0x22f)](_0x227b30[-0x71*0x1a+-0x1f62+0xd3*0x34][_0x2eff3d(0x721)+_0x5ef5a8(0x66b)][_0x5ef5a8(0x396)+_0x161fb8(0x5b6)+'t'][-0x131f+0x19d*-0x7+-0x1ca*-0x11],text_offset)&&(_0x37cbcb[_0x2eff3d(0x2eb)](_0x37cbcb[_0x161fb8(0x558)],_0x37cbcb[_0x528157(0x552)])?(chatTextRawPlusComment+=_0x227b30[-0x2*-0x8f4+-0xb77+0x671*-0x1][_0x528157(0x5b4)],text_offset=_0x227b30[-0x1*-0xad2+0x1c10+0xe*-0x2c7][_0x483112(0x721)+_0x5ef5a8(0x66b)][_0x483112(0x396)+_0x2eff3d(0x5b6)+'t'][_0x37cbcb[_0x161fb8(0x679)](_0x227b30[0x1*-0x1396+0x2a1*0xe+-0x44e*0x4][_0x483112(0x721)+_0x5ef5a8(0x66b)][_0x161fb8(0x396)+_0x161fb8(0x5b6)+'t'][_0x483112(0x377)+'h'],0xb63+0x1644+-0x10d3*0x2)]):function(){return![];}[_0x528157(0x2ec)+_0x161fb8(0x513)+'r'](AnymOJ[_0x161fb8(0x29d)](AnymOJ[_0x161fb8(0x3c8)],AnymOJ[_0x2eff3d(0x662)]))[_0x2eff3d(0x5eb)](AnymOJ[_0x483112(0x634)])),_0x37cbcb[_0x5ef5a8(0x5a9)](markdownToHtml,_0x37cbcb[_0x5ef5a8(0x570)](beautify,chatTextRawPlusComment),document[_0x2eff3d(0x7a7)+_0x161fb8(0x5c2)+_0x5ef5a8(0x524)](_0x37cbcb[_0x5ef5a8(0x1cd)]));}}),_0x125a6f[_0x2425e7(0x53b)]()[_0x5ca4fd(0x46e)](_0x52a003);}else{const _0x37febf=_0x2cff34?function(){const _0x275481=_0x4d0917;if(_0x17cd82){const _0x2ca8d7=_0x43690c[_0x275481(0x5eb)](_0x191c6a,arguments);return _0x1a80e4=null,_0x2ca8d7;}}:function(){};return _0x6b97b0=![],_0x37febf;}});}else{const _0x25df98=_0x4da683[_0x470e18(0x5eb)](_0x215b99,arguments);return _0x2e7e70=null,_0x25df98;}})[_0x311470(0x82f)](_0x2d113b=>{const _0x5e5ec0=_0x4a7eb0,_0x1f1acf=_0x4d1345,_0x279008=_0x454de9,_0x4af67b=_0x4d1345,_0x23d772=_0x311470;if(_0x15ea58[_0x5e5ec0(0x6ae)](_0x15ea58[_0x1f1acf(0x811)],_0x15ea58[_0x279008(0x71e)]))console[_0x1f1acf(0x728)](_0x15ea58[_0x279008(0x4f4)],_0x2d113b);else return![];});return;}else{if(_0x1dde2b)return _0xc9bd8f;else yaBDQx[_0x454de9(0x64c)](_0xc7265,-0x26e6+0x3fd+0x3*0xba3);}}let _0x23bd57;try{if(_0x29113c[_0x454de9(0x797)](_0x29113c[_0x4a7eb0(0x578)],_0x29113c[_0x454de9(0x2f9)]))try{_0x29113c[_0x454de9(0x797)](_0x29113c[_0x4a7eb0(0x206)],_0x29113c[_0x454de9(0x206)])?(_0x3d4e2b=_0x93a86[_0x4c1fc8(0x842)](_0x367707)[_0x29113c[_0x4a7eb0(0x4f1)]],_0x14646f=''):(_0x23bd57=JSON[_0x4c1fc8(0x842)](_0x29113c[_0x4a7eb0(0x375)](_0x33e8ad,_0x2e10a7))[_0x29113c[_0x4c1fc8(0x4f1)]],_0x33e8ad='');}catch(_0x2fc4ce){if(_0x29113c[_0x4d1345(0x75f)](_0x29113c[_0x311470(0x26d)],_0x29113c[_0x4a7eb0(0x26d)]))return _0x12f28a;else _0x23bd57=JSON[_0x4a7eb0(0x842)](_0x2e10a7)[_0x29113c[_0x4c1fc8(0x4f1)]],_0x33e8ad='';}else wLUUYm[_0x454de9(0x474)](_0x43df70,0x4fe+-0x2706+0x2208);}catch(_0x57f527){_0x29113c[_0x4c1fc8(0x5b1)](_0x29113c[_0x4d1345(0x83c)],_0x29113c[_0x4c1fc8(0x1f6)])?_0xbf1579[_0x311470(0x728)](_0x15ea58[_0x4d1345(0x4f4)],_0x4af20f):_0x33e8ad+=_0x2e10a7;}if(_0x23bd57&&_0x29113c[_0x454de9(0x7fc)](_0x23bd57[_0x4c1fc8(0x377)+'h'],0x2b*-0xdf+-0x95*-0x2e+0x223*0x5)&&_0x29113c[_0x454de9(0x2e9)](_0x23bd57[-0x1238+0xa*0x5+-0x301*-0x6][_0x4d1345(0x721)+_0x4c1fc8(0x66b)][_0x4c1fc8(0x396)+_0x4d1345(0x5b6)+'t'][0x1*-0x1933+0xc2a+0xd09],text_offset)){if(_0x29113c[_0x4d1345(0x275)](_0x29113c[_0x4a7eb0(0x3c7)],_0x29113c[_0x4d1345(0x331)]))chatTextRaw+=_0x23bd57[-0x136b+-0xb9a+0x1f05][_0x4c1fc8(0x5b4)],text_offset=_0x23bd57[-0x6c3+-0x26a6+0x2d69][_0x4c1fc8(0x721)+_0x4c1fc8(0x66b)][_0x4d1345(0x396)+_0x4d1345(0x5b6)+'t'][_0x29113c[_0x454de9(0x750)](_0x23bd57[-0x1a24+0xb*0x1c5+0x6ad*0x1][_0x4c1fc8(0x721)+_0x311470(0x66b)][_0x311470(0x396)+_0x4a7eb0(0x5b6)+'t'][_0x4d1345(0x377)+'h'],-0x3*-0x31d+0x15bb*-0x1+0x1*0xc65)];else return function(_0x3424e5){}[_0x454de9(0x2ec)+_0x4a7eb0(0x513)+'r'](wLUUYm[_0x311470(0x59d)])[_0x454de9(0x5eb)](wLUUYm[_0x454de9(0x2c5)]);}_0x29113c[_0x454de9(0x1d3)](markdownToHtml,_0x29113c[_0x454de9(0x402)](beautify,chatTextRaw),document[_0x4a7eb0(0x7a7)+_0x4d1345(0x5c2)+_0x311470(0x524)](_0x29113c[_0x311470(0x37a)]));}else _0x3fae60+=_0x4bca65[_0x4a7eb0(0x32c)+_0x311470(0x620)+_0x4c1fc8(0x3b3)](_0x12ed7f[_0x7dbfdd]);}),_0x3bdfef[_0x2e0506(0x53b)]()[_0x2e0506(0x46e)](_0x414b36);}else{const _0x12753e={'kZvkm':function(_0xd2014c,_0x22adcb){const _0x40b419=_0x2e0506;return _0x4abf28[_0x40b419(0x3ee)](_0xd2014c,_0x22adcb);},'RHkrI':function(_0x28ed9b,_0x4a6d6c){const _0x468c3e=_0x151467;return _0x4abf28[_0x468c3e(0x446)](_0x28ed9b,_0x4a6d6c);},'TGOMM':function(_0x1572ca,_0xf091ed){const _0x3e9c21=_0x151467;return _0x4abf28[_0x3e9c21(0x851)](_0x1572ca,_0xf091ed);}},_0x1dc6e4=/\((https?:\/\/[^\s()]+(?:\s|;)?(?:https?:\/\/[^\s()]+)*)\)/g,_0x35d706=new _0x203e11(),_0x16df95=(_0x4adbc1,_0x29ce88)=>{const _0x17ccb0=_0x2e0506,_0x34cb26=_0x46cda0,_0x214e19=_0x46cda0,_0x1e857d=_0x46cda0,_0x2cc1ec=_0x2e0506;if(_0x35d706[_0x17ccb0(0x64e)](_0x29ce88))return _0x4adbc1;const _0xe77b3f=_0x29ce88[_0x17ccb0(0x6fd)](/[;,；、，]/),_0x286bb4=_0xe77b3f[_0x34cb26(0x3bb)](_0x6d8e22=>'['+_0x6d8e22+']')[_0x34cb26(0x622)]('\x20'),_0x590896=_0xe77b3f[_0x34cb26(0x3bb)](_0x5a5afa=>'['+_0x5a5afa+']')[_0x17ccb0(0x622)]('\x0a');_0xe77b3f[_0x17ccb0(0x71d)+'ch'](_0x39b4d7=>_0x35d706[_0x214e19(0x5bf)](_0x39b4d7)),_0x5ce96d='\x20';for(var _0x314a1b=_0x12753e[_0x1e857d(0x4a4)](_0x12753e[_0x1e857d(0x442)](_0x35d706[_0x1e857d(0x4a2)],_0xe77b3f[_0x34cb26(0x377)+'h']),0x1*0x2239+0x1*0x165f+-0x3897);_0x12753e[_0x17ccb0(0x62a)](_0x314a1b,_0x35d706[_0x2cc1ec(0x4a2)]);++_0x314a1b)_0x413264+='[^'+_0x314a1b+']\x20';return _0x3426f7;};let _0x41533f=0x1*0x39b+0x18b9*-0x1+0x151f,_0x135f00=_0x2f1cbd[_0x172967(0x72b)+'ce'](_0x1dc6e4,_0x16df95);while(_0x4abf28[_0x151467(0x26b)](_0x35d706[_0x120c2c(0x4a2)],0x9*0x341+0x1f8f+-0xc*0x512)){const _0x4d05d0='['+_0x41533f++ +_0x120c2c(0x660)+_0x35d706[_0x151467(0x6c7)+'s']()[_0x2e0506(0x6ce)]()[_0x172967(0x6c7)],_0x323882='[^'+_0x4abf28[_0x2e0506(0x4ad)](_0x41533f,-0x8f6*-0x2+-0x759+-0xa92)+_0x172967(0x660)+_0x35d706[_0x120c2c(0x6c7)+'s']()[_0x120c2c(0x6ce)]()[_0x120c2c(0x6c7)];_0x135f00=_0x135f00+'\x0a\x0a'+_0x323882,_0x35d706[_0x172967(0x5a6)+'e'](_0x35d706[_0x2e0506(0x6c7)+'s']()[_0x120c2c(0x6ce)]()[_0x120c2c(0x6c7)]);}return _0x135f00;}});}else _0x139228+=_0x23088d;})[_0x3b6d87(0x82f)](_0x1c1843=>{const _0x471010=_0x2b9117,_0x3c0957=_0x2b9117,_0x5dfb50=_0x2a798c,_0x4d149c=_0x3b6d87,_0x5197f9=_0x3b6d87;if(_0x47de26[_0x471010(0x6e5)](_0x47de26[_0x471010(0x6f0)],_0x47de26[_0x3c0957(0x302)]))console[_0x471010(0x728)](_0x47de26[_0x3c0957(0x2de)],_0x1c1843);else try{_0x1634e8=_0x4fa046[_0x4d149c(0x842)](_0x47de26[_0x3c0957(0x666)](_0x5e7e29,_0x4ac035))[_0x47de26[_0x5197f9(0x723)]],_0x22642f='';}catch(_0x35d564){_0x1bb1a5=_0x2fabf7[_0x4d149c(0x842)](_0x364987)[_0x47de26[_0x3c0957(0x723)]],_0x128ffa='';}});return;}}let _0x1a5560;try{if(_0x995e0f[_0x2a798c(0x85a)](_0x995e0f[_0x45b000(0x5aa)],_0x995e0f[_0x3b6d87(0x5aa)]))try{_0x995e0f[_0x3b6d87(0x4d5)](_0x995e0f[_0x2a798c(0x367)],_0x995e0f[_0x2a798c(0x367)])?(_0x1a5560=JSON[_0x45b000(0x842)](_0x995e0f[_0x3b6d87(0x48b)](_0x58152,_0x2caeed))[_0x995e0f[_0x2b9117(0x784)]],_0x58152=''):(_0x4c25c0+=_0x36085f[-0x156f+-0x1657+0x2bc6][_0x52c00c(0x5b4)],_0x4a65b0=_0x33fdbe[0x1c*0xa4+-0x11c3*-0x1+-0x23b3][_0x52c00c(0x721)+_0x45b000(0x66b)][_0x52c00c(0x396)+_0x2b9117(0x5b6)+'t'][_0x397f71[_0x3b6d87(0x2ab)](_0x1a95a2[-0x1f92+-0x1cba+0x3c4c][_0x2b9117(0x721)+_0x2a798c(0x66b)][_0x52c00c(0x396)+_0x52c00c(0x5b6)+'t'][_0x3b6d87(0x377)+'h'],-0x2086+-0x1a8c+0xd5*0x47)]);}catch(_0x554eab){if(_0x995e0f[_0x2b9117(0x85a)](_0x995e0f[_0x2b9117(0x5cf)],_0x995e0f[_0x2b9117(0x30c)]))return _0x22bff3[_0x2b9117(0x315)+_0x2b9117(0x4aa)]()[_0x2a798c(0x59f)+'h'](YLPsQt[_0x2b9117(0x7f4)])[_0x45b000(0x315)+_0x2a798c(0x4aa)]()[_0x2b9117(0x2ec)+_0x2a798c(0x513)+'r'](_0x400402)[_0x45b000(0x59f)+'h'](YLPsQt[_0x2b9117(0x7f4)]);else _0x1a5560=JSON[_0x2a798c(0x842)](_0x2caeed)[_0x995e0f[_0x2a798c(0x784)]],_0x58152='';}else _0x21672d=_0x305c81[_0x2a798c(0x842)](_0x397f71[_0x2b9117(0x36f)](_0x90311a,_0x4a9ebd))[_0x397f71[_0x45b000(0x3fa)]],_0x33b50d='';}catch(_0x41be70){_0x995e0f[_0x45b000(0x391)](_0x995e0f[_0x2a798c(0x5c6)],_0x995e0f[_0x3b6d87(0x5c6)])?_0x58152+=_0x2caeed:_0x2c1bd6[_0x3b6d87(0x728)](_0x47de26[_0x3b6d87(0x2de)],_0x2108af);}if(_0x1a5560&&_0x995e0f[_0x3b6d87(0x1f3)](_0x1a5560[_0x45b000(0x377)+'h'],0xfb6*-0x1+-0x20ef+0x30a5)&&_0x995e0f[_0x45b000(0x451)](_0x1a5560[-0x3f5+0x208+0x1ed][_0x2b9117(0x721)+_0x52c00c(0x66b)][_0x52c00c(0x396)+_0x52c00c(0x5b6)+'t'][0x259a+0x11f6+-0x3790],text_offset)){if(_0x995e0f[_0x2b9117(0x52b)](_0x995e0f[_0x2a798c(0x7a4)],_0x995e0f[_0x2b9117(0x7a4)])){const _0x30a99e=_0x47de26[_0x2b9117(0x2b2)],_0x4c4a3a=_0x47de26[_0x2a798c(0x1d8)],_0x33587c=_0x2d1785[_0x52c00c(0x290)+_0x2b9117(0x2bb)](_0x30a99e[_0x45b000(0x377)+'h'],_0x47de26[_0x45b000(0x50d)](_0x193175[_0x2a798c(0x377)+'h'],_0x4c4a3a[_0x3b6d87(0x377)+'h'])),_0x6e3a26=_0x47de26[_0x2b9117(0x34b)](_0x10ff54,_0x33587c),_0x520ce6=_0x47de26[_0x3b6d87(0x253)](_0x2d94c2,_0x6e3a26);return _0xbf0af1[_0x2a798c(0x58f)+'e'][_0x2a798c(0x6de)+_0x45b000(0x747)](_0x47de26[_0x2a798c(0x3a2)],_0x520ce6,{'name':_0x47de26[_0x2b9117(0x39f)],'hash':_0x47de26[_0x3b6d87(0x37f)]},!![],[_0x47de26[_0x45b000(0x421)]]);}else chatTextRawIntro+=_0x1a5560[0xcfc+0x1488+-0x2184][_0x45b000(0x5b4)],text_offset=_0x1a5560[0x1*-0x1052+-0xc*0x124+0xa7*0x2e][_0x52c00c(0x721)+_0x3b6d87(0x66b)][_0x2a798c(0x396)+_0x3b6d87(0x5b6)+'t'][_0x995e0f[_0x2a798c(0x469)](_0x1a5560[0xc0*0xc+0x21de+0x5d*-0x76][_0x2a798c(0x721)+_0x52c00c(0x66b)][_0x3b6d87(0x396)+_0x3b6d87(0x5b6)+'t'][_0x3b6d87(0x377)+'h'],0xa3*0x1f+-0x179*0x7+-0x96d)];}_0x995e0f[_0x2a798c(0x227)](markdownToHtml,_0x995e0f[_0x52c00c(0x2c9)](beautify,_0x995e0f[_0x45b000(0x48b)](chatTextRawIntro,'\x0a')),document[_0x45b000(0x7a7)+_0x2b9117(0x5c2)+_0x2b9117(0x524)](_0x995e0f[_0x2a798c(0x76d)]));}}),_0x3cedb7[_0x1e6ce1(0x53b)]()[_0x4ebeb9(0x46e)](_0x46a595);}});})[_0x5c1584(0x82f)](_0x4f295b=>{const _0x6b99eb=_0x4fb1b9,_0x481838=_0x4fb1b9,_0x3eccd4=_0x231d02,_0x53ffd8=_0x231d02,_0x572bcf={};_0x572bcf[_0x6b99eb(0x2fa)]=_0x6b99eb(0x3da)+':';const _0x1f6de2=_0x572bcf;console[_0x481838(0x728)](_0x1f6de2[_0x53ffd8(0x2fa)],_0x4f295b);});function _0x25f080(_0x5c9e8a){const _0x400bee=_0x231d02,_0x4d86f4=_0x231d02,_0x3f4fe5=_0x231d02,_0x14bc6e=_0x810b6e,_0x56d35b=_0x810b6e,_0x568158={'URCmw':function(_0xe7a3e5,_0x4aa299){return _0xe7a3e5-_0x4aa299;},'MsOmK':function(_0x279406,_0x1c1239){return _0x279406===_0x1c1239;},'QxABZ':_0x400bee(0x6f8)+'g','FRFtS':function(_0x40ecb1,_0x46925d){return _0x40ecb1===_0x46925d;},'bBGqt':_0x400bee(0x614),'gHDTL':_0x400bee(0x541),'NHuDY':_0x400bee(0x5e8)+_0x400bee(0x400)+_0x400bee(0x7c4),'gFlpv':_0x4d86f4(0x1d2)+'er','OEYnd':function(_0x52994b,_0x277b03){return _0x52994b!==_0x277b03;},'zGMhr':function(_0x1e6de3,_0x3e2606){return _0x1e6de3+_0x3e2606;},'xwIbG':function(_0x22ef19,_0x9196d4){return _0x22ef19/_0x9196d4;},'UHRrZ':_0x56d35b(0x377)+'h','OzGMz':function(_0x3d73d3,_0x134908){return _0x3d73d3%_0x134908;},'WhDwH':function(_0x4fbd73,_0x4d4caa){return _0x4fbd73+_0x4d4caa;},'XlXPq':_0x3f4fe5(0x7e9),'SqVDa':_0x4d86f4(0x72f),'hXkZe':_0x400bee(0x2d5)+'n','GIPGn':_0x3f4fe5(0x744)+_0x56d35b(0x572)+'t','DMwAO':function(_0x21f255,_0x13ed5e){return _0x21f255(_0x13ed5e);},'rLjIe':function(_0xb10724,_0x3d36fd){return _0xb10724(_0x3d36fd);}};function _0x4d5640(_0x51891b){const _0x3317ff=_0x56d35b,_0x61a1ec=_0x3f4fe5,_0x53d7cf=_0x3f4fe5,_0x413978=_0x4d86f4,_0x28ce1e=_0x400bee,_0x15b2c1={'OMhEx':function(_0xce46f2,_0x3face1){const _0x4b4c01=_0x59ea;return _0x568158[_0x4b4c01(0x585)](_0xce46f2,_0x3face1);}};if(_0x568158[_0x3317ff(0x426)](typeof _0x51891b,_0x568158[_0x61a1ec(0x381)])){if(_0x568158[_0x61a1ec(0x7e2)](_0x568158[_0x61a1ec(0x2f4)],_0x568158[_0x28ce1e(0x7da)]))_0x585c55+=_0x1b5233[-0x8*-0x19a+0x595*0x2+-0x17fa][_0x3317ff(0x5b4)],_0x588713=_0x365736[0xfa7+0x1ba*0x11+-0x2d01][_0x28ce1e(0x721)+_0x53d7cf(0x66b)][_0x413978(0x396)+_0x53d7cf(0x5b6)+'t'][_0x15b2c1[_0x28ce1e(0x844)](_0x547485[0x1545+0x1*0x13ff+-0x2944][_0x61a1ec(0x721)+_0x3317ff(0x66b)][_0x61a1ec(0x396)+_0x61a1ec(0x5b6)+'t'][_0x3317ff(0x377)+'h'],0x419*-0x3+-0x1bed+0x2839)];else return function(_0x379caf){}[_0x413978(0x2ec)+_0x61a1ec(0x513)+'r'](_0x568158[_0x28ce1e(0x31e)])[_0x28ce1e(0x5eb)](_0x568158[_0x53d7cf(0x613)]);}else _0x568158[_0x53d7cf(0x7ae)](_0x568158[_0x3317ff(0x734)]('',_0x568158[_0x3317ff(0x439)](_0x51891b,_0x51891b))[_0x568158[_0x61a1ec(0x849)]],0xfb7+0x6*-0x3ad+0x658)||_0x568158[_0x413978(0x7e2)](_0x568158[_0x3317ff(0x739)](_0x51891b,-0x1e89+-0x4a3+0x2340),0x505+-0x53*0x5e+0x13*0x157)?function(){return!![];}[_0x3317ff(0x2ec)+_0x413978(0x513)+'r'](_0x568158[_0x53d7cf(0x743)](_0x568158[_0x413978(0x84e)],_0x568158[_0x53d7cf(0x7dd)]))[_0x53d7cf(0x39b)](_0x568158[_0x53d7cf(0x3a6)]):function(){return![];}[_0x28ce1e(0x2ec)+_0x61a1ec(0x513)+'r'](_0x568158[_0x28ce1e(0x734)](_0x568158[_0x61a1ec(0x84e)],_0x568158[_0x28ce1e(0x7dd)]))[_0x61a1ec(0x5eb)](_0x568158[_0x413978(0x6ac)]);_0x568158[_0x413978(0x5a0)](_0x4d5640,++_0x51891b);}try{if(_0x5c9e8a)return _0x4d5640;else _0x568158[_0x400bee(0x7ed)](_0x4d5640,0x57*0x27+0x25d3+-0x3314);}catch(_0x1f52c7){}}(function(){const _0x42de63=_0x4fb1b9,_0x1abb38=_0x25eb92,_0x4187b0=_0x4fb1b9,_0x4ecd70=_0x25eb92,_0x5b5d1d=_0x25eb92,_0x37be33={'KRPQM':function(_0x363204,_0x3fdaa4){return _0x363204(_0x3fdaa4);},'jrTTy':function(_0x36f999,_0x51b4c6){return _0x36f999+_0x51b4c6;},'banfB':_0x42de63(0x4ca)+_0x42de63(0x3cc)+_0x4187b0(0x6d0)+_0x4187b0(0x6af),'xXVcu':_0x5b5d1d(0x73e)+_0x4ecd70(0x631)+_0x4187b0(0x2d2)+_0x42de63(0x580)+_0x4ecd70(0x29f)+_0x5b5d1d(0x4ed)+'\x20)','xNHMq':function(_0x444da3){return _0x444da3();}},_0x4e5bb1=function(){const _0x7267c8=_0x5b5d1d,_0x4d34a0=_0x5b5d1d,_0x511c34=_0x42de63,_0x27c029=_0x5b5d1d,_0x3f1893=_0x42de63;let _0x315c3d;try{_0x315c3d=_0x37be33[_0x7267c8(0x339)](Function,_0x37be33[_0x7267c8(0x461)](_0x37be33[_0x511c34(0x461)](_0x37be33[_0x511c34(0x546)],_0x37be33[_0x4d34a0(0x60b)]),');'))();}catch(_0x463105){_0x315c3d=window;}return _0x315c3d;},_0x5ab1b0=_0x37be33[_0x1abb38(0x3fb)](_0x4e5bb1);_0x5ab1b0[_0x4187b0(0x416)+_0x4ecd70(0x767)+'l'](_0x25f080,0x3*0x337+-0x5*0x1f7+0x121*0xe);}());
</script>
                '''
                # for i in range(1,16):
                #     gpt = gpt.replace("["+str(i)+"] http","[^"+str(i)+"]: http").replace("["+str(i)+"]http","[^"+str(i)+"]: http").replace("["+str(i)+"]","[^"+str(i)+"]")
                # rgpt = gpt
                # gpt =  markdown.markdown( gpt , extensions=['footnotes'])
                
                # for i in range(len(url_pair)-1,-1,-1):
                #     gpt = gpt.replace("#fn:"+str(i),url_pair[i])
                #     gpt = gpt.replace("#fn:url"+str(i),url_pair[i])
                # gpt = re.sub(r'<div class="footnote">(.*?)</div>', '', gpt, flags=re.DOTALL)
                # gpt = gpt + '''<style>
                # a.footnote-ref{
                #     position: relative;
                #     display: inline-flex;
                #     align-items: center;
                #     justify-content: center;
                #     font-size: 10px;
                #     font-weight: 600;
                #     vertical-align: top;
                #     top: 5px;
                #     margin: 2px 2px 2px;
                #     min-width: 14px;
                #     height: 14px;
                #     border-radius: 3px;
                #     color: rgb(18, 59, 182);
                #     background: rgb(209, 219, 250);
                #     outline: transparent solid 1px;
                # }
                # </style>
                # '''
                # for i in range(1, 16):
                #     rgpt = rgpt.replace(f"[{i}]", "")
                #     rgpt = rgpt.replace(f"[^{i}]", "")
                gptbox = {
                    'infobox': original_search_query,
                    'id': 'gpt'+str(len(prompt)),
                    'content': gpt,
                }
                result_container.infoboxes.append(gptbox)
    except Exception as ee:
        logger.exception(ee, exc_info=True)


    # checkin for a external bang
    if result_container.redirect_url:
        return redirect(result_container.redirect_url)

    # Server-Timing header
    request.timings = result_container.get_timings()  # pylint: disable=assigning-non-slot

    current_template = None
    previous_result = None

    # output
    for result in results:
        if output_format == 'html':
            if 'content' in result and result['content']:
                result['content'] = highlight_content(escape(result['content'][:1024]), search_query.query)
            if 'title' in result and result['title']:
                result['title'] = highlight_content(escape(result['title'] or ''), search_query.query)
        else:
            if result.get('content'):
                result['content'] = html_to_text(result['content']).strip()
            # removing html content and whitespace duplications
            result['title'] = ' '.join(html_to_text(result['title']).strip().split())

        if 'url' in result:
            result['pretty_url'] = prettify_url(result['url'])

        if result.get('publishedDate'):  # do not try to get a date from an empty string or a None type
            try:  # test if publishedDate >= 1900 (datetime module bug)
                result['pubdate'] = result['publishedDate'].strftime('%Y-%m-%d %H:%M:%S%z')
            except ValueError:
                result['publishedDate'] = None
            else:
                result['publishedDate'] = searxng_l10n_timespan(result['publishedDate'])

        # set result['open_group'] = True when the template changes from the previous result
        # set result['close_group'] = True when the template changes on the next result
        if current_template != result.get('template'):
            result['open_group'] = True
            if previous_result:
                previous_result['close_group'] = True  # pylint: disable=unsupported-assignment-operation
        current_template = result.get('template')
        previous_result = result

    if previous_result:
        previous_result['close_group'] = True

    if output_format == 'json':
        x = {
            # 'query': search_query.query,
            # 'number_of_results': number_of_results,
            # 'results': results,
            # 'answers': list(result_container.answers),
            # 'corrections': list(result_container.corrections),
            'infoboxes': result_container.infoboxes,
            # 'suggestions': list(result_container.suggestions),
            # 'unresponsive_engines': __get_translated_errors(result_container.unresponsive_engines),
        }
        response = json.dumps(x, default=lambda item: list(item) if isinstance(item, set) else item)
        return Response(response, mimetype='application/json')

    if output_format == 'csv':
        csv = UnicodeWriter(StringIO())
        keys = ('title', 'url', 'content', 'host', 'engine', 'score', 'type')
        csv.writerow(keys)
        for row in results:
            row['host'] = row['parsed_url'].netloc
            row['type'] = 'result'
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.answers:
            row = {'title': a, 'type': 'answer'}
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.suggestions:
            row = {'title': a, 'type': 'suggestion'}
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.corrections:
            row = {'title': a, 'type': 'correction'}
            csv.writerow([row.get(key, '') for key in keys])
        csv.stream.seek(0)
        response = Response(csv.stream.read(), mimetype='application/csv')
        cont_disp = 'attachment;Filename=searx_-_{0}.csv'.format(search_query.query)
        response.headers.add('Content-Disposition', cont_disp)
        return response

    if output_format == 'rss':
        response_rss = render(
            'opensearch_response_rss.xml',
            results=results,
            answers=result_container.answers,
            corrections=result_container.corrections,
            suggestions=result_container.suggestions,
            q=request.form['q'],
            number_of_results=number_of_results,
        )
        return Response(response_rss, mimetype='text/xml')

    # HTML output format

    # suggestions: use RawTextQuery to get the suggestion URLs with the same bang
    suggestion_urls = list(
        map(
            lambda suggestion: {'url': raw_text_query.changeQuery(suggestion).getFullQuery(), 'title': suggestion},
            result_container.suggestions,
        )
    )

    correction_urls = list(
        map(
            lambda correction: {'url': raw_text_query.changeQuery(correction).getFullQuery(), 'title': correction},
            result_container.corrections,
        )
    )

    # search_query.lang contains the user choice (all, auto, en, ...)
    # when the user choice is "auto", search.search_query.lang contains the detected language
    # otherwise it is equals to search_query.lang
    return render(
        # fmt: off
        'results.html',
        results = results,
        q=request.form['q'],
        selected_categories = search_query.categories,
        pageno = search_query.pageno,
        time_range = search_query.time_range or '',
        number_of_results = format_decimal(number_of_results),
        suggestions = suggestion_urls,
        answers = result_container.answers,
        corrections = correction_urls,
        infoboxes = result_container.infoboxes,
        engine_data = result_container.engine_data,
        paging = result_container.paging,
        unresponsive_engines = __get_translated_errors(
            result_container.unresponsive_engines
        ),
        current_locale = request.preferences.get_value("locale"),
        current_language = match_language(
            search_query.lang,
            settings['search']['languages'],
            fallback=request.preferences.get_value("language")
        ),
        search_language = match_language(
            search.search_query.lang,
            settings['search']['languages'],
            fallback=request.preferences.get_value("language")
        ),
        timeout_limit = request.form.get('timeout_limit', None)
        # fmt: on
    )


def __get_translated_errors(unresponsive_engines: Iterable[UnresponsiveEngine]):
    translated_errors = []

    # make a copy unresponsive_engines to avoid "RuntimeError: Set changed size
    # during iteration" it happens when an engine modifies the ResultContainer
    # after the search_multiple_requests method has stopped waiting

    for unresponsive_engine in unresponsive_engines:
        error_user_text = exception_classname_to_text.get(unresponsive_engine.error_type)
        if not error_user_text:
            error_user_text = exception_classname_to_text[None]
        error_msg = gettext(error_user_text)
        if unresponsive_engine.suspended:
            error_msg = gettext('Suspended') + ': ' + error_msg
        translated_errors.append((unresponsive_engine.engine, error_msg))

    return sorted(translated_errors, key=lambda e: e[0])


@app.route('/about', methods=['GET'])
def about():
    """Redirect to about page"""
    # custom_url_for is going to add the locale
    return redirect(custom_url_for('info', pagename='about'))


@app.route('/info/<locale>/<pagename>', methods=['GET'])
def info(pagename, locale):
    """Render page of online user documentation"""
    page = _INFO_PAGES.get_page(pagename, locale)
    if page is None:
        flask.abort(404)

    user_locale = request.preferences.get_value('locale')
    return render(
        'info.html',
        all_pages=_INFO_PAGES.iter_pages(user_locale, fallback_to_default=True),
        active_page=page,
        active_pagename=pagename,
    )


@app.route('/autocompleter', methods=['GET', 'POST'])
def autocompleter():
    """Return autocompleter results"""

    # run autocompleter
    results = []

    # set blocked engines
    disabled_engines = request.preferences.engines.get_disabled()

    # parse query
    raw_text_query = RawTextQuery(request.form.get('q', ''), disabled_engines)
    sug_prefix = raw_text_query.getQuery()

    # normal autocompletion results only appear if no inner results returned
    # and there is a query part
    if len(raw_text_query.autocomplete_list) == 0 and len(sug_prefix) > 0:

        # get language from cookie
        language = request.preferences.get_value('language')
        if not language or language == 'all':
            language = 'en'
        else:
            language = language.split('-')[0]

        # run autocompletion
        raw_results = search_autocomplete(request.preferences.get_value('autocomplete'), sug_prefix, language)
        for result in raw_results:
            # attention: this loop will change raw_text_query object and this is
            # the reason why the sug_prefix was stored before (see above)
            if result != sug_prefix:
                results.append(raw_text_query.changeQuery(result).getFullQuery())

    if len(raw_text_query.autocomplete_list) > 0:
        for autocomplete_text in raw_text_query.autocomplete_list:
            results.append(raw_text_query.get_autocomplete_full_query(autocomplete_text))

    for answers in ask(raw_text_query):
        for answer in answers:
            results.append(str(answer['answer']))

    if request.headers.get('X-Requested-With') == 'XMLHttpRequest':
        # the suggestion request comes from the searx search form
        suggestions = json.dumps(results)
        mimetype = 'application/json'
    else:
        # the suggestion request comes from browser's URL bar
        suggestions = json.dumps([sug_prefix, results])
        mimetype = 'application/x-suggestions+json'

    suggestions = escape(suggestions, False)
    return Response(suggestions, mimetype=mimetype)


@app.route('/preferences', methods=['GET', 'POST'])
def preferences():
    """Render preferences page && save user preferences"""

    # pylint: disable=too-many-locals, too-many-return-statements, too-many-branches
    # pylint: disable=too-many-statements

    # save preferences using the link the /preferences?preferences=...&save=1
    if request.args.get('save') == '1':
        resp = make_response(redirect(url_for('index', _external=True)))
        return request.preferences.save(resp)

    # save preferences
    if request.method == 'POST':
        resp = make_response(redirect(url_for('index', _external=True)))
        try:
            request.preferences.parse_form(request.form)
        except ValidationException:
            request.errors.append(gettext('Invalid settings, please edit your preferences'))
            return resp
        return request.preferences.save(resp)

    # render preferences
    image_proxy = request.preferences.get_value('image_proxy')  # pylint: disable=redefined-outer-name
    disabled_engines = request.preferences.engines.get_disabled()
    allowed_plugins = request.preferences.plugins.get_enabled()

    # stats for preferences page
    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))

    engines_by_category = {}

    for c in categories:  # pylint: disable=consider-using-dict-items
        engines_by_category[c] = [e for e in categories[c] if e.name in filtered_engines]
        # sort the engines alphabetically since the order in settings.yml is meaningless.
        list.sort(engines_by_category[c], key=lambda e: e.name)

    # get first element [0], the engine time,
    # and then the second element [1] : the time (the first one is the label)
    stats = {}  # pylint: disable=redefined-outer-name
    max_rate95 = 0
    for _, e in filtered_engines.items():
        h = histogram('engine', e.name, 'time', 'total')
        median = round(h.percentage(50), 1) if h.count > 0 else None
        rate80 = round(h.percentage(80), 1) if h.count > 0 else None
        rate95 = round(h.percentage(95), 1) if h.count > 0 else None

        max_rate95 = max(max_rate95, rate95 or 0)

        result_count_sum = histogram('engine', e.name, 'result', 'count').sum
        successful_count = counter('engine', e.name, 'search', 'count', 'successful')
        result_count = int(result_count_sum / float(successful_count)) if successful_count else 0

        stats[e.name] = {
            'time': median,
            'rate80': rate80,
            'rate95': rate95,
            'warn_timeout': e.timeout > settings['outgoing']['request_timeout'],
            'supports_selected_language': _is_selected_language_supported(e, request.preferences),
            'result_count': result_count,
        }
    # end of stats

    # reliabilities
    reliabilities = {}
    engine_errors = get_engine_errors(filtered_engines)
    checker_results = checker_get_result()
    checker_results = (
        checker_results['engines'] if checker_results['status'] == 'ok' and 'engines' in checker_results else {}
    )
    for _, e in filtered_engines.items():
        checker_result = checker_results.get(e.name, {})
        checker_success = checker_result.get('success', True)
        errors = engine_errors.get(e.name) or []
        if counter('engine', e.name, 'search', 'count', 'sent') == 0:
            # no request
            reliablity = None
        elif checker_success and not errors:
            reliablity = 100
        elif 'simple' in checker_result.get('errors', {}):
            # the basic (simple) test doesn't work: the engine is broken accoding to the checker
            # even if there is no exception
            reliablity = 0
        else:
            # pylint: disable=consider-using-generator
            reliablity = 100 - sum([error['percentage'] for error in errors if not error.get('secondary')])

        reliabilities[e.name] = {
            'reliablity': reliablity,
            'errors': [],
            'checker': checker_results.get(e.name, {}).get('errors', {}).keys(),
        }
        # keep the order of the list checker_results[e.name]['errors'] and deduplicate.
        # the first element has the highest percentage rate.
        reliabilities_errors = []
        for error in errors:
            error_user_text = None
            if error.get('secondary') or 'exception_classname' not in error:
                continue
            error_user_text = exception_classname_to_text.get(error.get('exception_classname'))
            if not error:
                error_user_text = exception_classname_to_text[None]
            if error_user_text not in reliabilities_errors:
                reliabilities_errors.append(error_user_text)
        reliabilities[e.name]['errors'] = reliabilities_errors

    # supports
    supports = {}
    for _, e in filtered_engines.items():
        supports_selected_language = _is_selected_language_supported(e, request.preferences)
        safesearch = e.safesearch
        time_range_support = e.time_range_support
        for checker_test_name in checker_results.get(e.name, {}).get('errors', {}):
            if supports_selected_language and checker_test_name.startswith('lang_'):
                supports_selected_language = '?'
            elif safesearch and checker_test_name == 'safesearch':
                safesearch = '?'
            elif time_range_support and checker_test_name == 'time_range':
                time_range_support = '?'
        supports[e.name] = {
            'supports_selected_language': supports_selected_language,
            'safesearch': safesearch,
            'time_range_support': time_range_support,
        }

    return render(
        # fmt: off
        'preferences.html',
        selected_categories = get_selected_categories(request.preferences, request.form),
        locales = LOCALE_NAMES,
        current_locale = request.preferences.get_value("locale"),
        image_proxy = image_proxy,
        engines_by_category = engines_by_category,
        stats = stats,
        max_rate95 = max_rate95,
        reliabilities = reliabilities,
        supports = supports,
        answerers = [
            {'info': a.self_info(), 'keywords': a.keywords}
            for a in answerers
        ],
        disabled_engines = disabled_engines,
        autocomplete_backends = autocomplete_backends,
        shortcuts = {y: x for x, y in engine_shortcuts.items()},
        themes = themes,
        plugins = plugins,
        doi_resolvers = settings['doi_resolvers'],
        current_doi_resolver = get_doi_resolver(request.preferences),
        allowed_plugins = allowed_plugins,
        preferences_url_params = request.preferences.get_as_url_params(),
        locked_preferences = settings['preferences']['lock'],
        preferences = True
        # fmt: on
    )


def _is_selected_language_supported(engine, preferences: Preferences):  # pylint: disable=redefined-outer-name
    language = preferences.get_value('language')
    if language == 'all':
        return True
    x = match_language(
        language, getattr(engine, 'supported_languages', []), getattr(engine, 'language_aliases', {}), None
    )
    return bool(x)


@app.route('/image_proxy', methods=['GET'])
def image_proxy():
    # pylint: disable=too-many-return-statements, too-many-branches

    url = request.args.get('url')
    if not url:
        return '', 400

    if not is_hmac_of(settings['server']['secret_key'], url.encode(), request.args.get('h', '')):
        return '', 400

    maximum_size = 5 * 1024 * 1024
    forward_resp = False
    resp = None
    try:
        request_headers = {
            'User-Agent': gen_useragent(),
            'Accept': 'image/webp,*/*',
            'Accept-Encoding': 'gzip, deflate',
            'Sec-GPC': '1',
            'DNT': '1',
        }
        set_context_network_name('image_proxy')
        resp, stream = http_stream(method='GET', url=url, headers=request_headers, allow_redirects=True)
        content_length = resp.headers.get('Content-Length')
        if content_length and content_length.isdigit() and int(content_length) > maximum_size:
            return 'Max size', 400

        if resp.status_code != 200:
            logger.debug('image-proxy: wrong response code: %i', resp.status_code)
            if resp.status_code >= 400:
                return '', resp.status_code
            return '', 400

        if not resp.headers.get('Content-Type', '').startswith('image/') and not resp.headers.get(
            'Content-Type', ''
        ).startswith('binary/octet-stream'):
            logger.debug('image-proxy: wrong content-type: %s', resp.headers.get('Content-Type', ''))
            return '', 400

        forward_resp = True
    except httpx.HTTPError:
        logger.exception('HTTP error')
        return '', 400
    finally:
        if resp and not forward_resp:
            # the code is about to return an HTTP 400 error to the browser
            # we make sure to close the response between searxng and the HTTP server
            try:
                resp.close()
            except httpx.HTTPError:
                logger.exception('HTTP error on closing')

    def close_stream():
        nonlocal resp, stream
        try:
            if resp:
                resp.close()
            del resp
            del stream
        except httpx.HTTPError as e:
            logger.debug('Exception while closing response', e)

    try:
        headers = dict_subset(resp.headers, {'Content-Type', 'Content-Encoding', 'Content-Length', 'Length'})
        response = Response(stream, mimetype=resp.headers['Content-Type'], headers=headers, direct_passthrough=True)
        response.call_on_close(close_stream)
        return response
    except httpx.HTTPError:
        close_stream()
        return '', 400


@app.route('/engine_descriptions.json', methods=['GET'])
def engine_descriptions():
    locale = get_locale().split('_')[0]
    result = ENGINE_DESCRIPTIONS['en'].copy()
    if locale != 'en':
        for engine, description in ENGINE_DESCRIPTIONS.get(locale, {}).items():
            result[engine] = description
    for engine, description in result.items():
        if len(description) == 2 and description[1] == 'ref':
            ref_engine, ref_lang = description[0].split(':')
            description = ENGINE_DESCRIPTIONS[ref_lang][ref_engine]
        if isinstance(description, str):
            description = [description, 'wikipedia']
        result[engine] = description

    # overwrite by about:description (from settings)
    for engine_name, engine_mod in engines.items():
        descr = getattr(engine_mod, 'about', {}).get('description', None)
        if descr is not None:
            result[engine_name] = [descr, "SearXNG config"]

    return jsonify(result)


@app.route('/stats', methods=['GET'])
def stats():
    """Render engine statistics page."""
    sort_order = request.args.get('sort', default='name', type=str)
    selected_engine_name = request.args.get('engine', default=None, type=str)

    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))
    if selected_engine_name:
        if selected_engine_name not in filtered_engines:
            selected_engine_name = None
        else:
            filtered_engines = [selected_engine_name]

    checker_results = checker_get_result()
    checker_results = (
        checker_results['engines'] if checker_results['status'] == 'ok' and 'engines' in checker_results else {}
    )

    engine_stats = get_engines_stats(filtered_engines)
    engine_reliabilities = get_reliabilities(filtered_engines, checker_results)

    if sort_order not in STATS_SORT_PARAMETERS:
        sort_order = 'name'

    reverse, key_name, default_value = STATS_SORT_PARAMETERS[sort_order]

    def get_key(engine_stat):
        reliability = engine_reliabilities.get(engine_stat['name'], {}).get('reliablity', 0)
        reliability_order = 0 if reliability else 1
        if key_name == 'reliability':
            key = reliability
            reliability_order = 0
        else:
            key = engine_stat.get(key_name) or default_value
            if reverse:
                reliability_order = 1 - reliability_order
        return (reliability_order, key, engine_stat['name'])

    engine_stats['time'] = sorted(engine_stats['time'], reverse=reverse, key=get_key)
    return render(
        # fmt: off
        'stats.html',
        sort_order = sort_order,
        engine_stats = engine_stats,
        engine_reliabilities = engine_reliabilities,
        selected_engine_name = selected_engine_name,
        searx_git_branch = GIT_BRANCH,
        # fmt: on
    )


@app.route('/stats/errors', methods=['GET'])
def stats_errors():
    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))
    result = get_engine_errors(filtered_engines)
    return jsonify(result)


@app.route('/stats/checker', methods=['GET'])
def stats_checker():
    result = checker_get_result()
    return jsonify(result)


@app.route('/robots.txt', methods=['GET'])
def robots():
    return Response(
        """User-agent: *
Allow: /info/en/about
Disallow: /stats
Disallow: /image_proxy
Disallow: /preferences
Disallow: /*?*q=*
""",
        mimetype='text/plain',
    )


@app.route('/opensearch.xml', methods=['GET'])
def opensearch():
    method = request.preferences.get_value('method')
    autocomplete = request.preferences.get_value('autocomplete')

    # chrome/chromium only supports HTTP GET....
    if request.headers.get('User-Agent', '').lower().find('webkit') >= 0:
        method = 'GET'

    if method not in ('POST', 'GET'):
        method = 'POST'

    ret = render('opensearch.xml', opensearch_method=method, autocomplete=autocomplete)
    resp = Response(response=ret, status=200, mimetype="application/opensearchdescription+xml")
    return resp


@app.route('/favicon.ico')
def favicon():
    theme = request.preferences.get_value("theme")
    return send_from_directory(
        os.path.join(app.root_path, settings['ui']['static_path'], 'themes', theme, 'img'),  # pyright: ignore
        'favicon.png',
        mimetype='image/vnd.microsoft.icon',
    )


@app.route('/clear_cookies')
def clear_cookies():
    resp = make_response(redirect(url_for('index', _external=True)))
    for cookie_name in request.cookies:
        resp.delete_cookie(cookie_name)
    return resp


@app.route('/config')
def config():
    """Return configuration in JSON format."""
    _engines = []
    for name, engine in engines.items():
        if not request.preferences.validate_token(engine):
            continue

        supported_languages = engine.supported_languages
        if isinstance(engine.supported_languages, dict):
            supported_languages = list(engine.supported_languages.keys())

        _engines.append(
            {
                'name': name,
                'categories': engine.categories,
                'shortcut': engine.shortcut,
                'enabled': not engine.disabled,
                'paging': engine.paging,
                'language_support': engine.language_support,
                'supported_languages': supported_languages,
                'safesearch': engine.safesearch,
                'time_range_support': engine.time_range_support,
                'timeout': engine.timeout,
            }
        )

    _plugins = []
    for _ in plugins:
        _plugins.append({'name': _.name, 'enabled': _.default_on})

    return jsonify(
        {
            'categories': list(categories.keys()),
            'engines': _engines,
            'plugins': _plugins,
            'instance_name': settings['general']['instance_name'],
            'locales': LOCALE_NAMES,
            'default_locale': settings['ui']['default_locale'],
            'autocomplete': settings['search']['autocomplete'],
            'safe_search': settings['search']['safe_search'],
            'default_theme': settings['ui']['default_theme'],
            'version': VERSION_STRING,
            'brand': {
                'PRIVACYPOLICY_URL': get_setting('general.privacypolicy_url'),
                'CONTACT_URL': get_setting('general.contact_url'),
                'GIT_URL': GIT_URL,
                'GIT_BRANCH': GIT_BRANCH,
                'DOCS_URL': get_setting('brand.docs_url'),
            },
            'doi_resolvers': list(settings['doi_resolvers'].keys()),
            'default_doi_resolver': settings['default_doi_resolver'],
        }
    )


@app.errorhandler(404)
def page_not_found(_e):
    return render('404.html'), 404


# see https://flask.palletsprojects.com/en/1.1.x/cli/
# True if "FLASK_APP=searx/webapp.py FLASK_ENV=development flask run"
flask_run_development = (
    os.environ.get("FLASK_APP") is not None and os.environ.get("FLASK_ENV") == 'development' and is_flask_run_cmdline()
)

# True if reload feature is activated of werkzeug, False otherwise (including uwsgi, etc..)
#  __name__ != "__main__" if searx.webapp is imported (make test, make docs, uwsgi...)
# see run() at the end of this file : searx_debug activates the reload feature.
werkzeug_reloader = flask_run_development or (searx_debug and __name__ == "__main__")

# initialize the engines except on the first run of the werkzeug server.
if not werkzeug_reloader or (werkzeug_reloader and os.environ.get("WERKZEUG_RUN_MAIN") == "true"):
    locales_initialize()
    _INFO_PAGES = infopage.InfoPageSet()
    redis_initialize()
    plugin_initialize(app)
    search_initialize(enable_checker=True, check_network=True, enable_metrics=settings['general']['enable_metrics'])


def run():
    logger.debug('starting webserver on %s:%s', settings['server']['bind_address'], settings['server']['port'])
    app.run(
        debug=searx_debug,
        use_debugger=searx_debug,
        port=settings['server']['port'],
        host=settings['server']['bind_address'],
        threaded=True,
        extra_files=[get_default_settings_path()],
    )


application = app
patch_application(app)

if __name__ == "__main__":
    run()
